#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#
from enum import IntEnum
from typing import Tuple


class Tag(IntEnum):  # pragma: no cover
    @property
    def group(self) -> int:
        return self >> 16

    @property
    def element(self) -> int:
        return self & 0xFFFF

    def __str__(self) -> str:
        tag_repr = "<{0:04x},{1:04x}>".format(self.group, self.element)
        return f"{tag_repr} {self.name}"

    def __repr__(self) -> str:
        return str(self)

    def __len__(self) -> int:
        return 1  # Objects from this class only ever correspond to a single tag

    def __getitem__(self, i) -> int:
        return self.tag_tuple[i]

    @property
    def tag_tuple(self) -> Tuple[int, int]:
        return self.group, self.element

    # >>> BEGIN TAGS >>>
    CommandGroupLength = 0
    CommandLengthToEnd = 1
    AffectedSOPClassUID = 2
    RequestedSOPClassUID = 3
    CommandRecognitionCode = 16
    CommandField = 256
    MessageID = 272
    MessageIDBeingRespondedTo = 288
    Initiator = 512
    Receiver = 768
    FindLocation = 1024
    MoveDestination = 1536
    Priority = 1792
    CommandDataSetType = 2048
    NumberOfMatches = 2128
    ResponseSequenceNumber = 2144
    Status = 2304
    OffendingElement = 2305
    ErrorComment = 2306
    ErrorID = 2307
    AffectedSOPInstanceUID = 4096
    RequestedSOPInstanceUID = 4097
    EventTypeID = 4098
    AttributeIdentifierList = 4101
    ActionTypeID = 4104
    NumberOfRemainingSuboperations = 4128
    NumberOfCompletedSuboperations = 4129
    NumberOfFailedSuboperations = 4130
    NumberOfWarningSuboperations = 4131
    MoveOriginatorApplicationEntityTitle = 4144
    MoveOriginatorMessageID = 4145
    DialogReceiver = 16384
    TerminalType = 16400
    MessageSetID = 20496
    EndMessageID = 20512
    DisplayFormat = 20752
    PagePositionID = 20768
    TextFormatID = 20784
    NormalReverse = 20800
    AddGrayScale = 20816
    Borders = 20832
    Copies = 20848
    CommandMagnificationType = 20864
    Erase = 20880
    Print = 20896
    Overlays = 20912
    FileMetaInformationGroupLength = 131072
    FileMetaInformationVersion = 131073
    MediaStorageSOPClassUID = 131074
    MediaStorageSOPInstanceUID = 131075
    TransferSyntaxUID = 131088
    ImplementationClassUID = 131090
    ImplementationVersionName = 131091
    SourceApplicationEntityTitle = 131094
    SendingApplicationEntityTitle = 131095
    ReceivingApplicationEntityTitle = 131096
    SourcePresentationAddress = 131110
    SendingPresentationAddress = 131111
    ReceivingPresentationAddress = 131112
    RTVMetaInformationVersion = 131121
    RTVCommunicationSOPClassUID = 131122
    RTVCommunicationSOPInstanceUID = 131123
    RTVSourceIdentifier = 131125
    RTVFlowIdentifier = 131126
    RTVFlowRTPSamplingRate = 131127
    RTVFlowActualFrameDuration = 131128
    PrivateInformationCreatorUID = 131328
    PrivateInformation = 131330
    FileSetID = 266544
    FileSetDescriptorFileID = 266561
    SpecificCharacterSetOfFileSetDescriptorFile = 266562
    OffsetOfTheFirstDirectoryRecordOfTheRootDirectoryEntity = 266752
    OffsetOfTheLastDirectoryRecordOfTheRootDirectoryEntity = 266754
    FileSetConsistencyFlag = 266770
    DirectoryRecordSequence = 266784
    OffsetOfTheNextDirectoryRecord = 267264
    RecordInUseFlag = 267280
    OffsetOfReferencedLowerLevelDirectoryEntity = 267296
    DirectoryRecordType = 267312
    PrivateRecordUID = 267314
    ReferencedFileID = 267520
    MRDRDirectoryRecordOffset = 267524
    ReferencedSOPClassUIDInFile = 267536
    ReferencedSOPInstanceUIDInFile = 267537
    ReferencedTransferSyntaxUIDInFile = 267538
    ReferencedRelatedGeneralSOPClassUIDInFile = 267546
    NumberOfReferences = 267776
    LengthToEnd = 524289
    SpecificCharacterSet = 524293
    LanguageCodeSequence = 524294
    ImageType = 524296
    RecognitionCode = 524304
    InstanceCreationDate = 524306
    InstanceCreationTime = 524307
    InstanceCreatorUID = 524308
    InstanceCoercionDateTime = 524309
    SOPClassUID = 524310
    SOPInstanceUID = 524312
    RelatedGeneralSOPClassUID = 524314
    OriginalSpecializedSOPClassUID = 524315
    StudyDate = 524320
    SeriesDate = 524321
    AcquisitionDate = 524322
    ContentDate = 524323
    OverlayDate = 524324
    CurveDate = 524325
    AcquisitionDateTime = 524330
    StudyTime = 524336
    SeriesTime = 524337
    AcquisitionTime = 524338
    ContentTime = 524339
    OverlayTime = 524340
    CurveTime = 524341
    DataSetType = 524352
    DataSetSubtype = 524353
    NuclearMedicineSeriesType = 524354
    AccessionNumber = 524368
    IssuerOfAccessionNumberSequence = 524369
    QueryRetrieveLevel = 524370
    QueryRetrieveView = 524371
    RetrieveAETitle = 524372
    StationAETitle = 524373
    InstanceAvailability = 524374
    FailedSOPInstanceUIDList = 524376
    Modality = 524384
    ModalitiesInStudy = 524385
    SOPClassesInStudy = 524386
    AnatomicRegionsInStudyCodeSequence = 524387
    ConversionType = 524388
    PresentationIntentType = 524392
    Manufacturer = 524400
    InstitutionName = 524416
    InstitutionAddress = 524417
    InstitutionCodeSequence = 524418
    ReferringPhysicianName = 524432
    ReferringPhysicianAddress = 524434
    ReferringPhysicianTelephoneNumbers = 524436
    ReferringPhysicianIdentificationSequence = 524438
    ConsultingPhysicianName = 524444
    ConsultingPhysicianIdentificationSequence = 524445
    CodeValue = 524544
    ExtendedCodeValue = 524545
    CodingSchemeDesignator = 524546
    CodingSchemeVersion = 524547
    CodeMeaning = 524548
    MappingResource = 524549
    ContextGroupVersion = 524550
    ContextGroupLocalVersion = 524551
    ExtendedCodeMeaning = 524552
    CodingSchemeResourcesSequence = 524553
    CodingSchemeURLType = 524554
    ContextGroupExtensionFlag = 524555
    CodingSchemeUID = 524556
    ContextGroupExtensionCreatorUID = 524557
    CodingSchemeURL = 524558
    ContextIdentifier = 524559
    CodingSchemeIdentificationSequence = 524560
    CodingSchemeRegistry = 524562
    CodingSchemeExternalID = 524564
    CodingSchemeName = 524565
    CodingSchemeResponsibleOrganization = 524566
    ContextUID = 524567
    MappingResourceUID = 524568
    LongCodeValue = 524569
    URNCodeValue = 524576
    EquivalentCodeSequence = 524577
    MappingResourceName = 524578
    ContextGroupIdentificationSequence = 524579
    MappingResourceIdentificationSequence = 524580
    TimezoneOffsetFromUTC = 524801
    ResponsibleGroupCodeSequence = 524832
    EquipmentModality = 524833
    ManufacturerRelatedModelGroup = 524834
    PrivateDataElementCharacteristicsSequence = 525056
    PrivateGroupReference = 525057
    PrivateCreatorReference = 525058
    BlockIdentifyingInformationStatus = 525059
    NonidentifyingPrivateElements = 525060
    DeidentificationActionSequence = 525061
    IdentifyingPrivateElements = 525062
    DeidentificationAction = 525063
    PrivateDataElement = 525064
    PrivateDataElementValueMultiplicity = 525065
    PrivateDataElementValueRepresentation = 525066
    PrivateDataElementNumberOfItems = 525067
    PrivateDataElementName = 525068
    PrivateDataElementKeyword = 525069
    PrivateDataElementDescription = 525070
    PrivateDataElementEncoding = 525071
    PrivateDataElementDefinitionSequence = 525072
    NetworkID = 528384
    StationName = 528400
    StudyDescription = 528432
    ProcedureCodeSequence = 528434
    SeriesDescription = 528446
    SeriesDescriptionCodeSequence = 528447
    InstitutionalDepartmentName = 528448
    InstitutionalDepartmentTypeCodeSequence = 528449
    PhysiciansOfRecord = 528456
    PhysiciansOfRecordIdentificationSequence = 528457
    PerformingPhysicianName = 528464
    PerformingPhysicianIdentificationSequence = 528466
    NameOfPhysiciansReadingStudy = 528480
    PhysiciansReadingStudyIdentificationSequence = 528482
    OperatorsName = 528496
    OperatorIdentificationSequence = 528498
    AdmittingDiagnosesDescription = 528512
    AdmittingDiagnosesCodeSequence = 528516
    ManufacturerModelName = 528528
    ReferencedResultsSequence = 528640
    ReferencedStudySequence = 528656
    ReferencedPerformedProcedureStepSequence = 528657
    ReferencedSeriesSequence = 528661
    ReferencedPatientSequence = 528672
    ReferencedVisitSequence = 528677
    ReferencedOverlaySequence = 528688
    ReferencedStereometricInstanceSequence = 528692
    ReferencedWaveformSequence = 528698
    ReferencedImageSequence = 528704
    ReferencedCurveSequence = 528709
    ReferencedInstanceSequence = 528714
    ReferencedRealWorldValueMappingInstanceSequence = 528715
    ReferencedSOPClassUID = 528720
    ReferencedSOPInstanceUID = 528725
    DefinitionSourceSequence = 528726
    SOPClassesSupported = 528730
    ReferencedFrameNumber = 528736
    SimpleFrameList = 528737
    CalculatedFrameList = 528738
    TimeRange = 528739
    FrameExtractionSequence = 528740
    MultiFrameSourceSOPInstanceUID = 528743
    RetrieveURL = 528784
    TransactionUID = 528789
    WarningReason = 528790
    FailureReason = 528791
    FailedSOPSequence = 528792
    ReferencedSOPSequence = 528793
    OtherFailuresSequence = 528794
    StudiesContainingOtherReferencedInstancesSequence = 528896
    RelatedSeriesSequence = 528976
    LossyImageCompressionRetired = 532752
    DerivationDescription = 532753
    SourceImageSequence = 532754
    StageName = 532768
    StageNumber = 532770
    NumberOfStages = 532772
    ViewName = 532775
    ViewNumber = 532776
    NumberOfEventTimers = 532777
    NumberOfViewsInStage = 532778
    EventElapsedTimes = 532784
    EventTimerNames = 532786
    EventTimerSequence = 532787
    EventTimeOffset = 532788
    EventCodeSequence = 532789
    StartTrim = 532802
    StopTrim = 532803
    RecommendedDisplayFrameRate = 532804
    TransducerPosition = 532992
    TransducerOrientation = 532996
    AnatomicStructure = 533000
    AnatomicRegionSequence = 533016
    AnatomicRegionModifierSequence = 533024
    PrimaryAnatomicStructureSequence = 533032
    AnatomicStructureSpaceOrRegionSequence = 533033
    PrimaryAnatomicStructureModifierSequence = 533040
    TransducerPositionSequence = 533056
    TransducerPositionModifierSequence = 533058
    TransducerOrientationSequence = 533060
    TransducerOrientationModifierSequence = 533062
    AnatomicStructureSpaceOrRegionCodeSequenceTrial = 533073
    AnatomicPortalOfEntranceCodeSequenceTrial = 533075
    AnatomicApproachDirectionCodeSequenceTrial = 533077
    AnatomicPerspectiveDescriptionTrial = 533078
    AnatomicPerspectiveCodeSequenceTrial = 533079
    AnatomicLocationOfExaminingInstrumentDescriptionTrial = 533080
    AnatomicLocationOfExaminingInstrumentCodeSequenceTrial = 533081
    AnatomicStructureSpaceOrRegionModifierCodeSequenceTrial = 533082
    OnAxisBackgroundAnatomicStructureCodeSequenceTrial = 533084
    AlternateRepresentationSequence = 536577
    AvailableTransferSyntaxUID = 536578
    IrradiationEventUID = 536592
    SourceIrradiationEventSequence = 536593
    RadiopharmaceuticalAdministrationEventUID = 536594
    IdentifyingComments = 540672
    FrameType = 561159
    ReferencedImageEvidenceSequence = 561298
    ReferencedRawDataSequence = 561441
    CreatorVersionUID = 561443
    DerivationImageSequence = 561444
    SourceImageEvidenceSequence = 561492
    PixelPresentation = 561669
    VolumetricProperties = 561670
    VolumeBasedCalculationTechnique = 561671
    ComplexImageComponent = 561672
    AcquisitionContrast = 561673
    DerivationCodeSequence = 561685
    ReferencedPresentationStateSequence = 561719
    ReferencedOtherPlaneSequence = 562192
    FrameDisplaySequence = 562264
    RecommendedDisplayFrameRateInFloat = 562265
    SkipFrameRangeFlag = 562272
    PatientName = 1048592
    PatientID = 1048608
    IssuerOfPatientID = 1048609
    TypeOfPatientID = 1048610
    IssuerOfPatientIDQualifiersSequence = 1048612
    SourcePatientGroupIdentificationSequence = 1048614
    GroupOfPatientsIdentificationSequence = 1048615
    SubjectRelativePositionInImage = 1048616
    PatientBirthDate = 1048624
    PatientBirthTime = 1048626
    PatientBirthDateInAlternativeCalendar = 1048627
    PatientDeathDateInAlternativeCalendar = 1048628
    PatientAlternativeCalendar = 1048629
    PatientSex = 1048640
    PatientInsurancePlanCodeSequence = 1048656
    PatientPrimaryLanguageCodeSequence = 1048833
    PatientPrimaryLanguageModifierCodeSequence = 1048834
    QualityControlSubject = 1049088
    QualityControlSubjectTypeCodeSequence = 1049089
    StrainDescription = 1049106
    StrainNomenclature = 1049107
    StrainStockNumber = 1049108
    StrainSourceRegistryCodeSequence = 1049109
    StrainStockSequence = 1049110
    StrainSource = 1049111
    StrainAdditionalInformation = 1049112
    StrainCodeSequence = 1049113
    GeneticModificationsSequence = 1049121
    GeneticModificationsDescription = 1049122
    GeneticModificationsNomenclature = 1049123
    GeneticModificationsCodeSequence = 1049129
    OtherPatientIDs = 1052672
    OtherPatientNames = 1052673
    OtherPatientIDsSequence = 1052674
    PatientBirthName = 1052677
    PatientAge = 1052688
    PatientSize = 1052704
    PatientSizeCodeSequence = 1052705
    PatientBodyMassIndex = 1052706
    MeasuredAPDimension = 1052707
    MeasuredLateralDimension = 1052708
    PatientWeight = 1052720
    PatientAddress = 1052736
    InsurancePlanIdentification = 1052752
    PatientMotherBirthName = 1052768
    MilitaryRank = 1052800
    BranchOfService = 1052801
    MedicalRecordLocator = 1052816
    ReferencedPatientPhotoSequence = 1052928
    MedicalAlerts = 1056768
    Allergies = 1057040
    CountryOfResidence = 1057104
    RegionOfResidence = 1057106
    PatientTelephoneNumbers = 1057108
    PatientTelecomInformation = 1057109
    EthnicGroup = 1057120
    Occupation = 1057152
    SmokingStatus = 1057184
    AdditionalPatientHistory = 1057200
    PregnancyStatus = 1057216
    LastMenstrualDate = 1057232
    PatientReligiousPreference = 1057264
    PatientSpeciesDescription = 1057281
    PatientSpeciesCodeSequence = 1057282
    PatientSexNeutered = 1057283
    AnatomicalOrientationType = 1057296
    PatientBreedDescription = 1057426
    PatientBreedCodeSequence = 1057427
    BreedRegistrationSequence = 1057428
    BreedRegistrationNumber = 1057429
    BreedRegistryCodeSequence = 1057430
    ResponsiblePerson = 1057431
    ResponsiblePersonRole = 1057432
    ResponsibleOrganization = 1057433
    PatientComments = 1064960
    ExaminedBodyThickness = 1086513
    ClinicalTrialSponsorName = 1179664
    ClinicalTrialProtocolID = 1179680
    ClinicalTrialProtocolName = 1179681
    ClinicalTrialSiteID = 1179696
    ClinicalTrialSiteName = 1179697
    ClinicalTrialSubjectID = 1179712
    ClinicalTrialSubjectReadingID = 1179714
    ClinicalTrialTimePointID = 1179728
    ClinicalTrialTimePointDescription = 1179729
    LongitudinalTemporalOffsetFromEvent = 1179730
    LongitudinalTemporalEventType = 1179731
    ClinicalTrialCoordinatingCenterName = 1179744
    PatientIdentityRemoved = 1179746
    DeidentificationMethod = 1179747
    DeidentificationMethodCodeSequence = 1179748
    ClinicalTrialSeriesID = 1179761
    ClinicalTrialSeriesDescription = 1179762
    ClinicalTrialProtocolEthicsCommitteeName = 1179777
    ClinicalTrialProtocolEthicsCommitteeApprovalNumber = 1179778
    ConsentForClinicalTrialUseSequence = 1179779
    DistributionType = 1179780
    ConsentForDistributionFlag = 1179781
    EthicsCommitteeApprovalEffectivenessStartDate = 1179782
    EthicsCommitteeApprovalEffectivenessEndDate = 1179783
    CADFileFormat = 1310755
    ComponentReferenceSystem = 1310756
    ComponentManufacturingProcedure = 1310757
    ComponentManufacturer = 1310760
    MaterialThickness = 1310768
    MaterialPipeDiameter = 1310770
    MaterialIsolationDiameter = 1310772
    MaterialGrade = 1310786
    MaterialPropertiesDescription = 1310788
    MaterialPropertiesFileFormatRetired = 1310789
    MaterialNotes = 1310790
    ComponentShape = 1310800
    CurvatureType = 1310802
    OuterDiameter = 1310804
    InnerDiameter = 1310806
    ComponentWelderIDs = 1310976
    SecondaryApprovalStatus = 1310977
    SecondaryReviewDate = 1310978
    SecondaryReviewTime = 1310979
    SecondaryReviewerName = 1310980
    RepairID = 1310981
    MultipleComponentApprovalSequence = 1310982
    OtherApprovalStatus = 1310983
    OtherSecondaryApprovalStatus = 1310984
    ActualEnvironmentalConditions = 1314832
    ExpiryDate = 1314848
    EnvironmentalConditions = 1314880
    EvaluatorSequence = 1318914
    EvaluatorNumber = 1318916
    EvaluatorName = 1318918
    EvaluationAttempt = 1318920
    IndicationSequence = 1318930
    IndicationNumber = 1318932
    IndicationLabel = 1318934
    IndicationDescription = 1318936
    IndicationType = 1318938
    IndicationDisposition = 1318940
    IndicationROISequence = 1318942
    IndicationPhysicalPropertySequence = 1318960
    PropertyLabel = 1318962
    CoordinateSystemNumberOfAxes = 1319426
    CoordinateSystemAxesSequence = 1319428
    CoordinateSystemAxisDescription = 1319430
    CoordinateSystemDataSetMapping = 1319432
    CoordinateSystemAxisNumber = 1319434
    CoordinateSystemAxisType = 1319436
    CoordinateSystemAxisUnits = 1319438
    CoordinateSystemAxisValues = 1319440
    CoordinateSystemTransformSequence = 1319456
    TransformDescription = 1319458
    TransformNumberOfAxes = 1319460
    TransformOrderOfAxes = 1319462
    TransformedAxisUnits = 1319464
    CoordinateSystemTransformRotationAndScaleMatrix = 1319466
    CoordinateSystemTransformTranslationMatrix = 1319468
    InternalDetectorFrameTime = 1323025
    NumberOfFramesIntegrated = 1323026
    DetectorTemperatureSequence = 1323040
    SensorName = 1323042
    HorizontalOffsetOfSensor = 1323044
    VerticalOffsetOfSensor = 1323046
    SensorTemperature = 1323048
    DarkCurrentSequence = 1323072
    DarkCurrentCounts = 1323088
    GainCorrectionReferenceSequence = 1323104
    AirCounts = 1323120
    KVUsedInGainCalibration = 1323121
    MAUsedInGainCalibration = 1323122
    NumberOfFramesUsedForIntegration = 1323123
    FilterMaterialUsedInGainCalibration = 1323124
    FilterThicknessUsedInGainCalibration = 1323125
    DateOfGainCalibration = 1323126
    TimeOfGainCalibration = 1323127
    BadPixelImage = 1323136
    CalibrationNotes = 1323161
    LinearityCorrectionTechnique = 1323264
    BeamHardeningCorrectionTechnique = 1323265
    PulserEquipmentSequence = 1327106
    PulserType = 1327108
    PulserNotes = 1327110
    ReceiverEquipmentSequence = 1327112
    AmplifierType = 1327114
    ReceiverNotes = 1327116
    PreAmplifierEquipmentSequence = 1327118
    PreAmplifierNotes = 1327119
    TransmitTransducerSequence = 1327120
    ReceiveTransducerSequence = 1327121
    NumberOfElements = 1327122
    ElementShape = 1327123
    ElementDimensionA = 1327124
    ElementDimensionB = 1327125
    ElementPitchA = 1327126
    MeasuredBeamDimensionA = 1327127
    MeasuredBeamDimensionB = 1327128
    LocationOfMeasuredBeamDiameter = 1327129
    NominalFrequency = 1327130
    MeasuredCenterFrequency = 1327131
    MeasuredBandwidth = 1327132
    ElementPitchB = 1327133
    PulserSettingsSequence = 1327136
    PulseWidth = 1327138
    ExcitationFrequency = 1327140
    ModulationType = 1327142
    Damping = 1327144
    ReceiverSettingsSequence = 1327152
    AcquiredSoundpathLength = 1327153
    AcquisitionCompressionType = 1327154
    AcquisitionSampleSize = 1327155
    RectifierSmoothing = 1327156
    DACSequence = 1327157
    DACType = 1327158
    DACGainPoints = 1327160
    DACTimePoints = 1327162
    DACAmplitude = 1327164
    PreAmplifierSettingsSequence = 1327168
    TransmitTransducerSettingsSequence = 1327184
    ReceiveTransducerSettingsSequence = 1327185
    IncidentAngle = 1327186
    CouplingTechnique = 1327188
    CouplingMedium = 1327190
    CouplingVelocity = 1327191
    ProbeCenterLocationX = 1327192
    ProbeCenterLocationZ = 1327193
    SoundPathLength = 1327194
    DelayLawIdentifier = 1327196
    GateSettingsSequence = 1327200
    GateThreshold = 1327202
    VelocityOfSound = 1327204
    CalibrationSettingsSequence = 1327216
    CalibrationProcedure = 1327218
    ProcedureVersion = 1327220
    ProcedureCreationDate = 1327222
    ProcedureExpirationDate = 1327224
    ProcedureLastModifiedDate = 1327226
    CalibrationTime = 1327228
    CalibrationDate = 1327230
    ProbeDriveEquipmentSequence = 1327232
    DriveType = 1327233
    ProbeDriveNotes = 1327234
    DriveProbeSequence = 1327235
    ProbeInductance = 1327236
    ProbeResistance = 1327237
    ReceiveProbeSequence = 1327238
    ProbeDriveSettingsSequence = 1327239
    BridgeResistors = 1327240
    ProbeOrientationAngle = 1327241
    UserSelectedGainY = 1327243
    UserSelectedPhase = 1327244
    UserSelectedOffsetX = 1327245
    UserSelectedOffsetY = 1327246
    ChannelSettingsSequence = 1327249
    ChannelThreshold = 1327250
    ScannerSettingsSequence = 1327258
    ScanProcedure = 1327259
    TranslationRateX = 1327260
    TranslationRateY = 1327261
    ChannelOverlap = 1327263
    ImageQualityIndicatorType = 1327264
    ImageQualityIndicatorMaterial = 1327265
    ImageQualityIndicatorSize = 1327266
    LINACEnergy = 1331202
    LINACOutput = 1331204
    ActiveAperture = 1331456
    TotalAperture = 1331457
    ApertureElevation = 1331458
    MainLobeAngle = 1331459
    MainRoofAngle = 1331460
    ConnectorType = 1331461
    WedgeModelNumber = 1331462
    WedgeAngleFloat = 1331463
    WedgeRoofAngle = 1331464
    WedgeElement1Position = 1331465
    WedgeMaterialVelocity = 1331466
    WedgeMaterial = 1331467
    WedgeOffsetZ = 1331468
    WedgeOriginOffsetX = 1331469
    WedgeTimeDelay = 1331470
    WedgeName = 1331471
    WedgeManufacturerName = 1331472
    WedgeDescription = 1331473
    NominalBeamAngle = 1331474
    WedgeOffsetX = 1331475
    WedgeOffsetY = 1331476
    WedgeTotalLength = 1331477
    WedgeInContactLength = 1331478
    WedgeFrontGap = 1331479
    WedgeTotalHeight = 1331480
    WedgeFrontHeight = 1331481
    WedgeRearHeight = 1331482
    WedgeTotalWidth = 1331483
    WedgeInContactWidth = 1331484
    WedgeChamferHeight = 1331485
    WedgeCurve = 1331486
    RadiusAlongWedge = 1331487
    WhitePoint = 1441793
    PrimaryChromaticities = 1441794
    BatteryLevel = 1441795
    ExposureTimeInSeconds = 1441796
    FNumber = 1441797
    OECFRows = 1441798
    OECFColumns = 1441799
    OECFColumnNames = 1441800
    OECFValues = 1441801
    SpatialFrequencyResponseRows = 1441802
    SpatialFrequencyResponseColumns = 1441803
    SpatialFrequencyResponseColumnNames = 1441804
    SpatialFrequencyResponseValues = 1441805
    ColorFilterArrayPatternRows = 1441806
    ColorFilterArrayPatternColumns = 1441807
    ColorFilterArrayPatternValues = 1441808
    FlashFiringStatus = 1441809
    FlashReturnStatus = 1441810
    FlashMode = 1441811
    FlashFunctionPresent = 1441812
    FlashRedEyeMode = 1441813
    ExposureProgram = 1441814
    SpectralSensitivity = 1441815
    PhotographicSensitivity = 1441816
    SelfTimerMode = 1441817
    SensitivityType = 1441818
    StandardOutputSensitivity = 1441819
    RecommendedExposureIndex = 1441820
    ISOSpeed = 1441821
    ISOSpeedLatitudeyyy = 1441822
    ISOSpeedLatitudezzz = 1441823
    EXIFVersion = 1441824
    ShutterSpeedValue = 1441825
    ApertureValue = 1441826
    BrightnessValue = 1441827
    ExposureBiasValue = 1441828
    MaxApertureValue = 1441829
    SubjectDistance = 1441830
    MeteringMode = 1441831
    LightSource = 1441832
    FocalLength = 1441833
    SubjectArea = 1441834
    MakerNote = 1441835
    Temperature = 1441840
    Humidity = 1441841
    Pressure = 1441842
    WaterDepth = 1441843
    Acceleration = 1441844
    CameraElevationAngle = 1441845
    FlashEnergy = 1441846
    SubjectLocation = 1441847
    PhotographicExposureIndex = 1441848
    SensingMethod = 1441849
    FileSource = 1441850
    SceneType = 1441851
    CustomRendered = 1441857
    ExposureMode = 1441858
    WhiteBalance = 1441859
    DigitalZoomRatio = 1441860
    FocalLengthIn35mmFilm = 1441861
    SceneCaptureType = 1441862
    GainControl = 1441863
    Contrast = 1441864
    Saturation = 1441865
    Sharpness = 1441866
    DeviceSettingDescription = 1441867
    SubjectDistanceRange = 1441868
    CameraOwnerName = 1441869
    LensSpecification = 1441870
    LensMake = 1441871
    LensModel = 1441872
    LensSerialNumber = 1441873
    InteroperabilityIndex = 1441889
    InteroperabilityVersion = 1441890
    GPSVersionID = 1441904
    GPSLatitudeRef = 1441905
    GPSLatitude = 1441906
    GPSLongitudeRef = 1441907
    GPSLongitude = 1441908
    GPSAltitudeRef = 1441909
    GPSAltitude = 1441910
    GPSTimeStamp = 1441911
    GPSSatellites = 1441912
    GPSStatus = 1441913
    GPSMeasureMode = 1441914
    GPSDOP = 1441915
    GPSSpeedRef = 1441916
    GPSSpeed = 1441917
    GPSTrackRef = 1441918
    GPSTrack = 1441919
    GPSImgDirectionRef = 1441920
    GPSImgDirection = 1441921
    GPSMapDatum = 1441922
    GPSDestLatitudeRef = 1441923
    GPSDestLatitude = 1441924
    GPSDestLongitudeRef = 1441925
    GPSDestLongitude = 1441926
    GPSDestBearingRef = 1441927
    GPSDestBearing = 1441928
    GPSDestDistanceRef = 1441929
    GPSDestDistance = 1441930
    GPSProcessingMethod = 1441931
    GPSAreaInformation = 1441932
    GPSDateStamp = 1441933
    GPSDifferential = 1441934
    LightSourcePolarization = 1445889
    EmitterColorTemperature = 1445890
    ContactMethod = 1445891
    ImmersionMedia = 1445892
    OpticalMagnificationFactor = 1445893
    ContrastBolusAgent = 1572880
    ContrastBolusAgentSequence = 1572882
    ContrastBolusT1Relaxivity = 1572883
    ContrastBolusAdministrationRouteSequence = 1572884
    BodyPartExamined = 1572885
    ScanningSequence = 1572896
    SequenceVariant = 1572897
    ScanOptions = 1572898
    MRAcquisitionType = 1572899
    SequenceName = 1572900
    AngioFlag = 1572901
    InterventionDrugInformationSequence = 1572902
    InterventionDrugStopTime = 1572903
    InterventionDrugDose = 1572904
    InterventionDrugCodeSequence = 1572905
    AdditionalDrugSequence = 1572906
    Radionuclide = 1572912
    Radiopharmaceutical = 1572913
    EnergyWindowCenterline = 1572914
    EnergyWindowTotalWidth = 1572915
    InterventionDrugName = 1572916
    InterventionDrugStartTime = 1572917
    InterventionSequence = 1572918
    TherapyType = 1572919
    InterventionStatus = 1572920
    TherapyDescription = 1572921
    InterventionDescription = 1572922
    CineRate = 1572928
    InitialCineRunState = 1572930
    SliceThickness = 1572944
    KVP = 1572960
    CountsAccumulated = 1572976
    AcquisitionTerminationCondition = 1572977
    EffectiveDuration = 1572978
    AcquisitionStartCondition = 1572979
    AcquisitionStartConditionData = 1572980
    AcquisitionTerminationConditionData = 1572981
    RepetitionTime = 1572992
    EchoTime = 1572993
    InversionTime = 1572994
    NumberOfAverages = 1572995
    ImagingFrequency = 1572996
    ImagedNucleus = 1572997
    EchoNumbers = 1572998
    MagneticFieldStrength = 1572999
    SpacingBetweenSlices = 1573000
    NumberOfPhaseEncodingSteps = 1573001
    DataCollectionDiameter = 1573008
    EchoTrainLength = 1573009
    PercentSampling = 1573011
    PercentPhaseFieldOfView = 1573012
    PixelBandwidth = 1573013
    DeviceSerialNumber = 1576960
    DeviceUID = 1576962
    DeviceID = 1576963
    PlateID = 1576964
    GeneratorID = 1576965
    GridID = 1576966
    CassetteID = 1576967
    GantryID = 1576968
    UniqueDeviceIdentifier = 1576969
    UDISequence = 1576970
    ManufacturerDeviceClassUID = 1576971
    SecondaryCaptureDeviceID = 1576976
    HardcopyCreationDeviceID = 1576977
    DateOfSecondaryCapture = 1576978
    TimeOfSecondaryCapture = 1576980
    SecondaryCaptureDeviceManufacturer = 1576982
    HardcopyDeviceManufacturer = 1576983
    SecondaryCaptureDeviceManufacturerModelName = 1576984
    SecondaryCaptureDeviceSoftwareVersions = 1576985
    HardcopyDeviceSoftwareVersion = 1576986
    HardcopyDeviceManufacturerModelName = 1576987
    SoftwareVersions = 1576992
    VideoImageFormatAcquired = 1576994
    DigitalImageFormatAcquired = 1576995
    ProtocolName = 1577008
    ContrastBolusRoute = 1577024
    ContrastBolusVolume = 1577025
    ContrastBolusStartTime = 1577026
    ContrastBolusStopTime = 1577027
    ContrastBolusTotalDose = 1577028
    SyringeCounts = 1577029
    ContrastFlowRate = 1577030
    ContrastFlowDuration = 1577031
    ContrastBolusIngredient = 1577032
    ContrastBolusIngredientConcentration = 1577033
    SpatialResolution = 1577040
    TriggerTime = 1577056
    TriggerSourceOrType = 1577057
    NominalInterval = 1577058
    FrameTime = 1577059
    CardiacFramingType = 1577060
    FrameTimeVector = 1577061
    FrameDelay = 1577062
    ImageTriggerDelay = 1577063
    MultiplexGroupTimeOffset = 1577064
    TriggerTimeOffset = 1577065
    SynchronizationTrigger = 1577066
    SynchronizationChannel = 1577068
    TriggerSamplePosition = 1577070
    RadiopharmaceuticalRoute = 1577072
    RadiopharmaceuticalVolume = 1577073
    RadiopharmaceuticalStartTime = 1577074
    RadiopharmaceuticalStopTime = 1577075
    RadionuclideTotalDose = 1577076
    RadionuclideHalfLife = 1577077
    RadionuclidePositronFraction = 1577078
    RadiopharmaceuticalSpecificActivity = 1577079
    RadiopharmaceuticalStartDateTime = 1577080
    RadiopharmaceuticalStopDateTime = 1577081
    BeatRejectionFlag = 1577088
    LowRRValue = 1577089
    HighRRValue = 1577090
    IntervalsAcquired = 1577091
    IntervalsRejected = 1577092
    PVCRejection = 1577093
    SkipBeats = 1577094
    HeartRate = 1577096
    CardiacNumberOfImages = 1577104
    TriggerWindow = 1577108
    ReconstructionDiameter = 1577216
    DistanceSourceToDetector = 1577232
    DistanceSourceToPatient = 1577233
    EstimatedRadiographicMagnificationFactor = 1577236
    GantryDetectorTilt = 1577248
    GantryDetectorSlew = 1577249
    TableHeight = 1577264
    TableTraverse = 1577265
    TableMotion = 1577268
    TableVerticalIncrement = 1577269
    TableLateralIncrement = 1577270
    TableLongitudinalIncrement = 1577271
    TableAngle = 1577272
    TableType = 1577274
    RotationDirection = 1577280
    AngularPosition = 1577281
    RadialPosition = 1577282
    ScanArc = 1577283
    AngularStep = 1577284
    CenterOfRotationOffset = 1577285
    RotationOffset = 1577286
    FieldOfViewShape = 1577287
    FieldOfViewDimensions = 1577289
    ExposureTime = 1577296
    XRayTubeCurrent = 1577297
    Exposure = 1577298
    ExposureInuAs = 1577299
    AveragePulseWidth = 1577300
    RadiationSetting = 1577301
    RectificationType = 1577302
    RadiationMode = 1577306
    ImageAndFluoroscopyAreaDoseProduct = 1577310
    FilterType = 1577312
    TypeOfFilters = 1577313
    IntensifierSize = 1577314
    ImagerPixelSpacing = 1577316
    Grid = 1577318
    GeneratorPower = 1577328
    CollimatorGridName = 1577344
    CollimatorType = 1577345
    FocalDistance = 1577346
    XFocusCenter = 1577347
    YFocusCenter = 1577348
    FocalSpots = 1577360
    AnodeTargetMaterial = 1577361
    BodyPartThickness = 1577376
    CompressionForce = 1577378
    CompressionPressure = 1577379
    PaddleDescription = 1577380
    CompressionContactArea = 1577381
    AcquisitionMode = 1577392
    DoseModeName = 1577393
    AcquiredSubtractionMaskFlag = 1577394
    FluoroscopyPersistenceFlag = 1577395
    FluoroscopyLastImageHoldPersistenceFlag = 1577396
    UpperLimitNumberOfPersistentFluoroscopyFrames = 1577397
    ContrastBolusAutoInjectionTriggerFlag = 1577398
    ContrastBolusInjectionDelay = 1577399
    XAAcquisitionPhaseDetailsSequence = 1577400
    XAAcquisitionFrameRate = 1577401
    XAPlaneDetailsSequence = 1577402
    AcquisitionFieldOfViewLabel = 1577403
    XRayFilterDetailsSequence = 1577404
    XAAcquisitionDuration = 1577405
    ReconstructionPipelineType = 1577406
    ImageFilterDetailsSequence = 1577407
    AppliedMaskSubtractionFlag = 1577408
    RequestedSeriesDescriptionCodeSequence = 1577409
    DateOfLastCalibration = 1577472
    TimeOfLastCalibration = 1577473
    DateTimeOfLastCalibration = 1577474
    ConvolutionKernel = 1577488
    UpperLowerPixelValues = 1577536
    ActualFrameDuration = 1577538
    CountRate = 1577539
    PreferredPlaybackSequencing = 1577540
    ReceiveCoilName = 1577552
    TransmitCoilName = 1577553
    PlateType = 1577568
    PhosphorType = 1577569
    WaterEquivalentDiameter = 1577585
    WaterEquivalentDiameterCalculationMethodCodeSequence = 1577586
    ScanVelocity = 1577728
    WholeBodyTechnique = 1577729
    ScanLength = 1577730
    AcquisitionMatrix = 1577744
    InPlanePhaseEncodingDirection = 1577746
    FlipAngle = 1577748
    VariableFlipAngleFlag = 1577749
    SAR = 1577750
    dBdt = 1577752
    B1rms = 1577760
    AcquisitionDeviceProcessingDescription = 1577984
    AcquisitionDeviceProcessingCode = 1577985
    CassetteOrientation = 1577986
    CassetteSize = 1577987
    ExposuresOnPlate = 1577988
    RelativeXRayExposure = 1577989
    ExposureIndex = 1578001
    TargetExposureIndex = 1578002
    DeviationIndex = 1578003
    ColumnAngulation = 1578064
    TomoLayerHeight = 1578080
    TomoAngle = 1578096
    TomoTime = 1578112
    TomoType = 1578128
    TomoClass = 1578129
    NumberOfTomosynthesisSourceImages = 1578133
    PositionerMotion = 1578240
    PositionerType = 1578248
    PositionerPrimaryAngle = 1578256
    PositionerSecondaryAngle = 1578257
    PositionerPrimaryAngleIncrement = 1578272
    PositionerSecondaryAngleIncrement = 1578273
    DetectorPrimaryAngle = 1578288
    DetectorSecondaryAngle = 1578289
    ShutterShape = 1578496
    ShutterLeftVerticalEdge = 1578498
    ShutterRightVerticalEdge = 1578500
    ShutterUpperHorizontalEdge = 1578502
    ShutterLowerHorizontalEdge = 1578504
    CenterOfCircularShutter = 1578512
    RadiusOfCircularShutter = 1578514
    VerticesOfThePolygonalShutter = 1578528
    ShutterPresentationValue = 1578530
    ShutterOverlayGroup = 1578531
    ShutterPresentationColorCIELabValue = 1578532
    OutlineShapeType = 1578544
    OutlineLeftVerticalEdge = 1578545
    OutlineRightVerticalEdge = 1578546
    OutlineUpperHorizontalEdge = 1578547
    OutlineLowerHorizontalEdge = 1578548
    CenterOfCircularOutline = 1578549
    DiameterOfCircularOutline = 1578550
    NumberOfPolygonalVertices = 1578551
    VerticesOfThePolygonalOutline = 1578552
    CollimatorShape = 1578752
    CollimatorLeftVerticalEdge = 1578754
    CollimatorRightVerticalEdge = 1578756
    CollimatorUpperHorizontalEdge = 1578758
    CollimatorLowerHorizontalEdge = 1578760
    CenterOfCircularCollimator = 1578768
    RadiusOfCircularCollimator = 1578770
    VerticesOfThePolygonalCollimator = 1578784
    AcquisitionTimeSynchronized = 1579008
    TimeSource = 1579009
    TimeDistributionProtocol = 1579010
    NTPSourceAddress = 1579011
    PageNumberVector = 1581057
    FrameLabelVector = 1581058
    FramePrimaryAngleVector = 1581059
    FrameSecondaryAngleVector = 1581060
    SliceLocationVector = 1581061
    DisplayWindowLabelVector = 1581062
    NominalScannedPixelSpacing = 1581072
    DigitizingDeviceTransportDirection = 1581088
    RotationOfScannedFilm = 1581104
    BiopsyTargetSequence = 1581121
    TargetUID = 1581122
    LocalizingCursorPosition = 1581123
    CalculatedTargetPosition = 1581124
    TargetLabel = 1581125
    DisplayedZValue = 1581126
    IVUSAcquisition = 1585408
    IVUSPullbackRate = 1585409
    IVUSGatedRate = 1585410
    IVUSPullbackStartFrameNumber = 1585411
    IVUSPullbackStopFrameNumber = 1585412
    LesionNumber = 1585413
    AcquisitionComments = 1589248
    OutputPower = 1593344
    TransducerData = 1593360
    TransducerIdentificationSequence = 1593361
    FocusDepth = 1593362
    ProcessingFunction = 1593376
    PostprocessingFunction = 1593377
    MechanicalIndex = 1593378
    BoneThermalIndex = 1593380
    CranialThermalIndex = 1593382
    SoftTissueThermalIndex = 1593383
    SoftTissueFocusThermalIndex = 1593384
    SoftTissueSurfaceThermalIndex = 1593385
    DynamicRange = 1593392
    TotalGain = 1593408
    DepthOfScanField = 1593424
    PatientPosition = 1593600
    ViewPosition = 1593601
    ProjectionEponymousNameCodeSequence = 1593604
    ImageTransformationMatrix = 1593872
    ImageTranslationVector = 1593874
    Sensitivity = 1597440
    SequenceOfUltrasoundRegions = 1597457
    RegionSpatialFormat = 1597458
    RegionDataType = 1597460
    RegionFlags = 1597462
    RegionLocationMinX0 = 1597464
    RegionLocationMinY0 = 1597466
    RegionLocationMaxX1 = 1597468
    RegionLocationMaxY1 = 1597470
    ReferencePixelX0 = 1597472
    ReferencePixelY0 = 1597474
    PhysicalUnitsXDirection = 1597476
    PhysicalUnitsYDirection = 1597478
    ReferencePixelPhysicalValueX = 1597480
    ReferencePixelPhysicalValueY = 1597482
    PhysicalDeltaX = 1597484
    PhysicalDeltaY = 1597486
    TransducerFrequency = 1597488
    TransducerType = 1597489
    PulseRepetitionFrequency = 1597490
    DopplerCorrectionAngle = 1597492
    SteeringAngle = 1597494
    DopplerSampleVolumeXPositionRetired = 1597496
    DopplerSampleVolumeXPosition = 1597497
    DopplerSampleVolumeYPositionRetired = 1597498
    DopplerSampleVolumeYPosition = 1597499
    TMLinePositionX0Retired = 1597500
    TMLinePositionX0 = 1597501
    TMLinePositionY0Retired = 1597502
    TMLinePositionY0 = 1597503
    TMLinePositionX1Retired = 1597504
    TMLinePositionX1 = 1597505
    TMLinePositionY1Retired = 1597506
    TMLinePositionY1 = 1597507
    PixelComponentOrganization = 1597508
    PixelComponentMask = 1597510
    PixelComponentRangeStart = 1597512
    PixelComponentRangeStop = 1597514
    PixelComponentPhysicalUnits = 1597516
    PixelComponentDataType = 1597518
    NumberOfTableBreakPoints = 1597520
    TableOfXBreakPoints = 1597522
    TableOfYBreakPoints = 1597524
    NumberOfTableEntries = 1597526
    TableOfPixelValues = 1597528
    TableOfParameterValues = 1597530
    RWaveTimeVector = 1597536
    ActiveImageAreaOverlayGroup = 1597552
    DetectorConditionsNominalFlag = 1601536
    DetectorTemperature = 1601537
    DetectorType = 1601540
    DetectorConfiguration = 1601541
    DetectorDescription = 1601542
    DetectorMode = 1601544
    DetectorID = 1601546
    DateOfLastDetectorCalibration = 1601548
    TimeOfLastDetectorCalibration = 1601550
    ExposuresOnDetectorSinceLastCalibration = 1601552
    ExposuresOnDetectorSinceManufactured = 1601553
    DetectorTimeSinceLastExposure = 1601554
    DetectorActiveTime = 1601556
    DetectorActivationOffsetFromExposure = 1601558
    DetectorBinning = 1601562
    DetectorElementPhysicalSize = 1601568
    DetectorElementSpacing = 1601570
    DetectorActiveShape = 1601572
    DetectorActiveDimensions = 1601574
    DetectorActiveOrigin = 1601576
    DetectorManufacturerName = 1601578
    DetectorManufacturerModelName = 1601579
    FieldOfViewOrigin = 1601584
    FieldOfViewRotation = 1601586
    FieldOfViewHorizontalFlip = 1601588
    PixelDataAreaOriginRelativeToFOV = 1601590
    PixelDataAreaRotationAngleRelativeToFOV = 1601592
    GridAbsorbingMaterial = 1601600
    GridSpacingMaterial = 1601601
    GridThickness = 1601602
    GridPitch = 1601604
    GridAspectRatio = 1601606
    GridPeriod = 1601608
    GridFocalDistance = 1601612
    FilterMaterial = 1601616
    FilterThicknessMinimum = 1601618
    FilterThicknessMaximum = 1601620
    FilterBeamPathLengthMinimum = 1601622
    FilterBeamPathLengthMaximum = 1601624
    ExposureControlMode = 1601632
    ExposureControlModeDescription = 1601634
    ExposureStatus = 1601636
    PhototimerSetting = 1601637
    ExposureTimeInuS = 1605968
    XRayTubeCurrentInuA = 1605969
    ContentQualification = 1609732
    PulseSequenceName = 1609733
    MRImagingModifierSequence = 1609734
    EchoPulseSequence = 1609736
    InversionRecovery = 1609737
    FlowCompensation = 1609744
    MultipleSpinEcho = 1609745
    MultiPlanarExcitation = 1609746
    PhaseContrast = 1609748
    TimeOfFlightContrast = 1609749
    Spoiling = 1609750
    SteadyStatePulseSequence = 1609751
    EchoPlanarPulseSequence = 1609752
    TagAngleFirstAxis = 1609753
    MagnetizationTransfer = 1609760
    T2Preparation = 1609761
    BloodSignalNulling = 1609762
    SaturationRecovery = 1609764
    SpectrallySelectedSuppression = 1609765
    SpectrallySelectedExcitation = 1609766
    SpatialPresaturation = 1609767
    Tagging = 1609768
    OversamplingPhase = 1609769
    TagSpacingFirstDimension = 1609776
    GeometryOfKSpaceTraversal = 1609778
    SegmentedKSpaceTraversal = 1609779
    RectilinearPhaseEncodeReordering = 1609780
    TagThickness = 1609781
    PartialFourierDirection = 1609782
    CardiacSynchronizationTechnique = 1609783
    ReceiveCoilManufacturerName = 1609793
    MRReceiveCoilSequence = 1609794
    ReceiveCoilType = 1609795
    QuadratureReceiveCoil = 1609796
    MultiCoilDefinitionSequence = 1609797
    MultiCoilConfiguration = 1609798
    MultiCoilElementName = 1609799
    MultiCoilElementUsed = 1609800
    MRTransmitCoilSequence = 1609801
    TransmitCoilManufacturerName = 1609808
    TransmitCoilType = 1609809
    SpectralWidth = 1609810
    ChemicalShiftReference = 1609811
    VolumeLocalizationTechnique = 1609812
    MRAcquisitionFrequencyEncodingSteps = 1609816
    Decoupling = 1609817
    DecoupledNucleus = 1609824
    DecouplingFrequency = 1609825
    DecouplingMethod = 1609826
    DecouplingChemicalShiftReference = 1609827
    KSpaceFiltering = 1609828
    TimeDomainFiltering = 1609829
    NumberOfZeroFills = 1609830
    BaselineCorrection = 1609831
    ParallelReductionFactorInPlane = 1609833
    CardiacRRIntervalSpecified = 1609840
    AcquisitionDuration = 1609843
    FrameAcquisitionDateTime = 1609844
    DiffusionDirectionality = 1609845
    DiffusionGradientDirectionSequence = 1609846
    ParallelAcquisition = 1609847
    ParallelAcquisitionTechnique = 1609848
    InversionTimes = 1609849
    MetaboliteMapDescription = 1609856
    PartialFourier = 1609857
    EffectiveEchoTime = 1609858
    MetaboliteMapCodeSequence = 1609859
    ChemicalShiftSequence = 1609860
    CardiacSignalSource = 1609861
    DiffusionBValue = 1609863
    DiffusionGradientOrientation = 1609865
    VelocityEncodingDirection = 1609872
    VelocityEncodingMinimumValue = 1609873
    VelocityEncodingAcquisitionSequence = 1609874
    NumberOfKSpaceTrajectories = 1609875
    CoverageOfKSpace = 1609876
    SpectroscopyAcquisitionPhaseRows = 1609877
    ParallelReductionFactorInPlaneRetired = 1609878
    TransmitterFrequency = 1609880
    ResonantNucleus = 1609984
    FrequencyCorrection = 1609985
    MRSpectroscopyFOVGeometrySequence = 1609987
    SlabThickness = 1609988
    SlabOrientation = 1609989
    MidSlabPosition = 1609990
    MRSpatialSaturationSequence = 1609991
    MRTimingAndRelatedParametersSequence = 1610002
    MREchoSequence = 1610004
    MRModifierSequence = 1610005
    MRDiffusionSequence = 1610007
    CardiacSynchronizationSequence = 1610008
    MRAveragesSequence = 1610009
    MRFOVGeometrySequence = 1610021
    VolumeLocalizationSequence = 1610022
    SpectroscopyAcquisitionDataColumns = 1610023
    DiffusionAnisotropyType = 1610055
    FrameReferenceDateTime = 1610065
    MRMetaboliteMapSequence = 1610066
    ParallelReductionFactorOutOfPlane = 1610069
    SpectroscopyAcquisitionOutOfPlanePhaseSteps = 1610073
    BulkMotionStatus = 1610086
    ParallelReductionFactorSecondInPlane = 1610088
    CardiacBeatRejectionTechnique = 1610089
    RespiratoryMotionCompensationTechnique = 1610096
    RespiratorySignalSource = 1610097
    BulkMotionCompensationTechnique = 1610098
    BulkMotionSignalSource = 1610099
    ApplicableSafetyStandardAgency = 1610100
    ApplicableSafetyStandardDescription = 1610101
    OperatingModeSequence = 1610102
    OperatingModeType = 1610103
    OperatingMode = 1610104
    SpecificAbsorptionRateDefinition = 1610105
    GradientOutputType = 1610112
    SpecificAbsorptionRateValue = 1610113
    GradientOutput = 1610114
    FlowCompensationDirection = 1610115
    TaggingDelay = 1610116
    RespiratoryMotionCompensationTechniqueDescription = 1610117
    RespiratorySignalSourceID = 1610118
    ChemicalShiftMinimumIntegrationLimitInHz = 1610133
    ChemicalShiftMaximumIntegrationLimitInHz = 1610134
    MRVelocityEncodingSequence = 1610135
    FirstOrderPhaseCorrection = 1610136
    WaterReferencedPhaseCorrection = 1610137
    MRSpectroscopyAcquisitionType = 1610240
    RespiratoryCyclePosition = 1610260
    VelocityEncodingMaximumValue = 1610263
    TagSpacingSecondDimension = 1610264
    TagAngleSecondAxis = 1610265
    FrameAcquisitionDuration = 1610272
    MRImageFrameTypeSequence = 1610278
    MRSpectroscopyFrameTypeSequence = 1610279
    MRAcquisitionPhaseEncodingStepsInPlane = 1610289
    MRAcquisitionPhaseEncodingStepsOutOfPlane = 1610290
    SpectroscopyAcquisitionPhaseColumns = 1610292
    CardiacCyclePosition = 1610294
    SpecificAbsorptionRateSequence = 1610297
    RFEchoTrainLength = 1610304
    GradientEchoTrainLength = 1610305
    ArterialSpinLabelingContrast = 1610320
    MRArterialSpinLabelingSequence = 1610321
    ASLTechniqueDescription = 1610322
    ASLSlabNumber = 1610323
    ASLSlabThickness = 1610324
    ASLSlabOrientation = 1610325
    ASLMidSlabPosition = 1610326
    ASLContext = 1610327
    ASLPulseTrainDuration = 1610328
    ASLCrusherFlag = 1610329
    ASLCrusherFlowLimit = 1610330
    ASLCrusherDescription = 1610331
    ASLBolusCutoffFlag = 1610332
    ASLBolusCutoffTimingSequence = 1610333
    ASLBolusCutoffTechnique = 1610334
    ASLBolusCutoffDelayTime = 1610335
    ASLSlabSequence = 1610336
    ChemicalShiftMinimumIntegrationLimitInppm = 1610389
    ChemicalShiftMaximumIntegrationLimitInppm = 1610390
    WaterReferenceAcquisition = 1610391
    EchoPeakPosition = 1610392
    CTAcquisitionTypeSequence = 1610497
    AcquisitionType = 1610498
    TubeAngle = 1610499
    CTAcquisitionDetailsSequence = 1610500
    RevolutionTime = 1610501
    SingleCollimationWidth = 1610502
    TotalCollimationWidth = 1610503
    CTTableDynamicsSequence = 1610504
    TableSpeed = 1610505
    TableFeedPerRotation = 1610512
    SpiralPitchFactor = 1610513
    CTGeometrySequence = 1610514
    DataCollectionCenterPatient = 1610515
    CTReconstructionSequence = 1610516
    ReconstructionAlgorithm = 1610517
    ConvolutionKernelGroup = 1610518
    ReconstructionFieldOfView = 1610519
    ReconstructionTargetCenterPatient = 1610520
    ReconstructionAngle = 1610521
    ImageFilter = 1610528
    CTExposureSequence = 1610529
    ReconstructionPixelSpacing = 1610530
    ExposureModulationType = 1610531
    EstimatedDoseSaving = 1610532
    CTXRayDetailsSequence = 1610533
    CTPositionSequence = 1610534
    TablePosition = 1610535
    ExposureTimeInms = 1610536
    CTImageFrameTypeSequence = 1610537
    XRayTubeCurrentInmA = 1610544
    ExposureInmAs = 1610546
    ConstantVolumeFlag = 1610547
    FluoroscopyFlag = 1610548
    DistanceSourceToDataCollectionCenter = 1610549
    ContrastBolusAgentNumber = 1610551
    ContrastBolusIngredientCodeSequence = 1610552
    ContrastAdministrationProfileSequence = 1610560
    ContrastBolusUsageSequence = 1610561
    ContrastBolusAgentAdministered = 1610562
    ContrastBolusAgentDetected = 1610563
    ContrastBolusAgentPhase = 1610564
    CTDIvol = 1610565
    CTDIPhantomTypeCodeSequence = 1610566
    CalciumScoringMassFactorPatient = 1610577
    CalciumScoringMassFactorDevice = 1610578
    EnergyWeightingFactor = 1610579
    CTAdditionalXRaySourceSequence = 1610592
    MultienergyCTAcquisition = 1610593
    MultienergyCTAcquisitionSequence = 1610594
    MultienergyCTProcessingSequence = 1610595
    MultienergyCTCharacteristicsSequence = 1610596
    MultienergyCTXRaySourceSequence = 1610597
    XRaySourceIndex = 1610598
    XRaySourceID = 1610599
    MultienergySourceTechnique = 1610600
    SourceStartDateTime = 1610601
    SourceEndDateTime = 1610602
    SwitchingPhaseNumber = 1610603
    SwitchingPhaseNominalDuration = 1610604
    SwitchingPhaseTransitionDuration = 1610605
    EffectiveBinEnergy = 1610606
    MultienergyCTXRayDetectorSequence = 1610607
    XRayDetectorIndex = 1610608
    XRayDetectorID = 1610609
    MultienergyDetectorType = 1610610
    XRayDetectorLabel = 1610611
    NominalMaxEnergy = 1610612
    NominalMinEnergy = 1610613
    ReferencedXRayDetectorIndex = 1610614
    ReferencedXRaySourceIndex = 1610615
    ReferencedPathIndex = 1610616
    MultienergyCTPathSequence = 1610617
    MultienergyCTPathIndex = 1610618
    MultienergyAcquisitionDescription = 1610619
    MonoenergeticEnergyEquivalent = 1610620
    MaterialCodeSequence = 1610621
    DecompositionMethod = 1610622
    DecompositionDescription = 1610623
    DecompositionAlgorithmIdentificationSequence = 1610624
    DecompositionMaterialSequence = 1610625
    MaterialAttenuationSequence = 1610626
    PhotonEnergy = 1610627
    XRayMassAttenuationCoefficient = 1610628
    ProjectionPixelCalibrationSequence = 1610753
    DistanceSourceToIsocenter = 1610754
    DistanceObjectToTableTop = 1610755
    ObjectPixelSpacingInCenterOfBeam = 1610756
    PositionerPositionSequence = 1610757
    TablePositionSequence = 1610758
    CollimatorShapeSequence = 1610759
    PlanesInAcquisition = 1610768
    XAXRFFrameCharacteristicsSequence = 1610770
    FrameAcquisitionSequence = 1610775
    XRayReceptorType = 1610784
    AcquisitionProtocolName = 1610787
    AcquisitionProtocolDescription = 1610788
    ContrastBolusIngredientOpaque = 1610789
    DistanceReceptorPlaneToDetectorHousing = 1610790
    IntensifierActiveShape = 1610791
    IntensifierActiveDimensions = 1610792
    PhysicalDetectorSize = 1610793
    PositionOfIsocenterProjection = 1610800
    FieldOfViewSequence = 1610802
    FieldOfViewDescription = 1610803
    ExposureControlSensingRegionsSequence = 1610804
    ExposureControlSensingRegionShape = 1610805
    ExposureControlSensingRegionLeftVerticalEdge = 1610806
    ExposureControlSensingRegionRightVerticalEdge = 1610807
    ExposureControlSensingRegionUpperHorizontalEdge = 1610808
    ExposureControlSensingRegionLowerHorizontalEdge = 1610809
    CenterOfCircularExposureControlSensingRegion = 1610816
    RadiusOfCircularExposureControlSensingRegion = 1610817
    VerticesOfThePolygonalExposureControlSensingRegion = 1610818
    ColumnAngulationPatient = 1610823
    BeamAngle = 1610825
    FrameDetectorParametersSequence = 1610833
    CalculatedAnatomyThickness = 1610834
    CalibrationSequence = 1610837
    ObjectThicknessSequence = 1610838
    PlaneIdentification = 1610839
    FieldOfViewDimensionsInFloat = 1610849
    IsocenterReferenceSystemSequence = 1610850
    PositionerIsocenterPrimaryAngle = 1610851
    PositionerIsocenterSecondaryAngle = 1610852
    PositionerIsocenterDetectorRotationAngle = 1610853
    TableXPositionToIsocenter = 1610854
    TableYPositionToIsocenter = 1610855
    TableZPositionToIsocenter = 1610856
    TableHorizontalRotationAngle = 1610857
    TableHeadTiltAngle = 1610864
    TableCradleTiltAngle = 1610865
    FrameDisplayShutterSequence = 1610866
    AcquiredImageAreaDoseProduct = 1610867
    CArmPositionerTabletopRelationship = 1610868
    XRayGeometrySequence = 1610870
    IrradiationEventIdentificationSequence = 1610871
    XRay3DFrameTypeSequence = 1611012
    ContributingSourcesSequence = 1611014
    XRay3DAcquisitionSequence = 1611015
    PrimaryPositionerScanArc = 1611016
    SecondaryPositionerScanArc = 1611017
    PrimaryPositionerScanStartAngle = 1611024
    SecondaryPositionerScanStartAngle = 1611025
    PrimaryPositionerIncrement = 1611028
    SecondaryPositionerIncrement = 1611029
    StartAcquisitionDateTime = 1611030
    EndAcquisitionDateTime = 1611031
    PrimaryPositionerIncrementSign = 1611032
    SecondaryPositionerIncrementSign = 1611033
    ApplicationName = 1611044
    ApplicationVersion = 1611045
    ApplicationManufacturer = 1611046
    AlgorithmType = 1611047
    AlgorithmDescription = 1611048
    XRay3DReconstructionSequence = 1611056
    ReconstructionDescription = 1611057
    PerProjectionAcquisitionSequence = 1611064
    DetectorPositionSequence = 1611073
    XRayAcquisitionDoseSequence = 1611074
    XRaySourceIsocenterPrimaryAngle = 1611075
    XRaySourceIsocenterSecondaryAngle = 1611076
    BreastSupportIsocenterPrimaryAngle = 1611077
    BreastSupportIsocenterSecondaryAngle = 1611078
    BreastSupportXPositionToIsocenter = 1611079
    BreastSupportYPositionToIsocenter = 1611080
    BreastSupportZPositionToIsocenter = 1611081
    DetectorIsocenterPrimaryAngle = 1611088
    DetectorIsocenterSecondaryAngle = 1611089
    DetectorXPositionToIsocenter = 1611090
    DetectorYPositionToIsocenter = 1611091
    DetectorZPositionToIsocenter = 1611092
    XRayGridSequence = 1611093
    XRayFilterSequence = 1611094
    DetectorActiveAreaTLHCPosition = 1611095
    DetectorActiveAreaOrientation = 1611096
    PositionerPrimaryAngleDirection = 1611097
    DiffusionBMatrixSequence = 1611265
    DiffusionBValueXX = 1611266
    DiffusionBValueXY = 1611267
    DiffusionBValueXZ = 1611268
    DiffusionBValueYY = 1611269
    DiffusionBValueYZ = 1611270
    DiffusionBValueZZ = 1611271
    FunctionalMRSequence = 1611297
    FunctionalSettlingPhaseFramesPresent = 1611298
    FunctionalSyncPulse = 1611299
    SettlingPhaseFrame = 1611300
    DecayCorrectionDateTime = 1611521
    StartDensityThreshold = 1611541
    StartRelativeDensityDifferenceThreshold = 1611542
    StartCardiacTriggerCountThreshold = 1611543
    StartRespiratoryTriggerCountThreshold = 1611544
    TerminationCountsThreshold = 1611545
    TerminationDensityThreshold = 1611552
    TerminationRelativeDensityThreshold = 1611553
    TerminationTimeThreshold = 1611554
    TerminationCardiacTriggerCountThreshold = 1611555
    TerminationRespiratoryTriggerCountThreshold = 1611556
    DetectorGeometry = 1611557
    TransverseDetectorSeparation = 1611558
    AxialDetectorDimension = 1611559
    RadiopharmaceuticalAgentNumber = 1611561
    PETFrameAcquisitionSequence = 1611570
    PETDetectorMotionDetailsSequence = 1611571
    PETTableDynamicsSequence = 1611572
    PETPositionSequence = 1611573
    PETFrameCorrectionFactorsSequence = 1611574
    RadiopharmaceuticalUsageSequence = 1611575
    AttenuationCorrectionSource = 1611576
    NumberOfIterations = 1611577
    NumberOfSubsets = 1611584
    PETReconstructionSequence = 1611593
    PETFrameTypeSequence = 1611601
    TimeOfFlightInformationUsed = 1611605
    ReconstructionType = 1611606
    DecayCorrected = 1611608
    AttenuationCorrected = 1611609
    ScatterCorrected = 1611616
    DeadTimeCorrected = 1611617
    GantryMotionCorrected = 1611618
    PatientMotionCorrected = 1611619
    CountLossNormalizationCorrected = 1611620
    RandomsCorrected = 1611621
    NonUniformRadialSamplingCorrected = 1611622
    SensitivityCalibrated = 1611623
    DetectorNormalizationCorrection = 1611624
    IterativeReconstructionMethod = 1611625
    AttenuationCorrectionTemporalRelationship = 1611632
    PatientPhysiologicalStateSequence = 1611633
    PatientPhysiologicalStateCodeSequence = 1611634
    DepthsOfFocus = 1611777
    ExcludedIntervalsSequence = 1611779
    ExclusionStartDateTime = 1611780
    ExclusionDuration = 1611781
    USImageDescriptionSequence = 1611782
    ImageDataTypeSequence = 1611783
    DataType = 1611784
    TransducerScanPatternCodeSequence = 1611785
    AliasedDataType = 1611787
    PositionMeasuringDeviceUsed = 1611788
    TransducerGeometryCodeSequence = 1611789
    TransducerBeamSteeringCodeSequence = 1611790
    TransducerApplicationCodeSequence = 1611791
    ZeroVelocityPixelValue = 1611792
    ReferenceLocationLabel = 1612032
    ReferenceLocationDescription = 1612033
    ReferenceBasisCodeSequence = 1612034
    ReferenceGeometryCodeSequence = 1612035
    OffsetDistance = 1612036
    OffsetDirection = 1612037
    PotentialScheduledProtocolCodeSequence = 1612038
    PotentialRequestedProcedureCodeSequence = 1612039
    PotentialReasonsForProcedure = 1612040
    PotentialReasonsForProcedureCodeSequence = 1612041
    PotentialDiagnosticTasks = 1612042
    ContraindicationsCodeSequence = 1612043
    ReferencedDefinedProtocolSequence = 1612044
    ReferencedPerformedProtocolSequence = 1612045
    PredecessorProtocolSequence = 1612046
    ProtocolPlanningInformation = 1612047
    ProtocolDesignRationale = 1612048
    PatientSpecificationSequence = 1612049
    ModelSpecificationSequence = 1612050
    ParametersSpecificationSequence = 1612051
    InstructionSequence = 1612052
    InstructionIndex = 1612053
    InstructionText = 1612054
    InstructionDescription = 1612055
    InstructionPerformedFlag = 1612056
    InstructionPerformedDateTime = 1612057
    InstructionPerformanceComment = 1612058
    PatientPositioningInstructionSequence = 1612059
    PositioningMethodCodeSequence = 1612060
    PositioningLandmarkSequence = 1612061
    TargetFrameOfReferenceUID = 1612062
    AcquisitionProtocolElementSpecificationSequence = 1612063
    AcquisitionProtocolElementSequence = 1612064
    ProtocolElementNumber = 1612065
    ProtocolElementName = 1612066
    ProtocolElementCharacteristicsSummary = 1612067
    ProtocolElementPurpose = 1612068
    AcquisitionMotion = 1612080
    AcquisitionStartLocationSequence = 1612081
    AcquisitionEndLocationSequence = 1612082
    ReconstructionProtocolElementSpecificationSequence = 1612083
    ReconstructionProtocolElementSequence = 1612084
    StorageProtocolElementSpecificationSequence = 1612085
    StorageProtocolElementSequence = 1612086
    RequestedSeriesDescription = 1612087
    SourceAcquisitionProtocolElementNumber = 1612088
    SourceAcquisitionBeamNumber = 1612089
    SourceReconstructionProtocolElementNumber = 1612090
    ReconstructionStartLocationSequence = 1612091
    ReconstructionEndLocationSequence = 1612092
    ReconstructionAlgorithmSequence = 1612093
    ReconstructionTargetCenterLocationSequence = 1612094
    ImageFilterDescription = 1612097
    CTDIvolNotificationTrigger = 1612098
    DLPNotificationTrigger = 1612099
    AutoKVPSelectionType = 1612100
    AutoKVPUpperBound = 1612101
    AutoKVPLowerBound = 1612102
    ProtocolDefinedPatientPosition = 1612103
    ContributingEquipmentSequence = 1613825
    ContributionDateTime = 1613826
    ContributionDescription = 1613827
    StudyInstanceUID = 2097165
    SeriesInstanceUID = 2097166
    StudyID = 2097168
    SeriesNumber = 2097169
    AcquisitionNumber = 2097170
    InstanceNumber = 2097171
    IsotopeNumber = 2097172
    PhaseNumber = 2097173
    IntervalNumber = 2097174
    TimeSlotNumber = 2097175
    AngleNumber = 2097176
    ItemNumber = 2097177
    PatientOrientation = 2097184
    OverlayNumber = 2097186
    CurveNumber = 2097188
    LUTNumber = 2097190
    ImagePosition = 2097200
    ImagePositionPatient = 2097202
    ImageOrientation = 2097205
    ImageOrientationPatient = 2097207
    Location = 2097232
    FrameOfReferenceUID = 2097234
    Laterality = 2097248
    ImageLaterality = 2097250
    ImageGeometryType = 2097264
    MaskingImage = 2097280
    ReportNumber = 2097322
    TemporalPositionIdentifier = 2097408
    NumberOfTemporalPositions = 2097413
    TemporalResolution = 2097424
    SynchronizationFrameOfReferenceUID = 2097664
    SOPInstanceUIDOfConcatenationSource = 2097730
    SeriesInStudy = 2101248
    AcquisitionsInSeries = 2101249
    ImagesInAcquisition = 2101250
    ImagesInSeries = 2101251
    AcquisitionsInStudy = 2101252
    ImagesInStudy = 2101253
    Reference = 2101280
    TargetPositionReferenceIndicator = 2101311
    PositionReferenceIndicator = 2101312
    SliceLocation = 2101313
    OtherStudyNumbers = 2101360
    NumberOfPatientRelatedStudies = 2101760
    NumberOfPatientRelatedSeries = 2101762
    NumberOfPatientRelatedInstances = 2101764
    NumberOfStudyRelatedSeries = 2101766
    NumberOfStudyRelatedInstances = 2101768
    NumberOfSeriesRelatedInstances = 2101769
    ModifyingDeviceID = 2110465
    ModifiedImageID = 2110466
    ModifiedImageDate = 2110467
    ModifyingDeviceManufacturer = 2110468
    ModifiedImageTime = 2110469
    ModifiedImageDescription = 2110470
    ImageComments = 2113536
    OriginalImageIdentification = 2117632
    OriginalImageIdentificationNomenclature = 2117634
    StackID = 2134102
    InStackPositionNumber = 2134103
    FrameAnatomySequence = 2134129
    FrameLaterality = 2134130
    FrameContentSequence = 2134289
    PlanePositionSequence = 2134291
    PlaneOrientationSequence = 2134294
    TemporalPositionIndex = 2134312
    NominalCardiacTriggerDelayTime = 2134355
    NominalCardiacTriggerTimePriorToRPeak = 2134356
    ActualCardiacTriggerTimePriorToRPeak = 2134357
    FrameAcquisitionNumber = 2134358
    DimensionIndexValues = 2134359
    FrameComments = 2134360
    ConcatenationUID = 2134369
    InConcatenationNumber = 2134370
    InConcatenationTotalNumber = 2134371
    DimensionOrganizationUID = 2134372
    DimensionIndexPointer = 2134373
    FunctionalGroupPointer = 2134375
    UnassignedSharedConvertedAttributesSequence = 2134384
    UnassignedPerFrameConvertedAttributesSequence = 2134385
    ConversionSourceAttributesSequence = 2134386
    DimensionIndexPrivateCreator = 2134547
    DimensionOrganizationSequence = 2134561
    DimensionIndexSequence = 2134562
    ConcatenationFrameOffsetNumber = 2134568
    FunctionalGroupPrivateCreator = 2134584
    NominalPercentageOfCardiacPhase = 2134593
    NominalPercentageOfRespiratoryPhase = 2134597
    StartingRespiratoryAmplitude = 2134598
    StartingRespiratoryPhase = 2134599
    EndingRespiratoryAmplitude = 2134600
    EndingRespiratoryPhase = 2134601
    RespiratoryTriggerType = 2134608
    RRIntervalTimeNominal = 2134609
    ActualCardiacTriggerDelayTime = 2134610
    RespiratorySynchronizationSequence = 2134611
    RespiratoryIntervalTime = 2134612
    NominalRespiratoryTriggerDelayTime = 2134613
    RespiratoryTriggerDelayThreshold = 2134614
    ActualRespiratoryTriggerDelayTime = 2134615
    ImagePositionVolume = 2134785
    ImageOrientationVolume = 2134786
    UltrasoundAcquisitionGeometry = 2134791
    ApexPosition = 2134792
    VolumeToTransducerMappingMatrix = 2134793
    VolumeToTableMappingMatrix = 2134794
    VolumeToTransducerRelationship = 2134795
    PatientFrameOfReferenceSource = 2134796
    TemporalPositionTimeOffset = 2134797
    PlanePositionVolumeSequence = 2134798
    PlaneOrientationVolumeSequence = 2134799
    TemporalPositionSequence = 2134800
    DimensionOrganizationType = 2134801
    VolumeFrameOfReferenceUID = 2134802
    TableFrameOfReferenceUID = 2134803
    DimensionDescriptionLabel = 2135073
    PatientOrientationInFrameSequence = 2135120
    FrameLabel = 2135123
    AcquisitionIndex = 2135320
    ContributingSOPInstancesReferenceSequence = 2135337
    ReconstructionIndex = 2135350
    LightPathFilterPassThroughWavelength = 2228225
    LightPathFilterPassBand = 2228226
    ImagePathFilterPassThroughWavelength = 2228227
    ImagePathFilterPassBand = 2228228
    PatientEyeMovementCommanded = 2228229
    PatientEyeMovementCommandCodeSequence = 2228230
    SphericalLensPower = 2228231
    CylinderLensPower = 2228232
    CylinderAxis = 2228233
    EmmetropicMagnification = 2228234
    IntraOcularPressure = 2228235
    HorizontalFieldOfView = 2228236
    PupilDilated = 2228237
    DegreeOfDilation = 2228238
    StereoBaselineAngle = 2228240
    StereoBaselineDisplacement = 2228241
    StereoHorizontalPixelOffset = 2228242
    StereoVerticalPixelOffset = 2228243
    StereoRotation = 2228244
    AcquisitionDeviceTypeCodeSequence = 2228245
    IlluminationTypeCodeSequence = 2228246
    LightPathFilterTypeStackCodeSequence = 2228247
    ImagePathFilterTypeStackCodeSequence = 2228248
    LensesCodeSequence = 2228249
    ChannelDescriptionCodeSequence = 2228250
    RefractiveStateSequence = 2228251
    MydriaticAgentCodeSequence = 2228252
    RelativeImagePositionCodeSequence = 2228253
    CameraAngleOfView = 2228254
    StereoPairsSequence = 2228256
    LeftImageSequence = 2228257
    RightImageSequence = 2228258
    StereoPairsPresent = 2228264
    AxialLengthOfTheEye = 2228272
    OphthalmicFrameLocationSequence = 2228273
    ReferenceCoordinates = 2228274
    DepthSpatialResolution = 2228277
    MaximumDepthDistortion = 2228278
    AlongScanSpatialResolution = 2228279
    MaximumAlongScanDistortion = 2228280
    OphthalmicImageOrientation = 2228281
    DepthOfTransverseImage = 2228289
    MydriaticAgentConcentrationUnitsSequence = 2228290
    AcrossScanSpatialResolution = 2228296
    MaximumAcrossScanDistortion = 2228297
    MydriaticAgentConcentration = 2228302
    IlluminationWaveLength = 2228309
    IlluminationPower = 2228310
    IlluminationBandwidth = 2228311
    MydriaticAgentSequence = 2228312
    OphthalmicAxialMeasurementsRightEyeSequence = 2232327
    OphthalmicAxialMeasurementsLeftEyeSequence = 2232328
    OphthalmicAxialMeasurementsDeviceType = 2232329
    OphthalmicAxialLengthMeasurementsType = 2232336
    OphthalmicAxialLengthSequence = 2232338
    OphthalmicAxialLength = 2232345
    LensStatusCodeSequence = 2232356
    VitreousStatusCodeSequence = 2232357
    IOLFormulaCodeSequence = 2232360
    IOLFormulaDetail = 2232361
    KeratometerIndex = 2232371
    SourceOfOphthalmicAxialLengthCodeSequence = 2232373
    SourceOfCornealSizeDataCodeSequence = 2232374
    TargetRefraction = 2232375
    RefractiveProcedureOccurred = 2232377
    RefractiveSurgeryTypeCodeSequence = 2232384
    OphthalmicUltrasoundMethodCodeSequence = 2232388
    SurgicallyInducedAstigmatismSequence = 2232389
    TypeOfOpticalCorrection = 2232390
    ToricIOLPowerSequence = 2232391
    PredictedToricErrorSequence = 2232392
    PreSelectedForImplantation = 2232393
    ToricIOLPowerForExactEmmetropiaSequence = 2232394
    ToricIOLPowerForExactTargetRefractionSequence = 2232395
    OphthalmicAxialLengthMeasurementsSequence = 2232400
    IOLPower = 2232403
    PredictedRefractiveError = 2232404
    OphthalmicAxialLengthVelocity = 2232409
    LensStatusDescription = 2232421
    VitreousStatusDescription = 2232422
    IOLPowerSequence = 2232464
    LensConstantSequence = 2232466
    IOLManufacturer = 2232467
    LensConstantDescription = 2232468
    ImplantName = 2232469
    KeratometryMeasurementTypeCodeSequence = 2232470
    ImplantPartNumber = 2232471
    ReferencedOphthalmicAxialMeasurementsSequence = 2232576
    OphthalmicAxialLengthMeasurementsSegmentNameCodeSequence = 2232577
    RefractiveErrorBeforeRefractiveSurgeryCodeSequence = 2232579
    IOLPowerForExactEmmetropia = 2232609
    IOLPowerForExactTargetRefraction = 2232610
    AnteriorChamberDepthDefinitionCodeSequence = 2232613
    LensThicknessSequence = 2232615
    AnteriorChamberDepthSequence = 2232616
    CalculationCommentSequence = 2232618
    CalculationCommentType = 2232619
    CalculationComment = 2232620
    LensThickness = 2232624
    AnteriorChamberDepth = 2232625
    SourceOfLensThicknessDataCodeSequence = 2232626
    SourceOfAnteriorChamberDepthDataCodeSequence = 2232627
    SourceOfRefractiveMeasurementsSequence = 2232628
    SourceOfRefractiveMeasurementsCodeSequence = 2232629
    OphthalmicAxialLengthMeasurementModified = 2232640
    OphthalmicAxialLengthDataSourceCodeSequence = 2232656
    OphthalmicAxialLengthAcquisitionMethodCodeSequence = 2232659
    SignalToNoiseRatio = 2232661
    OphthalmicAxialLengthDataSourceDescription = 2232665
    OphthalmicAxialLengthMeasurementsTotalLengthSequence = 2232848
    OphthalmicAxialLengthMeasurementsSegmentalLengthSequence = 2232849
    OphthalmicAxialLengthMeasurementsLengthSummationSequence = 2232850
    UltrasoundOphthalmicAxialLengthMeasurementsSequence = 2232864
    OpticalOphthalmicAxialLengthMeasurementsSequence = 2232869
    UltrasoundSelectedOphthalmicAxialLengthSequence = 2232880
    OphthalmicAxialLengthSelectionMethodCodeSequence = 2232912
    OpticalSelectedOphthalmicAxialLengthSequence = 2232917
    SelectedSegmentalOphthalmicAxialLengthSequence = 2232919
    SelectedTotalOphthalmicAxialLengthSequence = 2232928
    OphthalmicAxialLengthQualityMetricSequence = 2232930
    OphthalmicAxialLengthQualityMetricTypeCodeSequence = 2232933
    OphthalmicAxialLengthQualityMetricTypeDescription = 2232947
    IntraocularLensCalculationsRightEyeSequence = 2233088
    IntraocularLensCalculationsLeftEyeSequence = 2233104
    ReferencedOphthalmicAxialLengthMeasurementQCImageSequence = 2233136
    OphthalmicMappingDeviceType = 2233365
    AcquisitionMethodCodeSequence = 2233376
    AcquisitionMethodAlgorithmSequence = 2233379
    OphthalmicThicknessMapTypeCodeSequence = 2233398
    OphthalmicThicknessMappingNormalsSequence = 2233411
    RetinalThicknessDefinitionCodeSequence = 2233413
    PixelValueMappingToCodedConceptSequence = 2233424
    MappedPixelValue = 2233426
    PixelValueMappingExplanation = 2233428
    OphthalmicThicknessMapQualityThresholdSequence = 2233432
    OphthalmicThicknessMapThresholdQualityRating = 2233440
    AnatomicStructureReferencePoint = 2233443
    RegistrationToLocalizerSequence = 2233445
    RegisteredLocalizerUnits = 2233446
    RegisteredLocalizerTopLeftHandCorner = 2233447
    RegisteredLocalizerBottomRightHandCorner = 2233448
    OphthalmicThicknessMapQualityRatingSequence = 2233456
    RelevantOPTAttributesSequence = 2233458
    TransformationMethodCodeSequence = 2233618
    TransformationAlgorithmSequence = 2233619
    OphthalmicAxialLengthMethod = 2233621
    OphthalmicFOV = 2233623
    TwoDimensionalToThreeDimensionalMapSequence = 2233624
    WideFieldOphthalmicPhotographyQualityRatingSequence = 2233637
    WideFieldOphthalmicPhotographyQualityThresholdSequence = 2233638
    WideFieldOphthalmicPhotographyThresholdQualityRating = 2233639
    XCoordinatesCenterPixelViewAngle = 2233640
    YCoordinatesCenterPixelViewAngle = 2233641
    NumberOfMapPoints = 2233648
    TwoDimensionalToThreeDimensionalMapData = 2233649
    DerivationAlgorithmSequence = 2233874
    OphthalmicImageTypeCodeSequence = 2233877
    OphthalmicImageTypeDescription = 2233878
    ScanPatternTypeCodeSequence = 2233880
    ReferencedSurfaceMeshIdentificationSequence = 2233888
    OphthalmicVolumetricPropertiesFlag = 2233890
    OphthalmicAnatomicReferencePointXCoordinate = 2233892
    OphthalmicAnatomicReferencePointYCoordinate = 2233894
    OphthalmicEnFaceImageQualityRatingSequence = 2233896
    QualityThreshold = 2233904
    OCTBscanAnalysisAcquisitionParametersSequence = 2233920
    NumberOfBscansPerFrame = 2233922
    BscanSlabThickness = 2233923
    DistanceBetweenBscanSlabs = 2233924
    BscanCycleTime = 2233925
    BscanCycleTimeVector = 2233926
    AscanRate = 2233929
    BscanRate = 2233936
    SurfaceMeshZPixelOffset = 2233944
    VisualFieldHorizontalExtent = 2359312
    VisualFieldVerticalExtent = 2359313
    VisualFieldShape = 2359314
    ScreeningTestModeCodeSequence = 2359318
    MaximumStimulusLuminance = 2359320
    BackgroundLuminance = 2359328
    StimulusColorCodeSequence = 2359329
    BackgroundIlluminationColorCodeSequence = 2359332
    StimulusArea = 2359333
    StimulusPresentationTime = 2359336
    FixationSequence = 2359346
    FixationMonitoringCodeSequence = 2359347
    VisualFieldCatchTrialSequence = 2359348
    FixationCheckedQuantity = 2359349
    PatientNotProperlyFixatedQuantity = 2359350
    PresentedVisualStimuliDataFlag = 2359351
    NumberOfVisualStimuli = 2359352
    ExcessiveFixationLossesDataFlag = 2359353
    ExcessiveFixationLosses = 2359360
    StimuliRetestingQuantity = 2359362
    CommentsOnPatientPerformanceOfVisualField = 2359364
    FalseNegativesEstimateFlag = 2359365
    FalseNegativesEstimate = 2359366
    NegativeCatchTrialsQuantity = 2359368
    FalseNegativesQuantity = 2359376
    ExcessiveFalseNegativesDataFlag = 2359377
    ExcessiveFalseNegatives = 2359378
    FalsePositivesEstimateFlag = 2359379
    FalsePositivesEstimate = 2359380
    CatchTrialsDataFlag = 2359381
    PositiveCatchTrialsQuantity = 2359382
    TestPointNormalsDataFlag = 2359383
    TestPointNormalsSequence = 2359384
    GlobalDeviationProbabilityNormalsFlag = 2359385
    FalsePositivesQuantity = 2359392
    ExcessiveFalsePositivesDataFlag = 2359393
    ExcessiveFalsePositives = 2359394
    VisualFieldTestNormalsFlag = 2359395
    ResultsNormalsSequence = 2359396
    AgeCorrectedSensitivityDeviationAlgorithmSequence = 2359397
    GlobalDeviationFromNormal = 2359398
    GeneralizedDefectSensitivityDeviationAlgorithmSequence = 2359399
    LocalizedDeviationFromNormal = 2359400
    PatientReliabilityIndicator = 2359401
    VisualFieldMeanSensitivity = 2359408
    GlobalDeviationProbability = 2359409
    LocalDeviationProbabilityNormalsFlag = 2359410
    LocalizedDeviationProbability = 2359411
    ShortTermFluctuationCalculated = 2359412
    ShortTermFluctuation = 2359413
    ShortTermFluctuationProbabilityCalculated = 2359414
    ShortTermFluctuationProbability = 2359415
    CorrectedLocalizedDeviationFromNormalCalculated = 2359416
    CorrectedLocalizedDeviationFromNormal = 2359417
    CorrectedLocalizedDeviationFromNormalProbabilityCalculated = 2359424
    CorrectedLocalizedDeviationFromNormalProbability = 2359425
    GlobalDeviationProbabilitySequence = 2359427
    LocalizedDeviationProbabilitySequence = 2359429
    FovealSensitivityMeasured = 2359430
    FovealSensitivity = 2359431
    VisualFieldTestDuration = 2359432
    VisualFieldTestPointSequence = 2359433
    VisualFieldTestPointXCoordinate = 2359440
    VisualFieldTestPointYCoordinate = 2359441
    AgeCorrectedSensitivityDeviationValue = 2359442
    StimulusResults = 2359443
    SensitivityValue = 2359444
    RetestStimulusSeen = 2359445
    RetestSensitivityValue = 2359446
    VisualFieldTestPointNormalsSequence = 2359447
    QuantifiedDefect = 2359448
    AgeCorrectedSensitivityDeviationProbabilityValue = 2359552
    GeneralizedDefectCorrectedSensitivityDeviationFlag = 2359554
    GeneralizedDefectCorrectedSensitivityDeviationValue = 2359555
    GeneralizedDefectCorrectedSensitivityDeviationProbabilityValue = 2359556
    MinimumSensitivityValue = 2359557
    BlindSpotLocalized = 2359558
    BlindSpotXCoordinate = 2359559
    BlindSpotYCoordinate = 2359560
    VisualAcuityMeasurementSequence = 2359568
    RefractiveParametersUsedOnPatientSequence = 2359570
    MeasurementLaterality = 2359571
    OphthalmicPatientClinicalInformationLeftEyeSequence = 2359572
    OphthalmicPatientClinicalInformationRightEyeSequence = 2359573
    FovealPointNormativeDataFlag = 2359575
    FovealPointProbabilityValue = 2359576
    ScreeningBaselineMeasured = 2359584
    ScreeningBaselineMeasuredSequence = 2359586
    ScreeningBaselineType = 2359588
    ScreeningBaselineValue = 2359590
    AlgorithmSource = 2359810
    DataSetName = 2360070
    DataSetVersion = 2360071
    DataSetSource = 2360072
    DataSetDescription = 2360073
    VisualFieldTestReliabilityGlobalIndexSequence = 2360087
    VisualFieldGlobalResultsIndexSequence = 2360096
    DataObservationSequence = 2360101
    IndexNormalsFlag = 2360120
    IndexProbability = 2360129
    IndexProbabilitySequence = 2360132
    SamplesPerPixel = 2621442
    SamplesPerPixelUsed = 2621443
    PhotometricInterpretation = 2621444
    ImageDimensions = 2621445
    PlanarConfiguration = 2621446
    NumberOfFrames = 2621448
    FrameIncrementPointer = 2621449
    FrameDimensionPointer = 2621450
    Rows = 2621456
    Columns = 2621457
    Planes = 2621458
    UltrasoundColorDataPresent = 2621460
    PixelSpacing = 2621488
    ZoomFactor = 2621489
    ZoomCenter = 2621490
    PixelAspectRatio = 2621492
    ImageFormat = 2621504
    ManipulatedImage = 2621520
    CorrectedImage = 2621521
    CompressionRecognitionCode = 2621535
    CompressionCode = 2621536
    CompressionOriginator = 2621537
    CompressionLabel = 2621538
    CompressionDescription = 2621539
    CompressionSequence = 2621541
    CompressionStepPointers = 2621542
    RepeatInterval = 2621544
    BitsGrouped = 2621545
    PerimeterTable = 2621552
    PerimeterValue = 2621553
    PredictorRows = 2621568
    PredictorColumns = 2621569
    PredictorConstants = 2621570
    BlockedPixels = 2621584
    BlockRows = 2621585
    BlockColumns = 2621586
    RowOverlap = 2621587
    ColumnOverlap = 2621588
    BitsAllocated = 2621696
    BitsStored = 2621697
    HighBit = 2621698
    PixelRepresentation = 2621699
    SmallestValidPixelValue = 2621700
    LargestValidPixelValue = 2621701
    SmallestImagePixelValue = 2621702
    LargestImagePixelValue = 2621703
    SmallestPixelValueInSeries = 2621704
    LargestPixelValueInSeries = 2621705
    SmallestImagePixelValueInPlane = 2621712
    LargestImagePixelValueInPlane = 2621713
    PixelPaddingValue = 2621728
    PixelPaddingRangeLimit = 2621729
    FloatPixelPaddingValue = 2621730
    DoubleFloatPixelPaddingValue = 2621731
    FloatPixelPaddingRangeLimit = 2621732
    DoubleFloatPixelPaddingRangeLimit = 2621733
    ImageLocation = 2621952
    QualityControlImage = 2622208
    BurnedInAnnotation = 2622209
    RecognizableVisualFeatures = 2622210
    LongitudinalTemporalInformationModified = 2622211
    ReferencedColorPaletteInstanceUID = 2622212
    TransformLabel = 2622464
    TransformVersionNumber = 2622465
    NumberOfTransformSteps = 2622466
    SequenceOfCompressedData = 2622467
    DetailsOfCoefficients = 2622468
    DCTLabel = 2623232
    DataBlockDescription = 2623233
    DataBlock = 2623234
    NormalizationFactorFormat = 2623248
    ZonalMapNumberFormat = 2623264
    ZonalMapLocation = 2623265
    ZonalMapFormat = 2623266
    AdaptiveMapFormat = 2623280
    CodeNumberFormat = 2623296
    PixelSpacingCalibrationType = 2624002
    PixelSpacingCalibrationDescription = 2624004
    PixelIntensityRelationship = 2625600
    PixelIntensityRelationshipSign = 2625601
    WindowCenter = 2625616
    WindowWidth = 2625617
    RescaleIntercept = 2625618
    RescaleSlope = 2625619
    RescaleType = 2625620
    WindowCenterWidthExplanation = 2625621
    VOILUTFunction = 2625622
    GrayScale = 2625664
    RecommendedViewingMode = 2625680
    GrayLookupTableDescriptor = 2625792
    RedPaletteColorLookupTableDescriptor = 2625793
    GreenPaletteColorLookupTableDescriptor = 2625794
    BluePaletteColorLookupTableDescriptor = 2625795
    AlphaPaletteColorLookupTableDescriptor = 2625796
    LargeRedPaletteColorLookupTableDescriptor = 2625809
    LargeGreenPaletteColorLookupTableDescriptor = 2625810
    LargeBluePaletteColorLookupTableDescriptor = 2625811
    PaletteColorLookupTableUID = 2625945
    GrayLookupTableData = 2626048
    RedPaletteColorLookupTableData = 2626049
    GreenPaletteColorLookupTableData = 2626050
    BluePaletteColorLookupTableData = 2626051
    AlphaPaletteColorLookupTableData = 2626052
    LargeRedPaletteColorLookupTableData = 2626065
    LargeGreenPaletteColorLookupTableData = 2626066
    LargeBluePaletteColorLookupTableData = 2626067
    LargePaletteColorLookupTableUID = 2626068
    SegmentedRedPaletteColorLookupTableData = 2626081
    SegmentedGreenPaletteColorLookupTableData = 2626082
    SegmentedBluePaletteColorLookupTableData = 2626083
    SegmentedAlphaPaletteColorLookupTableData = 2626084
    StoredValueColorRangeSequence = 2626096
    MinimumStoredValueMapped = 2626097
    MaximumStoredValueMapped = 2626098
    BreastImplantPresent = 2626304
    PartialView = 2626384
    PartialViewDescription = 2626385
    PartialViewCodeSequence = 2626386
    SpatialLocationsPreserved = 2626394
    DataFrameAssignmentSequence = 2626561
    DataPathAssignment = 2626562
    BitsMappedToColorLookupTable = 2626563
    BlendingLUT1Sequence = 2626564
    BlendingLUT1TransferFunction = 2626565
    BlendingWeightConstant = 2626566
    BlendingLookupTableDescriptor = 2626567
    BlendingLookupTableData = 2626568
    EnhancedPaletteColorLookupTableSequence = 2626571
    BlendingLUT2Sequence = 2626572
    BlendingLUT2TransferFunction = 2626573
    DataPathID = 2626574
    RGBLUTTransferFunction = 2626575
    AlphaLUTTransferFunction = 2626576
    ICCProfile = 2629632
    ColorSpace = 2629634
    LossyImageCompression = 2629904
    LossyImageCompressionRatio = 2629906
    LossyImageCompressionMethod = 2629908
    ModalityLUTSequence = 2633728
    LUTDescriptor = 2633730
    LUTExplanation = 2633731
    ModalityLUTType = 2633732
    LUTData = 2633734
    VOILUTSequence = 2633744
    SoftcopyVOILUTSequence = 2634000
    ImagePresentationComments = 2637824
    BiPlaneAcquisitionSequence = 2641920
    RepresentativeFrameNumber = 2646032
    FrameNumbersOfInterest = 2646048
    FrameOfInterestDescription = 2646050
    FrameOfInterestType = 2646051
    MaskPointers = 2646064
    RWavePointer = 2646080
    MaskSubtractionSequence = 2646272
    MaskOperation = 2646273
    ApplicableFrameRange = 2646274
    MaskFrameNumbers = 2646288
    ContrastFrameAveraging = 2646290
    MaskSubPixelShift = 2646292
    TIDOffset = 2646304
    MaskOperationExplanation = 2646416
    EquipmentAdministratorSequence = 2650112
    NumberOfDisplaySubsystems = 2650113
    CurrentConfigurationID = 2650114
    DisplaySubsystemID = 2650115
    DisplaySubsystemName = 2650116
    DisplaySubsystemDescription = 2650117
    SystemStatus = 2650118
    SystemStatusComment = 2650119
    TargetLuminanceCharacteristicsSequence = 2650120
    LuminanceCharacteristicsID = 2650121
    DisplaySubsystemConfigurationSequence = 2650122
    ConfigurationID = 2650123
    ConfigurationName = 2650124
    ConfigurationDescription = 2650125
    ReferencedTargetLuminanceCharacteristicsID = 2650126
    QAResultsSequence = 2650127
    DisplaySubsystemQAResultsSequence = 2650128
    ConfigurationQAResultsSequence = 2650129
    MeasurementEquipmentSequence = 2650130
    MeasurementFunctions = 2650131
    MeasurementEquipmentType = 2650132
    VisualEvaluationResultSequence = 2650133
    DisplayCalibrationResultSequence = 2650134
    DDLValue = 2650135
    CIExyWhitePoint = 2650136
    DisplayFunctionType = 2650137
    GammaValue = 2650138
    NumberOfLuminancePoints = 2650139
    LuminanceResponseSequence = 2650140
    TargetMinimumLuminance = 2650141
    TargetMaximumLuminance = 2650142
    LuminanceValue = 2650143
    LuminanceResponseDescription = 2650144
    WhitePointFlag = 2650145
    DisplayDeviceTypeCodeSequence = 2650146
    DisplaySubsystemSequence = 2650147
    LuminanceResultSequence = 2650148
    AmbientLightValueSource = 2650149
    MeasuredCharacteristics = 2650150
    LuminanceUniformityResultSequence = 2650151
    VisualEvaluationTestSequence = 2650152
    TestResult = 2650153
    TestResultComment = 2650154
    TestImageValidation = 2650155
    TestPatternCodeSequence = 2650156
    MeasurementPatternCodeSequence = 2650157
    VisualEvaluationMethodCodeSequence = 2650158
    PixelDataProviderURL = 2654176
    DataPointRows = 2658305
    DataPointColumns = 2658306
    SignalDomainColumns = 2658307
    LargestMonochromePixelValue = 2658457
    DataRepresentation = 2658568
    PixelMeasuresSequence = 2658576
    FrameVOILUTSequence = 2658610
    PixelValueTransformationSequence = 2658629
    SignalDomainRows = 2658869
    DisplayFilterPercentage = 2659345
    FramePixelShiftSequence = 2659349
    SubtractionItemID = 2659350
    PixelIntensityRelationshipLUTSequence = 2659362
    FramePixelDataPropertiesSequence = 2659395
    GeometricalProperties = 2659396
    GeometricMaximumDistortion = 2659397
    ImageProcessingApplied = 2659398
    MaskSelectionMode = 2659412
    LUTFunction = 2659444
    MaskVisibilityPercentage = 2659448
    PixelShiftSequence = 2659585
    RegionPixelShiftSequence = 2659586
    VerticesOfTheRegion = 2659587
    MultiFramePresentationSequence = 2659589
    PixelShiftFrameRange = 2659590
    LUTFrameRange = 2659591
    ImageToEquipmentMappingMatrix = 2659616
    EquipmentCoordinateSystemIdentification = 2659639
    StudyStatusID = 3276810
    StudyPriorityID = 3276812
    StudyIDIssuer = 3276818
    StudyVerifiedDate = 3276850
    StudyVerifiedTime = 3276851
    StudyReadDate = 3276852
    StudyReadTime = 3276853
    ScheduledStudyStartDate = 3280896
    ScheduledStudyStartTime = 3280897
    ScheduledStudyStopDate = 3280912
    ScheduledStudyStopTime = 3280913
    ScheduledStudyLocation = 3280928
    ScheduledStudyLocationAETitle = 3280929
    ReasonForStudy = 3280944
    RequestingPhysicianIdentificationSequence = 3280945
    RequestingPhysician = 3280946
    RequestingService = 3280947
    RequestingServiceCodeSequence = 3280948
    StudyArrivalDate = 3280960
    StudyArrivalTime = 3280961
    StudyCompletionDate = 3280976
    StudyCompletionTime = 3280977
    StudyComponentStatusID = 3280981
    RequestedProcedureDescription = 3280992
    RequestedProcedureCodeSequence = 3280996
    ReasonForVisit = 3280998
    ReasonForVisitCodeSequence = 3280999
    RequestedContrastAgent = 3281008
    StudyComments = 3293184
    FlowIdentifierSequence = 3407873
    FlowIdentifier = 3407874
    FlowTransferSyntaxUID = 3407875
    FlowRTPSamplingRate = 3407876
    SourceIdentifier = 3407877
    FrameOriginTimestamp = 3407879
    IncludesImagingSubject = 3407880
    FrameUsefulnessGroupSequence = 3407881
    RealTimeBulkDataFlowSequence = 3407882
    CameraPositionGroupSequence = 3407883
    IncludesInformation = 3407884
    TimeOfFrameGroupSequence = 3407885
    ReferencedPatientAliasSequence = 3670020
    VisitStatusID = 3670024
    AdmissionID = 3670032
    IssuerOfAdmissionID = 3670033
    IssuerOfAdmissionIDSequence = 3670036
    RouteOfAdmissions = 3670038
    ScheduledAdmissionDate = 3670042
    ScheduledAdmissionTime = 3670043
    ScheduledDischargeDate = 3670044
    ScheduledDischargeTime = 3670045
    ScheduledPatientInstitutionResidence = 3670046
    AdmittingDate = 3670048
    AdmittingTime = 3670049
    DischargeDate = 3670064
    DischargeTime = 3670066
    DischargeDiagnosisDescription = 3670080
    DischargeDiagnosisCodeSequence = 3670084
    SpecialNeeds = 3670096
    ServiceEpisodeID = 3670112
    IssuerOfServiceEpisodeID = 3670113
    ServiceEpisodeDescription = 3670114
    IssuerOfServiceEpisodeIDSequence = 3670116
    PertinentDocumentsSequence = 3670272
    PertinentResourcesSequence = 3670273
    ResourceDescription = 3670274
    CurrentPatientLocation = 3670784
    PatientInstitutionResidence = 3671040
    PatientState = 3671296
    PatientClinicalTrialParticipationSequence = 3671298
    VisitComments = 3686400
    WaveformOriginality = 3801092
    NumberOfWaveformChannels = 3801093
    NumberOfWaveformSamples = 3801104
    SamplingFrequency = 3801114
    MultiplexGroupLabel = 3801120
    ChannelDefinitionSequence = 3801600
    WaveformChannelNumber = 3801602
    ChannelLabel = 3801603
    ChannelStatus = 3801605
    ChannelSourceSequence = 3801608
    ChannelSourceModifiersSequence = 3801609
    SourceWaveformSequence = 3801610
    ChannelDerivationDescription = 3801612
    ChannelSensitivity = 3801616
    ChannelSensitivityUnitsSequence = 3801617
    ChannelSensitivityCorrectionFactor = 3801618
    ChannelBaseline = 3801619
    ChannelTimeSkew = 3801620
    ChannelSampleSkew = 3801621
    ChannelOffset = 3801624
    WaveformBitsStored = 3801626
    FilterLowFrequency = 3801632
    FilterHighFrequency = 3801633
    NotchFilterFrequency = 3801634
    NotchFilterBandwidth = 3801635
    WaveformDataDisplayScale = 3801648
    WaveformDisplayBackgroundCIELabValue = 3801649
    WaveformPresentationGroupSequence = 3801664
    PresentationGroupNumber = 3801665
    ChannelDisplaySequence = 3801666
    ChannelRecommendedDisplayCIELabValue = 3801668
    ChannelPosition = 3801669
    DisplayShadingFlag = 3801670
    FractionalChannelDisplayScale = 3801671
    AbsoluteChannelDisplayScale = 3801672
    MultiplexedAudioChannelsDescriptionCodeSequence = 3801856
    ChannelIdentificationCode = 3801857
    ChannelMode = 3801858
    MultiplexGroupUID = 3801872
    PowerlineFrequency = 3801873
    ChannelImpedanceSequence = 3801874
    ImpedanceValue = 3801875
    ImpedanceMeasurementDateTime = 3801876
    ImpedanceMeasurementFrequency = 3801877
    ImpedanceMeasurementCurrentType = 3801878
    ScheduledStationAETitle = 4194305
    ScheduledProcedureStepStartDate = 4194306
    ScheduledProcedureStepStartTime = 4194307
    ScheduledProcedureStepEndDate = 4194308
    ScheduledProcedureStepEndTime = 4194309
    ScheduledPerformingPhysicianName = 4194310
    ScheduledProcedureStepDescription = 4194311
    ScheduledProtocolCodeSequence = 4194312
    ScheduledProcedureStepID = 4194313
    StageCodeSequence = 4194314
    ScheduledPerformingPhysicianIdentificationSequence = 4194315
    ScheduledStationName = 4194320
    ScheduledProcedureStepLocation = 4194321
    PreMedication = 4194322
    ScheduledProcedureStepStatus = 4194336
    OrderPlacerIdentifierSequence = 4194342
    OrderFillerIdentifierSequence = 4194343
    LocalNamespaceEntityID = 4194353
    UniversalEntityID = 4194354
    UniversalEntityIDType = 4194355
    IdentifierTypeCode = 4194357
    AssigningFacilitySequence = 4194358
    AssigningJurisdictionCodeSequence = 4194361
    AssigningAgencyOrDepartmentCodeSequence = 4194362
    ScheduledProcedureStepSequence = 4194560
    ReferencedNonImageCompositeSOPInstanceSequence = 4194848
    PerformedStationAETitle = 4194881
    PerformedStationName = 4194882
    PerformedLocation = 4194883
    PerformedProcedureStepStartDate = 4194884
    PerformedProcedureStepStartTime = 4194885
    PerformedProcedureStepEndDate = 4194896
    PerformedProcedureStepEndTime = 4194897
    PerformedProcedureStepStatus = 4194898
    PerformedProcedureStepID = 4194899
    PerformedProcedureStepDescription = 4194900
    PerformedProcedureTypeDescription = 4194901
    PerformedProtocolCodeSequence = 4194912
    PerformedProtocolType = 4194913
    ScheduledStepAttributesSequence = 4194928
    RequestAttributesSequence = 4194933
    CommentsOnThePerformedProcedureStep = 4194944
    PerformedProcedureStepDiscontinuationReasonCodeSequence = 4194945
    QuantitySequence = 4194963
    Quantity = 4194964
    MeasuringUnitsSequence = 4194965
    BillingItemSequence = 4194966
    TotalTimeOfFluoroscopy = 4195072
    TotalNumberOfExposures = 4195073
    EntranceDose = 4195074
    ExposedArea = 4195075
    DistanceSourceToEntrance = 4195078
    DistanceSourceToSupport = 4195079
    ExposureDoseSequence = 4195086
    CommentsOnRadiationDose = 4195088
    XRayOutput = 4195090
    HalfValueLayer = 4195092
    OrganDose = 4195094
    OrganExposed = 4195096
    BillingProcedureStepSequence = 4195104
    FilmConsumptionSequence = 4195105
    BillingSuppliesAndDevicesSequence = 4195108
    ReferencedProcedureStepSequence = 4195120
    PerformedSeriesSequence = 4195136
    CommentsOnTheScheduledProcedureStep = 4195328
    ProtocolContextSequence = 4195392
    ContentItemModifierSequence = 4195393
    ScheduledSpecimenSequence = 4195584
    SpecimenAccessionNumber = 4195594
    ContainerIdentifier = 4195602
    IssuerOfTheContainerIdentifierSequence = 4195603
    AlternateContainerIdentifierSequence = 4195605
    ContainerTypeCodeSequence = 4195608
    ContainerDescription = 4195610
    ContainerComponentSequence = 4195616
    SpecimenSequence = 4195664
    SpecimenIdentifier = 4195665
    SpecimenDescriptionSequenceTrial = 4195666
    SpecimenDescriptionTrial = 4195667
    SpecimenUID = 4195668
    AcquisitionContextSequence = 4195669
    AcquisitionContextDescription = 4195670
    SpecimenDescriptionSequence = 4195680
    IssuerOfTheSpecimenIdentifierSequence = 4195682
    SpecimenTypeCodeSequence = 4195738
    SpecimenShortDescription = 4195840
    SpecimenDetailedDescription = 4195842
    SpecimenPreparationSequence = 4195856
    SpecimenPreparationStepContentItemSequence = 4195858
    SpecimenLocalizationContentItemSequence = 4195872
    SlideIdentifier = 4196090
    WholeSlideMicroscopyImageFrameTypeSequence = 4196112
    ImageCenterPointCoordinatesSequence = 4196122
    XOffsetInSlideCoordinateSystem = 4196138
    YOffsetInSlideCoordinateSystem = 4196154
    ZOffsetInSlideCoordinateSystem = 4196170
    PixelSpacingSequence = 4196568
    CoordinateSystemAxisCodeSequence = 4196570
    MeasurementUnitsCodeSequence = 4196586
    VitalStainCodeSequenceTrial = 4196856
    RequestedProcedureID = 4198401
    ReasonForTheRequestedProcedure = 4198402
    RequestedProcedurePriority = 4198403
    PatientTransportArrangements = 4198404
    RequestedProcedureLocation = 4198405
    PlacerOrderNumberProcedure = 4198406
    FillerOrderNumberProcedure = 4198407
    ConfidentialityCode = 4198408
    ReportingPriority = 4198409
    ReasonForRequestedProcedureCodeSequence = 4198410
    NamesOfIntendedRecipientsOfResults = 4198416
    IntendedRecipientsOfResultsIdentificationSequence = 4198417
    ReasonForPerformedProcedureCodeSequence = 4198418
    RequestedProcedureDescriptionTrial = 4198496
    PersonIdentificationCodeSequence = 4198657
    PersonAddress = 4198658
    PersonTelephoneNumbers = 4198659
    PersonTelecomInformation = 4198660
    RequestedProcedureComments = 4199424
    ReasonForTheImagingServiceRequest = 4202497
    IssueDateOfImagingServiceRequest = 4202500
    IssueTimeOfImagingServiceRequest = 4202501
    PlacerOrderNumberImagingServiceRequestRetired = 4202502
    FillerOrderNumberImagingServiceRequestRetired = 4202503
    OrderEnteredBy = 4202504
    OrderEntererLocation = 4202505
    OrderCallbackPhoneNumber = 4202512
    OrderCallbackTelecomInformation = 4202513
    PlacerOrderNumberImagingServiceRequest = 4202518
    FillerOrderNumberImagingServiceRequest = 4202519
    ImagingServiceRequestComments = 4203520
    ConfidentialityConstraintOnPatientDataDescription = 4206593
    GeneralPurposeScheduledProcedureStepStatus = 4210689
    GeneralPurposePerformedProcedureStepStatus = 4210690
    GeneralPurposeScheduledProcedureStepPriority = 4210691
    ScheduledProcessingApplicationsCodeSequence = 4210692
    ScheduledProcedureStepStartDateTime = 4210693
    MultipleCopiesFlag = 4210694
    PerformedProcessingApplicationsCodeSequence = 4210695
    ScheduledProcedureStepExpirationDateTime = 4210696
    HumanPerformerCodeSequence = 4210697
    ScheduledProcedureStepModificationDateTime = 4210704
    ExpectedCompletionDateTime = 4210705
    ResultingGeneralPurposePerformedProcedureStepsSequence = 4210709
    ReferencedGeneralPurposeScheduledProcedureStepSequence = 4210710
    ScheduledWorkitemCodeSequence = 4210712
    PerformedWorkitemCodeSequence = 4210713
    InputAvailabilityFlag = 4210720
    InputInformationSequence = 4210721
    RelevantInformationSequence = 4210722
    ReferencedGeneralPurposeScheduledProcedureStepTransactionUID = 4210723
    ScheduledStationNameCodeSequence = 4210725
    ScheduledStationClassCodeSequence = 4210726
    ScheduledStationGeographicLocationCodeSequence = 4210727
    PerformedStationNameCodeSequence = 4210728
    PerformedStationClassCodeSequence = 4210729
    PerformedStationGeographicLocationCodeSequence = 4210736
    RequestedSubsequentWorkitemCodeSequence = 4210737
    NonDICOMOutputCodeSequence = 4210738
    OutputInformationSequence = 4210739
    ScheduledHumanPerformersSequence = 4210740
    ActualHumanPerformersSequence = 4210741
    HumanPerformerOrganization = 4210742
    HumanPerformerName = 4210743
    RawDataHandling = 4210752
    InputReadinessState = 4210753
    PerformedProcedureStepStartDateTime = 4210768
    PerformedProcedureStepEndDateTime = 4210769
    ProcedureStepCancellationDateTime = 4210770
    OutputDestinationSequence = 4210800
    DICOMStorageSequence = 4210801
    STOWRSStorageSequence = 4210802
    StorageURL = 4210803
    XDSStorageSequence = 4210804
    EntranceDoseInmGy = 4227842
    EntranceDoseDerivation = 4227843
    ParametricMapFrameTypeSequence = 4231314
    ReferencedImageRealWorldValueMappingSequence = 4231316
    RealWorldValueMappingSequence = 4231318
    PixelValueMappingCodeSequence = 4231320
    LUTLabel = 4231696
    RealWorldValueLastValueMapped = 4231697
    RealWorldValueLUTData = 4231698
    DoubleFloatRealWorldValueLastValueMapped = 4231699
    DoubleFloatRealWorldValueFirstValueMapped = 4231700
    RealWorldValueFirstValueMapped = 4231702
    QuantityDefinitionSequence = 4231712
    RealWorldValueIntercept = 4231716
    RealWorldValueSlope = 4231717
    FindingsFlagTrial = 4235271
    RelationshipType = 4235280
    FindingsSequenceTrial = 4235296
    FindingsGroupUIDTrial = 4235297
    ReferencedFindingsGroupUIDTrial = 4235298
    FindingsGroupRecordingDateTrial = 4235299
    FindingsGroupRecordingTimeTrial = 4235300
    FindingsSourceCategoryCodeSequenceTrial = 4235302
    VerifyingOrganization = 4235303
    DocumentingOrganizationIdentifierCodeSequenceTrial = 4235304
    VerificationDateTime = 4235312
    ObservationDateTime = 4235314
    ObservationStartDateTime = 4235315
    ValueType = 4235328
    ConceptNameCodeSequence = 4235331
    MeasurementPrecisionDescriptionTrial = 4235335
    ContinuityOfContent = 4235344
    UrgencyOrPriorityAlertsTrial = 4235351
    SequencingIndicatorTrial = 4235360
    DocumentIdentifierCodeSequenceTrial = 4235366
    DocumentAuthorTrial = 4235367
    DocumentAuthorIdentifierCodeSequenceTrial = 4235368
    IdentifierCodeSequenceTrial = 4235376
    VerifyingObserverSequence = 4235379
    ObjectBinaryIdentifierTrial = 4235380
    VerifyingObserverName = 4235381
    DocumentingObserverIdentifierCodeSequenceTrial = 4235382
    AuthorObserverSequence = 4235384
    ParticipantSequence = 4235386
    CustodialOrganizationSequence = 4235388
    ParticipationType = 4235392
    ParticipationDateTime = 4235394
    ObserverType = 4235396
    ProcedureIdentifierCodeSequenceTrial = 4235397
    VerifyingObserverIdentificationCodeSequence = 4235400
    ObjectDirectoryBinaryIdentifierTrial = 4235401
    EquivalentCDADocumentSequence = 4235408
    ReferencedWaveformChannels = 4235440
    DateOfDocumentOrVerbalTransactionTrial = 4235536
    TimeOfDocumentCreationOrVerbalTransactionTrial = 4235538
    DateTime = 4235552
    Date = 4235553
    Time = 4235554
    PersonName = 4235555
    UID = 4235556
    ReportStatusIDTrial = 4235557
    TemporalRangeType = 4235568
    ReferencedSamplePositions = 4235570
    ReferencedFrameNumbers = 4235574
    ReferencedTimeOffsets = 4235576
    ReferencedDateTime = 4235578
    TextValue = 4235616
    FloatingPointValue = 4235617
    RationalNumeratorValue = 4235618
    RationalDenominatorValue = 4235619
    ObservationCategoryCodeSequenceTrial = 4235623
    ConceptCodeSequence = 4235624
    BibliographicCitationTrial = 4235626
    PurposeOfReferenceCodeSequence = 4235632
    ObservationUID = 4235633
    ReferencedObservationUIDTrial = 4235634
    ReferencedObservationClassTrial = 4235635
    ReferencedObjectObservationClassTrial = 4235636
    AnnotationGroupNumber = 4235648
    ObservationDateTrial = 4235666
    ObservationTimeTrial = 4235667
    MeasurementAutomationTrial = 4235668
    ModifierCodeSequence = 4235669
    IdentificationDescriptionTrial = 4235812
    CoordinatesSetGeometricTypeTrial = 4235920
    AlgorithmCodeSequenceTrial = 4235926
    AlgorithmDescriptionTrial = 4235927
    PixelCoordinatesSetTrial = 4235930
    MeasuredValueSequence = 4236032
    NumericValueQualifierCodeSequence = 4236033
    CurrentObserverTrial = 4236039
    NumericValue = 4236042
    ReferencedAccessionSequenceTrial = 4236051
    ReportStatusCommentTrial = 4236090
    ProcedureContextSequenceTrial = 4236096
    VerbalSourceTrial = 4236114
    AddressTrial = 4236115
    TelephoneNumberTrial = 4236116
    VerbalSourceIdentifierCodeSequenceTrial = 4236120
    PredecessorDocumentsSequence = 4236128
    ReferencedRequestSequence = 4236144
    PerformedProcedureCodeSequence = 4236146
    CurrentRequestedProcedureEvidenceSequence = 4236149
    ReportDetailSequenceTrial = 4236160
    PertinentOtherEvidenceSequence = 4236165
    HL7StructuredDocumentReferenceSequence = 4236176
    ObservationSubjectUIDTrial = 4236290
    ObservationSubjectClassTrial = 4236291
    ObservationSubjectTypeCodeSequenceTrial = 4236292
    CompletionFlag = 4236433
    CompletionFlagDescription = 4236434
    VerificationFlag = 4236435
    ArchiveRequested = 4236436
    PreliminaryFlag = 4236438
    ContentTemplateSequence = 4236548
    IdenticalDocumentsSequence = 4236581
    ObservationSubjectContextFlagTrial = 4236800
    ObserverContextFlagTrial = 4236801
    ProcedureContextFlagTrial = 4236803
    ContentSequence = 4237104
    RelationshipSequenceTrial = 4237105
    RelationshipTypeCodeSequenceTrial = 4237106
    LanguageCodeSequenceTrial = 4237124
    TabulatedValuesSequence = 4237313
    NumberOfTableRows = 4237314
    NumbeOfTableColumns = 4237315
    TableRowNumber = 4237316
    TableColumnNumber = 4237317
    TableRowDefinitionSequence = 4237318
    TableColumnDefinitionSequence = 4237319
    CellValuesSequence = 4237320
    UniformResourceLocatorTrial = 4237714
    WaveformAnnotationSequence = 4239392
    TemplateIdentifier = 4250368
    TemplateVersion = 4250374
    TemplateLocalVersion = 4250375
    TemplateExtensionFlag = 4250379
    TemplateExtensionOrganizationUID = 4250380
    TemplateExtensionCreatorUID = 4250381
    ReferencedContentItemIdentifier = 4250483
    HL7InstanceIdentifier = 4251649
    HL7DocumentEffectiveTime = 4251652
    HL7DocumentTypeCodeSequence = 4251654
    DocumentClassCodeSequence = 4251656
    RetrieveURI = 4251664
    RetrieveLocationUID = 4251665
    TypeOfInstances = 4251680
    DICOMRetrievalSequence = 4251681
    DICOMMediaRetrievalSequence = 4251682
    WADORetrievalSequence = 4251683
    XDSRetrievalSequence = 4251684
    WADORSRetrievalSequence = 4251685
    RepositoryUniqueID = 4251696
    HomeCommunityID = 4251697
    DocumentTitle = 4325392
    EncapsulatedDocument = 4325393
    MIMETypeOfEncapsulatedDocument = 4325394
    SourceInstanceSequence = 4325395
    ListOfMIMETypes = 4325396
    EncapsulatedDocumentLength = 4325397
    ProductPackageIdentifier = 4456449
    SubstanceAdministrationApproval = 4456450
    ApprovalStatusFurtherDescription = 4456451
    ApprovalStatusDateTime = 4456452
    ProductTypeCodeSequence = 4456455
    ProductName = 4456456
    ProductDescription = 4456457
    ProductLotIdentifier = 4456458
    ProductExpirationDateTime = 4456459
    SubstanceAdministrationDateTime = 4456464
    SubstanceAdministrationNotes = 4456465
    SubstanceAdministrationDeviceID = 4456466
    ProductParameterSequence = 4456467
    SubstanceAdministrationParameterSequence = 4456473
    ApprovalSequence = 4456704
    AssertionCodeSequence = 4456705
    AssertionUID = 4456706
    AsserterIdentificationSequence = 4456707
    AssertionDateTime = 4456708
    AssertionExpirationDateTime = 4456709
    AssertionComments = 4456710
    RelatedAssertionSequence = 4456711
    ReferencedAssertionUID = 4456712
    ApprovalSubjectSequence = 4456713
    OrganizationalRoleCodeSequence = 4456714
    LensDescription = 4587538
    RightLensSequence = 4587540
    LeftLensSequence = 4587541
    UnspecifiedLateralityLensSequence = 4587542
    CylinderSequence = 4587544
    PrismSequence = 4587560
    HorizontalPrismPower = 4587568
    HorizontalPrismBase = 4587570
    VerticalPrismPower = 4587572
    VerticalPrismBase = 4587574
    LensSegmentType = 4587576
    OpticalTransmittance = 4587584
    ChannelWidth = 4587586
    PupilSize = 4587588
    CornealSize = 4587590
    CornealSizeSequence = 4587591
    AutorefractionRightEyeSequence = 4587600
    AutorefractionLeftEyeSequence = 4587602
    DistancePupillaryDistance = 4587616
    NearPupillaryDistance = 4587618
    IntermediatePupillaryDistance = 4587619
    OtherPupillaryDistance = 4587620
    KeratometryRightEyeSequence = 4587632
    KeratometryLeftEyeSequence = 4587633
    SteepKeratometricAxisSequence = 4587636
    RadiusOfCurvature = 4587637
    KeratometricPower = 4587638
    KeratometricAxis = 4587639
    FlatKeratometricAxisSequence = 4587648
    BackgroundColor = 4587666
    Optotype = 4587668
    OptotypePresentation = 4587669
    SubjectiveRefractionRightEyeSequence = 4587671
    SubjectiveRefractionLeftEyeSequence = 4587672
    AddNearSequence = 4587776
    AddIntermediateSequence = 4587777
    AddOtherSequence = 4587778
    AddPower = 4587780
    ViewingDistance = 4587782
    CorneaMeasurementsSequence = 4587792
    SourceOfCorneaMeasurementDataCodeSequence = 4587793
    SteepCornealAxisSequence = 4587794
    FlatCornealAxisSequence = 4587795
    CornealPower = 4587796
    CornealAxis = 4587797
    CorneaMeasurementMethodCodeSequence = 4587798
    RefractiveIndexOfCornea = 4587799
    RefractiveIndexOfAqueousHumor = 4587800
    VisualAcuityTypeCodeSequence = 4587809
    VisualAcuityRightEyeSequence = 4587810
    VisualAcuityLeftEyeSequence = 4587811
    VisualAcuityBothEyesOpenSequence = 4587812
    ViewingDistanceType = 4587813
    VisualAcuityModifiers = 4587829
    DecimalVisualAcuity = 4587831
    OptotypeDetailedDefinition = 4587833
    ReferencedRefractiveMeasurementsSequence = 4587845
    SpherePower = 4587846
    CylinderPower = 4587847
    CornealTopographySurface = 4588033
    CornealVertexLocation = 4588034
    PupilCentroidXCoordinate = 4588035
    PupilCentroidYCoordinate = 4588036
    EquivalentPupilRadius = 4588037
    CornealTopographyMapTypeCodeSequence = 4588039
    VerticesOfTheOutlineOfPupil = 4588040
    CornealTopographyMappingNormalsSequence = 4588048
    MaximumCornealCurvatureSequence = 4588049
    MaximumCornealCurvature = 4588050
    MaximumCornealCurvatureLocation = 4588051
    MinimumKeratometricSequence = 4588053
    SimulatedKeratometricCylinderSequence = 4588056
    AverageCornealPower = 4588064
    CornealISValue = 4588068
    AnalyzedArea = 4588071
    SurfaceRegularityIndex = 4588080
    SurfaceAsymmetryIndex = 4588082
    CornealEccentricityIndex = 4588084
    KeratoconusPredictionIndex = 4588086
    DecimalPotentialVisualAcuity = 4588088
    CornealTopographyMapQualityEvaluation = 4588098
    SourceImageCornealProcessedDataSequence = 4588100
    CornealPointLocation = 4588103
    CornealPointEstimated = 4588104
    AxialPower = 4588105
    TangentialPower = 4588112
    RefractivePower = 4588113
    RelativeElevation = 4588114
    CornealWavefront = 4588115
    ImagedVolumeWidth = 4718593
    ImagedVolumeHeight = 4718594
    ImagedVolumeDepth = 4718595
    TotalPixelMatrixColumns = 4718598
    TotalPixelMatrixRows = 4718599
    TotalPixelMatrixOriginSequence = 4718600
    SpecimenLabelInImage = 4718608
    FocusMethod = 4718609
    ExtendedDepthOfField = 4718610
    NumberOfFocalPlanes = 4718611
    DistanceBetweenFocalPlanes = 4718612
    RecommendedAbsentPixelCIELabValue = 4718613
    IlluminatorTypeCodeSequence = 4718848
    ImageOrientationSlide = 4718850
    OpticalPathSequence = 4718853
    OpticalPathIdentifier = 4718854
    OpticalPathDescription = 4718855
    IlluminationColorCodeSequence = 4718856
    SpecimenReferenceSequence = 4718864
    CondenserLensPower = 4718865
    ObjectiveLensPower = 4718866
    ObjectiveLensNumericalAperture = 4718867
    PaletteColorLookupTableSequence = 4718880
    ReferencedImageNavigationSequence = 4719104
    TopLeftHandCornerOfLocalizerArea = 4719105
    BottomRightHandCornerOfLocalizerArea = 4719106
    OpticalPathIdentificationSequence = 4719111
    PlanePositionSlideSequence = 4719130
    ColumnPositionInTotalImagePixelMatrix = 4719134
    RowPositionInTotalImagePixelMatrix = 4719135
    PixelOriginInterpretation = 4719361
    NumberOfOpticalPaths = 4719362
    TotalPixelMatrixFocalPlanes = 4719363
    CalibrationImage = 5242884
    DeviceSequence = 5242896
    ContainerComponentTypeCodeSequence = 5242898
    ContainerComponentThickness = 5242899
    DeviceLength = 5242900
    ContainerComponentWidth = 5242901
    DeviceDiameter = 5242902
    DeviceDiameterUnits = 5242903
    DeviceVolume = 5242904
    InterMarkerDistance = 5242905
    ContainerComponentMaterial = 5242906
    ContainerComponentID = 5242907
    ContainerComponentLength = 5242908
    ContainerComponentDiameter = 5242909
    ContainerComponentDescription = 5242910
    DeviceDescription = 5242912
    LongDeviceDescription = 5242913
    ContrastBolusIngredientPercentByVolume = 5373953
    OCTFocalDistance = 5373954
    BeamSpotSize = 5373955
    EffectiveRefractiveIndex = 5373956
    OCTAcquisitionDomain = 5373958
    OCTOpticalCenterWavelength = 5373959
    AxialResolution = 5373960
    RangingDepth = 5373961
    ALineRate = 5373969
    ALinesPerFrame = 5373970
    CatheterRotationalRate = 5373971
    ALinePixelSpacing = 5373972
    ModeOfPercutaneousAccessSequence = 5373974
    IntravascularOCTFrameTypeSequence = 5373989
    OCTZOffsetApplied = 5373990
    IntravascularFrameContentSequence = 5373991
    IntravascularLongitudinalDistance = 5373992
    IntravascularOCTFrameContentSequence = 5373993
    OCTZOffsetCorrection = 5374000
    CatheterDirectionOfRotation = 5374001
    SeamLineLocation = 5374003
    FirstALineLocation = 5374004
    SeamLineIndex = 5374006
    NumberOfPaddedALines = 5374008
    InterpolationType = 5374009
    RefractiveIndexApplied = 5374010
    EnergyWindowVector = 5505040
    NumberOfEnergyWindows = 5505041
    EnergyWindowInformationSequence = 5505042
    EnergyWindowRangeSequence = 5505043
    EnergyWindowLowerLimit = 5505044
    EnergyWindowUpperLimit = 5505045
    RadiopharmaceuticalInformationSequence = 5505046
    ResidualSyringeCounts = 5505047
    EnergyWindowName = 5505048
    DetectorVector = 5505056
    NumberOfDetectors = 5505057
    DetectorInformationSequence = 5505058
    PhaseVector = 5505072
    NumberOfPhases = 5505073
    PhaseInformationSequence = 5505074
    NumberOfFramesInPhase = 5505075
    PhaseDelay = 5505078
    PauseBetweenFrames = 5505080
    PhaseDescription = 5505081
    RotationVector = 5505104
    NumberOfRotations = 5505105
    RotationInformationSequence = 5505106
    NumberOfFramesInRotation = 5505107
    RRIntervalVector = 5505120
    NumberOfRRIntervals = 5505121
    GatedInformationSequence = 5505122
    DataInformationSequence = 5505123
    TimeSlotVector = 5505136
    NumberOfTimeSlots = 5505137
    TimeSlotInformationSequence = 5505138
    TimeSlotTime = 5505139
    SliceVector = 5505152
    NumberOfSlices = 5505153
    AngularViewVector = 5505168
    TimeSliceVector = 5505280
    NumberOfTimeSlices = 5505281
    StartAngle = 5505536
    TypeOfDetectorMotion = 5505538
    TriggerVector = 5505552
    NumberOfTriggersInPhase = 5505553
    ViewCodeSequence = 5505568
    ViewModifierCodeSequence = 5505570
    RadionuclideCodeSequence = 5505792
    AdministrationRouteCodeSequence = 5505794
    RadiopharmaceuticalCodeSequence = 5505796
    CalibrationDataSequence = 5505798
    EnergyWindowNumber = 5505800
    ImageID = 5506048
    PatientOrientationCodeSequence = 5506064
    PatientOrientationModifierCodeSequence = 5506066
    PatientGantryRelationshipCodeSequence = 5506068
    SliceProgressionDirection = 5506304
    ScanProgressionDirection = 5506305
    SeriesType = 5509120
    Units = 5509121
    CountsSource = 5509122
    ReprojectionMethod = 5509124
    SUVType = 5509126
    RandomsCorrectionMethod = 5509376
    AttenuationCorrectionMethod = 5509377
    DecayCorrection = 5509378
    ReconstructionMethod = 5509379
    DetectorLinesOfResponseUsed = 5509380
    ScatterCorrectionMethod = 5509381
    AxialAcceptance = 5509632
    AxialMash = 5509633
    TransverseMash = 5509634
    DetectorElementSize = 5509635
    CoincidenceWindowWidth = 5509648
    SecondaryCountsType = 5509664
    FrameReferenceTime = 5509888
    PrimaryPromptsCountsAccumulated = 5509904
    SecondaryCountsAccumulated = 5509905
    SliceSensitivityFactor = 5509920
    DecayFactor = 5509921
    DoseCalibrationFactor = 5509922
    ScatterFractionFactor = 5509923
    DeadTimeFactor = 5509924
    ImageIndex = 5509936
    CountsIncluded = 5510144
    DeadTimeCorrectionFlag = 5510145
    HistogramSequence = 6303744
    HistogramNumberOfBins = 6303746
    HistogramFirstBinValue = 6303748
    HistogramLastBinValue = 6303750
    HistogramBinWidth = 6303752
    HistogramExplanation = 6303760
    HistogramData = 6303776
    SegmentationType = 6422529
    SegmentSequence = 6422530
    SegmentedPropertyCategoryCodeSequence = 6422531
    SegmentNumber = 6422532
    SegmentLabel = 6422533
    SegmentDescription = 6422534
    SegmentationAlgorithmIdentificationSequence = 6422535
    SegmentAlgorithmType = 6422536
    SegmentAlgorithmName = 6422537
    SegmentIdentificationSequence = 6422538
    ReferencedSegmentNumber = 6422539
    RecommendedDisplayGrayscaleValue = 6422540
    RecommendedDisplayCIELabValue = 6422541
    MaximumFractionalValue = 6422542
    SegmentedPropertyTypeCodeSequence = 6422543
    SegmentationFractionalType = 6422544
    SegmentedPropertyTypeModifierCodeSequence = 6422545
    UsedSegmentsSequence = 6422546
    SegmentsOverlap = 6422547
    TrackingID = 6422560
    TrackingUID = 6422561
    DeformableRegistrationSequence = 6553602
    SourceFrameOfReferenceUID = 6553603
    DeformableRegistrationGridSequence = 6553605
    GridDimensions = 6553607
    GridResolution = 6553608
    VectorGridData = 6553609
    PreDeformationMatrixRegistrationSequence = 6553615
    PostDeformationMatrixRegistrationSequence = 6553616
    NumberOfSurfaces = 6684673
    SurfaceSequence = 6684674
    SurfaceNumber = 6684675
    SurfaceComments = 6684676
    SurfaceProcessing = 6684681
    SurfaceProcessingRatio = 6684682
    SurfaceProcessingDescription = 6684683
    RecommendedPresentationOpacity = 6684684
    RecommendedPresentationType = 6684685
    FiniteVolume = 6684686
    Manifold = 6684688
    SurfacePointsSequence = 6684689
    SurfacePointsNormalsSequence = 6684690
    SurfaceMeshPrimitivesSequence = 6684691
    NumberOfSurfacePoints = 6684693
    PointCoordinatesData = 6684694
    PointPositionAccuracy = 6684695
    MeanPointDistance = 6684696
    MaximumPointDistance = 6684697
    PointsBoundingBoxCoordinates = 6684698
    AxisOfRotation = 6684699
    CenterOfRotation = 6684700
    NumberOfVectors = 6684702
    VectorDimensionality = 6684703
    VectorAccuracy = 6684704
    VectorCoordinateData = 6684705
    DoublePointCoordinatesData = 6684706
    TrianglePointIndexList = 6684707
    EdgePointIndexList = 6684708
    VertexPointIndexList = 6684709
    TriangleStripSequence = 6684710
    TriangleFanSequence = 6684711
    LineSequence = 6684712
    PrimitivePointIndexList = 6684713
    SurfaceCount = 6684714
    ReferencedSurfaceSequence = 6684715
    ReferencedSurfaceNumber = 6684716
    SegmentSurfaceGenerationAlgorithmIdentificationSequence = 6684717
    SegmentSurfaceSourceInstanceSequence = 6684718
    AlgorithmFamilyCodeSequence = 6684719
    AlgorithmNameCodeSequence = 6684720
    AlgorithmVersion = 6684721
    AlgorithmParameters = 6684722
    FacetSequence = 6684724
    SurfaceProcessingAlgorithmIdentificationSequence = 6684725
    AlgorithmName = 6684726
    RecommendedPointRadius = 6684727
    RecommendedLineThickness = 6684728
    LongPrimitivePointIndexList = 6684736
    LongTrianglePointIndexList = 6684737
    LongEdgePointIndexList = 6684738
    LongVertexPointIndexList = 6684739
    TrackSetSequence = 6684929
    TrackSequence = 6684930
    RecommendedDisplayCIELabValueList = 6684931
    TrackingAlgorithmIdentificationSequence = 6684932
    TrackSetNumber = 6684933
    TrackSetLabel = 6684934
    TrackSetDescription = 6684935
    TrackSetAnatomicalTypeCodeSequence = 6684936
    MeasurementsSequence = 6684961
    TrackSetStatisticsSequence = 6684964
    FloatingPointValues = 6684965
    TrackPointIndexList = 6684969
    TrackStatisticsSequence = 6684976
    MeasurementValuesSequence = 6684978
    DiffusionAcquisitionCodeSequence = 6684979
    DiffusionModelCodeSequence = 6684980
    ImplantSize = 6840848
    ImplantTemplateVersion = 6840865
    ReplacedImplantTemplateSequence = 6840866
    ImplantType = 6840867
    DerivationImplantTemplateSequence = 6840868
    OriginalImplantTemplateSequence = 6840869
    EffectiveDateTime = 6840870
    ImplantTargetAnatomySequence = 6840880
    InformationFromManufacturerSequence = 6840928
    NotificationFromManufacturerSequence = 6840933
    InformationIssueDateTime = 6840944
    InformationSummary = 6840960
    ImplantRegulatoryDisapprovalCodeSequence = 6840992
    OverallTemplateSpatialTolerance = 6840997
    HPGLDocumentSequence = 6841024
    HPGLDocumentID = 6841040
    HPGLDocumentLabel = 6841045
    ViewOrientationCodeSequence = 6841056
    ViewOrientationModifierCodeSequence = 6841072
    HPGLDocumentScaling = 6841074
    HPGLDocument = 6841088
    HPGLContourPenNumber = 6841104
    HPGLPenSequence = 6841120
    HPGLPenNumber = 6841136
    HPGLPenLabel = 6841152
    HPGLPenDescription = 6841157
    RecommendedRotationPoint = 6841158
    BoundingRectangle = 6841159
    ImplantTemplate3DModelSurfaceNumber = 6841168
    SurfaceModelDescriptionSequence = 6841184
    SurfaceModelLabel = 6841216
    SurfaceModelScalingFactor = 6841232
    MaterialsCodeSequence = 6841248
    CoatingMaterialsCodeSequence = 6841252
    ImplantTypeCodeSequence = 6841256
    FixationMethodCodeSequence = 6841260
    MatingFeatureSetsSequence = 6841264
    MatingFeatureSetID = 6841280
    MatingFeatureSetLabel = 6841296
    MatingFeatureSequence = 6841312
    MatingFeatureID = 6841328
    MatingFeatureDegreeOfFreedomSequence = 6841344
    DegreeOfFreedomID = 6841360
    DegreeOfFreedomType = 6841376
    TwoDMatingFeatureCoordinatesSequence = 6841392
    ReferencedHPGLDocumentID = 6841408
    TwoDMatingPoint = 6841424
    TwoDMatingAxes = 6841440
    TwoDDegreeOfFreedomSequence = 6841456
    ThreeDDegreeOfFreedomAxis = 6841488
    RangeOfFreedom = 6841504
    ThreeDMatingPoint = 6841536
    ThreeDMatingAxes = 6841552
    TwoDDegreeOfFreedomAxis = 6841584
    PlanningLandmarkPointSequence = 6841600
    PlanningLandmarkLineSequence = 6841616
    PlanningLandmarkPlaneSequence = 6841632
    PlanningLandmarkID = 6841648
    PlanningLandmarkDescription = 6841664
    PlanningLandmarkIdentificationCodeSequence = 6841669
    TwoDPointCoordinatesSequence = 6841680
    TwoDPointCoordinates = 6841696
    ThreeDPointCoordinates = 6841744
    TwoDLineCoordinatesSequence = 6841760
    TwoDLineCoordinates = 6841776
    ThreeDLineCoordinates = 6841808
    TwoDPlaneCoordinatesSequence = 6841824
    TwoDPlaneIntersection = 6841840
    ThreeDPlaneOrigin = 6841872
    ThreeDPlaneNormal = 6841888
    ModelModification = 6844417
    ModelMirroring = 6844418
    ModelUsageCodeSequence = 6844419
    ModelGroupUID = 6844420
    RelativeURIReferenceWithinEncapsulatedDocument = 6844421
    AnnotationCoordinateType = 6946817
    AnnotationGroupSequence = 6946818
    AnnotationGroupUID = 6946819
    AnnotationGroupLabel = 6946821
    AnnotationGroupDescription = 6946822
    AnnotationGroupGenerationType = 6946823
    AnnotationGroupAlgorithmIdentificationSequence = 6946824
    AnnotationPropertyCategoryCodeSequence = 6946825
    AnnotationPropertyTypeCodeSequence = 6946826
    AnnotationPropertyTypeModifierCodeSequence = 6946827
    NumberOfAnnotations = 6946828
    AnnotationAppliesToAllOpticalPaths = 6946829
    ReferencedOpticalPathIdentifier = 6946830
    AnnotationAppliesToAllZPlanes = 6946831
    CommonZCoordinateValue = 6946832
    AnnotationIndexList = 6946833
    GraphicAnnotationSequence = 7340033
    GraphicLayer = 7340034
    BoundingBoxAnnotationUnits = 7340035
    AnchorPointAnnotationUnits = 7340036
    GraphicAnnotationUnits = 7340037
    UnformattedTextValue = 7340038
    TextObjectSequence = 7340040
    GraphicObjectSequence = 7340041
    BoundingBoxTopLeftHandCorner = 7340048
    BoundingBoxBottomRightHandCorner = 7340049
    BoundingBoxTextHorizontalJustification = 7340050
    AnchorPoint = 7340052
    AnchorPointVisibility = 7340053
    GraphicDimensions = 7340064
    NumberOfGraphicPoints = 7340065
    GraphicData = 7340066
    GraphicType = 7340067
    GraphicFilled = 7340068
    ImageRotationRetired = 7340096
    ImageHorizontalFlip = 7340097
    ImageRotation = 7340098
    DisplayedAreaTopLeftHandCornerTrial = 7340112
    DisplayedAreaBottomRightHandCornerTrial = 7340113
    DisplayedAreaTopLeftHandCorner = 7340114
    DisplayedAreaBottomRightHandCorner = 7340115
    DisplayedAreaSelectionSequence = 7340122
    GraphicLayerSequence = 7340128
    GraphicLayerOrder = 7340130
    GraphicLayerRecommendedDisplayGrayscaleValue = 7340134
    GraphicLayerRecommendedDisplayRGBValue = 7340135
    GraphicLayerDescription = 7340136
    ContentLabel = 7340160
    ContentDescription = 7340161
    PresentationCreationDate = 7340162
    PresentationCreationTime = 7340163
    ContentCreatorName = 7340164
    ContentCreatorIdentificationCodeSequence = 7340166
    AlternateContentDescriptionSequence = 7340167
    PresentationSizeMode = 7340288
    PresentationPixelSpacing = 7340289
    PresentationPixelAspectRatio = 7340290
    PresentationPixelMagnificationRatio = 7340291
    GraphicGroupLabel = 7340551
    GraphicGroupDescription = 7340552
    CompoundGraphicSequence = 7340553
    CompoundGraphicInstanceID = 7340582
    FontName = 7340583
    FontNameType = 7340584
    CSSFontName = 7340585
    RotationAngle = 7340592
    TextStyleSequence = 7340593
    LineStyleSequence = 7340594
    FillStyleSequence = 7340595
    GraphicGroupSequence = 7340596
    TextColorCIELabValue = 7340609
    HorizontalAlignment = 7340610
    VerticalAlignment = 7340611
    ShadowStyle = 7340612
    ShadowOffsetX = 7340613
    ShadowOffsetY = 7340614
    ShadowColorCIELabValue = 7340615
    Underlined = 7340616
    Bold = 7340617
    Italic = 7340624
    PatternOnColorCIELabValue = 7340625
    PatternOffColorCIELabValue = 7340626
    LineThickness = 7340627
    LineDashingStyle = 7340628
    LinePattern = 7340629
    FillPattern = 7340630
    FillMode = 7340631
    ShadowOpacity = 7340632
    GapLength = 7340641
    DiameterOfVisibility = 7340642
    RotationPoint = 7340659
    TickAlignment = 7340660
    ShowTickLabel = 7340664
    TickLabelAlignment = 7340665
    CompoundGraphicUnits = 7340674
    PatternOnOpacity = 7340676
    PatternOffOpacity = 7340677
    MajorTicksSequence = 7340679
    TickPosition = 7340680
    TickLabel = 7340681
    CompoundGraphicType = 7340692
    GraphicGroupID = 7340693
    ShapeType = 7340806
    RegistrationSequence = 7340808
    MatrixRegistrationSequence = 7340809
    MatrixSequence = 7340810
    FrameOfReferenceToDisplayedCoordinateSystemTransformationMatrix = 7340811
    FrameOfReferenceTransformationMatrixType = 7340812
    RegistrationTypeCodeSequence = 7340813
    FiducialDescription = 7340815
    FiducialIdentifier = 7340816
    FiducialIdentifierCodeSequence = 7340817
    ContourUncertaintyRadius = 7340818
    UsedFiducialsSequence = 7340820
    GraphicCoordinatesDataSequence = 7340824
    FiducialUID = 7340826
    ReferencedFiducialUID = 7340827
    FiducialSetSequence = 7340828
    FiducialSequence = 7340830
    FiducialsPropertyCategoryCodeSequence = 7340831
    GraphicLayerRecommendedDisplayCIELabValue = 7341057
    BlendingSequence = 7341058
    RelativeOpacity = 7341059
    ReferencedSpatialRegistrationSequence = 7341060
    BlendingPosition = 7341061
    PresentationDisplayCollectionUID = 7344385
    PresentationSequenceCollectionUID = 7344386
    PresentationSequencePositionIndex = 7344387
    RenderedImageReferenceSequence = 7344388
    VolumetricPresentationStateInputSequence = 7344641
    PresentationInputType = 7344642
    InputSequencePositionIndex = 7344643
    Crop = 7344644
    CroppingSpecificationIndex = 7344645
    CompositingMethod = 7344646
    VolumetricPresentationInputNumber = 7344647
    ImageVolumeGeometry = 7344648
    VolumetricPresentationInputSetUID = 7344649
    VolumetricPresentationInputSetSequence = 7344650
    GlobalCrop = 7344651
    GlobalCroppingSpecificationIndex = 7344652
    RenderingMethod = 7344653
    VolumeCroppingSequence = 7344897
    VolumeCroppingMethod = 7344898
    BoundingBoxCrop = 7344899
    ObliqueCroppingPlaneSequence = 7344900
    Plane = 7344901
    PlaneNormal = 7344902
    CroppingSpecificationNumber = 7344905
    MultiPlanarReconstructionStyle = 7345409
    MPRThicknessType = 7345410
    MPRSlabThickness = 7345411
    MPRTopLeftHandCorner = 7345413
    MPRViewWidthDirection = 7345415
    MPRViewWidth = 7345416
    NumberOfVolumetricCurvePoints = 7345420
    VolumetricCurvePoints = 7345421
    MPRViewHeightDirection = 7345425
    MPRViewHeight = 7345426
    RenderProjection = 7345666
    ViewpointPosition = 7345667
    ViewpointLookAtPoint = 7345668
    ViewpointUpDirection = 7345669
    RenderFieldOfView = 7345670
    SamplingStepSize = 7345671
    ShadingStyle = 7345921
    AmbientReflectionIntensity = 7345922
    LightDirection = 7345923
    DiffuseReflectionIntensity = 7345924
    SpecularReflectionIntensity = 7345925
    Shininess = 7345926
    PresentationStateClassificationComponentSequence = 7346177
    ComponentType = 7346178
    ComponentInputSequence = 7346179
    VolumetricPresentationInputIndex = 7346180
    PresentationStateCompositorComponentSequence = 7346181
    WeightingTransferFunctionSequence = 7346182
    WeightingLookupTableDescriptor = 7346183
    WeightingLookupTableData = 7346184
    VolumetricAnnotationSequence = 7346433
    ReferencedStructuredContextSequence = 7346435
    ReferencedContentItem = 7346436
    VolumetricPresentationInputAnnotationSequence = 7346437
    AnnotationClipping = 7346439
    PresentationAnimationStyle = 7346689
    RecommendedAnimationRate = 7346691
    AnimationCurveSequence = 7346692
    AnimationStepSize = 7346693
    SwivelRange = 7346694
    VolumetricCurveUpDirections = 7346695
    VolumeStreamSequence = 7346696
    RGBATransferFunctionDescription = 7346697
    AdvancedBlendingSequence = 7346945
    BlendingInputNumber = 7346946
    BlendingDisplayInputSequence = 7346947
    BlendingDisplaySequence = 7346948
    BlendingMode = 7346950
    TimeSeriesBlending = 7346951
    GeometryForDisplay = 7346952
    ThresholdSequence = 7346961
    ThresholdValueSequence = 7346962
    ThresholdType = 7346963
    ThresholdValue = 7346964
    HangingProtocolName = 7471106
    HangingProtocolDescription = 7471108
    HangingProtocolLevel = 7471110
    HangingProtocolCreator = 7471112
    HangingProtocolCreationDateTime = 7471114
    HangingProtocolDefinitionSequence = 7471116
    HangingProtocolUserIdentificationCodeSequence = 7471118
    HangingProtocolUserGroupName = 7471120
    SourceHangingProtocolSequence = 7471122
    NumberOfPriorsReferenced = 7471124
    ImageSetsSequence = 7471136
    ImageSetSelectorSequence = 7471138
    ImageSetSelectorUsageFlag = 7471140
    SelectorAttribute = 7471142
    SelectorValueNumber = 7471144
    TimeBasedImageSetsSequence = 7471152
    ImageSetNumber = 7471154
    ImageSetSelectorCategory = 7471156
    RelativeTime = 7471160
    RelativeTimeUnits = 7471162
    AbstractPriorValue = 7471164
    AbstractPriorCodeSequence = 7471166
    ImageSetLabel = 7471168
    SelectorAttributeVR = 7471184
    SelectorSequencePointer = 7471186
    SelectorSequencePointerPrivateCreator = 7471188
    SelectorAttributePrivateCreator = 7471190
    SelectorAEValue = 7471198
    SelectorASValue = 7471199
    SelectorATValue = 7471200
    SelectorDAValue = 7471201
    SelectorCSValue = 7471202
    SelectorDTValue = 7471203
    SelectorISValue = 7471204
    SelectorOBValue = 7471205
    SelectorLOValue = 7471206
    SelectorOFValue = 7471207
    SelectorLTValue = 7471208
    SelectorOWValue = 7471209
    SelectorPNValue = 7471210
    SelectorTMValue = 7471211
    SelectorSHValue = 7471212
    SelectorUNValue = 7471213
    SelectorSTValue = 7471214
    SelectorUCValue = 7471215
    SelectorUTValue = 7471216
    SelectorURValue = 7471217
    SelectorDSValue = 7471218
    SelectorODValue = 7471219
    SelectorFDValue = 7471220
    SelectorOLValue = 7471221
    SelectorFLValue = 7471222
    SelectorULValue = 7471224
    SelectorUSValue = 7471226
    SelectorSLValue = 7471228
    SelectorSSValue = 7471230
    SelectorUIValue = 7471231
    SelectorCodeSequenceValue = 7471232
    SelectorOVValue = 7471233
    SelectorSVValue = 7471234
    SelectorUVValue = 7471235
    NumberOfScreens = 7471360
    NominalScreenDefinitionSequence = 7471362
    NumberOfVerticalPixels = 7471364
    NumberOfHorizontalPixels = 7471366
    DisplayEnvironmentSpatialPosition = 7471368
    ScreenMinimumGrayscaleBitDepth = 7471370
    ScreenMinimumColorBitDepth = 7471372
    ApplicationMaximumRepaintTime = 7471374
    DisplaySetsSequence = 7471616
    DisplaySetNumber = 7471618
    DisplaySetLabel = 7471619
    DisplaySetPresentationGroup = 7471620
    DisplaySetPresentationGroupDescription = 7471622
    PartialDataDisplayHandling = 7471624
    SynchronizedScrollingSequence = 7471632
    DisplaySetScrollingGroup = 7471634
    NavigationIndicatorSequence = 7471636
    NavigationDisplaySet = 7471638
    ReferenceDisplaySets = 7471640
    ImageBoxesSequence = 7471872
    ImageBoxNumber = 7471874
    ImageBoxLayoutType = 7471876
    ImageBoxTileHorizontalDimension = 7471878
    ImageBoxTileVerticalDimension = 7471880
    ImageBoxScrollDirection = 7471888
    ImageBoxSmallScrollType = 7471890
    ImageBoxSmallScrollAmount = 7471892
    ImageBoxLargeScrollType = 7471894
    ImageBoxLargeScrollAmount = 7471896
    ImageBoxOverlapPriority = 7471904
    CineRelativeToRealTime = 7471920
    FilterOperationsSequence = 7472128
    FilterByCategory = 7472130
    FilterByAttributePresence = 7472132
    FilterByOperator = 7472134
    StructuredDisplayBackgroundCIELabValue = 7472160
    EmptyImageBoxCIELabValue = 7472161
    StructuredDisplayImageBoxSequence = 7472162
    StructuredDisplayTextBoxSequence = 7472164
    ReferencedFirstFrameSequence = 7472167
    ImageBoxSynchronizationSequence = 7472176
    SynchronizedImageBoxList = 7472178
    TypeOfSynchronization = 7472180
    BlendingOperationType = 7472384
    ReformattingOperationType = 7472400
    ReformattingThickness = 7472402
    ReformattingInterval = 7472404
    ReformattingOperationInitialViewDirection = 7472406
    ThreeDRenderingType = 7472416
    SortingOperationsSequence = 7472640
    SortByCategory = 7472642
    SortingDirection = 7472644
    DisplaySetPatientOrientation = 7472896
    VOIType = 7472898
    PseudoColorType = 7472900
    PseudoColorPaletteInstanceReferenceSequence = 7472901
    ShowGrayscaleInverted = 7472902
    ShowImageTrueSizeFlag = 7472912
    ShowGraphicAnnotationFlag = 7472914
    ShowPatientDemographicsFlag = 7472916
    ShowAcquisitionTechniquesFlag = 7472918
    DisplaySetHorizontalJustification = 7472919
    DisplaySetVerticalJustification = 7472920
    ContinuationStartMeterset = 7602464
    ContinuationEndMeterset = 7602465
    ProcedureStepState = 7606272
    ProcedureStepProgressInformationSequence = 7606274
    ProcedureStepProgress = 7606276
    ProcedureStepProgressDescription = 7606278
    ProcedureStepProgressParametersSequence = 7606279
    ProcedureStepCommunicationsURISequence = 7606280
    ContactURI = 7606282
    ContactDisplayName = 7606284
    ProcedureStepDiscontinuationReasonCodeSequence = 7606286
    BeamTaskSequence = 7606304
    BeamTaskType = 7606306
    BeamOrderIndexTrial = 7606308
    AutosequenceFlag = 7606309
    TableTopVerticalAdjustedPosition = 7606310
    TableTopLongitudinalAdjustedPosition = 7606311
    TableTopLateralAdjustedPosition = 7606312
    PatientSupportAdjustedAngle = 7606314
    TableTopEccentricAdjustedAngle = 7606315
    TableTopPitchAdjustedAngle = 7606316
    TableTopRollAdjustedAngle = 7606317
    DeliveryVerificationImageSequence = 7606320
    VerificationImageTiming = 7606322
    DoubleExposureFlag = 7606324
    DoubleExposureOrdering = 7606326
    DoubleExposureMetersetTrial = 7606328
    DoubleExposureFieldDeltaTrial = 7606330
    RelatedReferenceRTImageSequence = 7606336
    GeneralMachineVerificationSequence = 7606338
    ConventionalMachineVerificationSequence = 7606340
    IonMachineVerificationSequence = 7606342
    FailedAttributesSequence = 7606344
    OverriddenAttributesSequence = 7606346
    ConventionalControlPointVerificationSequence = 7606348
    IonControlPointVerificationSequence = 7606350
    AttributeOccurrenceSequence = 7606352
    AttributeOccurrencePointer = 7606354
    AttributeItemSelector = 7606356
    AttributeOccurrencePrivateCreator = 7606358
    SelectorSequencePointerItems = 7606359
    ScheduledProcedureStepPriority = 7606784
    WorklistLabel = 7606786
    ProcedureStepLabel = 7606788
    ScheduledProcessingParametersSequence = 7606800
    PerformedProcessingParametersSequence = 7606802
    UnifiedProcedureStepPerformedProcedureSequence = 7606806
    RelatedProcedureStepSequence = 7606816
    ProcedureStepRelationshipType = 7606818
    ReplacedProcedureStepSequence = 7606820
    DeletionLock = 7606832
    ReceivingAE = 7606836
    RequestingAE = 7606838
    ReasonForCancellation = 7606840
    SCPStatus = 7606850
    SubscriptionListStatus = 7606852
    UnifiedProcedureStepListStatus = 7606854
    BeamOrderIndex = 7607076
    DoubleExposureMeterset = 7607096
    DoubleExposureFieldDelta = 7607098
    BrachyTaskSequence = 7607297
    ContinuationStartTotalReferenceAirKerma = 7607298
    ContinuationEndTotalReferenceAirKerma = 7607299
    ContinuationPulseNumber = 7607300
    ChannelDeliveryOrderSequence = 7607301
    ReferencedChannelNumber = 7607302
    StartCumulativeTimeWeight = 7607303
    EndCumulativeTimeWeight = 7607304
    OmittedChannelSequence = 7607305
    ReasonForChannelOmission = 7607306
    ReasonForChannelOmissionDescription = 7607307
    ChannelDeliveryOrderIndex = 7607308
    ChannelDeliveryContinuationSequence = 7607309
    OmittedApplicationSetupSequence = 7607310
    ImplantAssemblyTemplateName = 7733249
    ImplantAssemblyTemplateIssuer = 7733251
    ImplantAssemblyTemplateVersion = 7733254
    ReplacedImplantAssemblyTemplateSequence = 7733256
    ImplantAssemblyTemplateType = 7733258
    OriginalImplantAssemblyTemplateSequence = 7733260
    DerivationImplantAssemblyTemplateSequence = 7733262
    ImplantAssemblyTemplateTargetAnatomySequence = 7733264
    ProcedureTypeCodeSequence = 7733280
    SurgicalTechnique = 7733296
    ComponentTypesSequence = 7733298
    ComponentTypeCodeSequence = 7733300
    ExclusiveComponentType = 7733302
    MandatoryComponentType = 7733304
    ComponentSequence = 7733312
    ComponentID = 7733333
    ComponentAssemblySequence = 7733344
    Component1ReferencedID = 7733360
    Component1ReferencedMatingFeatureSetID = 7733376
    Component1ReferencedMatingFeatureID = 7733392
    Component2ReferencedID = 7733408
    Component2ReferencedMatingFeatureSetID = 7733424
    Component2ReferencedMatingFeatureID = 7733440
    ImplantTemplateGroupName = 7864321
    ImplantTemplateGroupDescription = 7864336
    ImplantTemplateGroupIssuer = 7864352
    ImplantTemplateGroupVersion = 7864356
    ReplacedImplantTemplateGroupSequence = 7864358
    ImplantTemplateGroupTargetAnatomySequence = 7864360
    ImplantTemplateGroupMembersSequence = 7864362
    ImplantTemplateGroupMemberID = 7864366
    ThreeDImplantTemplateGroupMemberMatchingPoint = 7864400
    ThreeDImplantTemplateGroupMemberMatchingAxes = 7864416
    ImplantTemplateGroupMemberMatching2DCoordinatesSequence = 7864432
    TwoDImplantTemplateGroupMemberMatchingPoint = 7864464
    TwoDImplantTemplateGroupMemberMatchingAxes = 7864480
    ImplantTemplateGroupVariationDimensionSequence = 7864496
    ImplantTemplateGroupVariationDimensionName = 7864498
    ImplantTemplateGroupVariationDimensionRankSequence = 7864500
    ReferencedImplantTemplateGroupMemberID = 7864502
    ImplantTemplateGroupVariationDimensionRank = 7864504
    SurfaceScanAcquisitionTypeCodeSequence = 8388609
    SurfaceScanModeCodeSequence = 8388610
    RegistrationMethodCodeSequence = 8388611
    ShotDurationTime = 8388612
    ShotOffsetTime = 8388613
    SurfacePointPresentationValueData = 8388614
    SurfacePointColorCIELabValueData = 8388615
    UVMappingSequence = 8388616
    TextureLabel = 8388617
    UValueData = 8388624
    VValueData = 8388625
    ReferencedTextureSequence = 8388626
    ReferencedSurfaceDataSequence = 8388627
    AssessmentSummary = 8519681
    AssessmentSummaryDescription = 8519683
    AssessedSOPInstanceSequence = 8519684
    ReferencedComparisonSOPInstanceSequence = 8519685
    NumberOfAssessmentObservations = 8519686
    AssessmentObservationsSequence = 8519687
    ObservationSignificance = 8519688
    ObservationDescription = 8519690
    StructuredConstraintObservationSequence = 8519692
    AssessedAttributeValueSequence = 8519696
    AssessmentSetID = 8519702
    AssessmentRequesterSequence = 8519703
    SelectorAttributeName = 8519704
    SelectorAttributeKeyword = 8519705
    AssessmentTypeCodeSequence = 8519713
    ObservationBasisCodeSequence = 8519714
    AssessmentLabel = 8519715
    ConstraintType = 8519730
    SpecificationSelectionGuidance = 8519731
    ConstraintValueSequence = 8519732
    RecommendedDefaultValueSequence = 8519733
    ConstraintViolationSignificance = 8519734
    ConstraintViolationCondition = 8519735
    ModifiableConstraintFlag = 8519736
    StorageMediaFileSetID = 8913200
    StorageMediaFileSetUID = 8913216
    IconImageSequence = 8913408
    TopicTitle = 8915204
    TopicSubject = 8915206
    TopicAuthor = 8915216
    TopicKeywords = 8915218
    SOPInstanceStatus = 16778256
    SOPAuthorizationDateTime = 16778272
    SOPAuthorizationComment = 16778276
    AuthorizationEquipmentCertificationNumber = 16778278
    MACIDNumber = 67108869
    MACCalculationTransferSyntaxUID = 67108880
    MACAlgorithm = 67108885
    DataElementsSigned = 67108896
    DigitalSignatureUID = 67109120
    DigitalSignatureDateTime = 67109125
    CertificateType = 67109136
    CertificateOfSigner = 67109141
    Signature = 67109152
    CertifiedTimestampType = 67109637
    CertifiedTimestamp = 67109648
    DigitalSignaturePurposeCodeSequence = 67109889
    ReferencedDigitalSignatureSequence = 67109890
    ReferencedSOPInstanceMACSequence = 67109891
    MAC = 67109892
    EncryptedAttributesSequence = 67110144
    EncryptedContentTransferSyntaxUID = 67110160
    EncryptedContent = 67110176
    ModifiedAttributesSequence = 67110224
    NonconformingModifiedAttributesSequence = 67110225
    NonconformingDataElementValue = 67110226
    OriginalAttributesSequence = 67110241
    AttributeModificationDateTime = 67110242
    ModifyingSystem = 67110243
    SourceOfPreviousValues = 67110244
    ReasonForTheAttributeModification = 67110245
    InstanceOriginStatus = 67110400
    NumberOfCopies = 536870928
    PrinterConfigurationSequence = 536870942
    PrintPriority = 536870944
    MediumType = 536870960
    FilmDestination = 536870976
    FilmSessionLabel = 536870992
    MemoryAllocation = 536871008
    MaximumMemoryAllocation = 536871009
    ColorImagePrintingFlag = 536871010
    CollationFlag = 536871011
    AnnotationFlag = 536871013
    ImageOverlayFlag = 536871015
    PresentationLUTFlag = 536871017
    ImageBoxPresentationLUTFlag = 536871018
    MemoryBitDepth = 536871072
    PrintingBitDepth = 536871073
    MediaInstalledSequence = 536871074
    OtherMediaAvailableSequence = 536871076
    SupportedImageDisplayFormatsSequence = 536871080
    ReferencedFilmBoxSequence = 536872192
    ReferencedStoredPrintSequence = 536872208
    ImageDisplayFormat = 537919504
    AnnotationDisplayFormatID = 537919536
    FilmOrientation = 537919552
    FilmSizeID = 537919568
    PrinterResolutionID = 537919570
    DefaultPrinterResolutionID = 537919572
    MagnificationType = 537919584
    SmoothingType = 537919616
    DefaultMagnificationType = 537919654
    OtherMagnificationTypesAvailable = 537919655
    DefaultSmoothingType = 537919656
    OtherSmoothingTypesAvailable = 537919657
    BorderDensity = 537919744
    EmptyImageDensity = 537919760
    MinDensity = 537919776
    MaxDensity = 537919792
    Trim = 537919808
    ConfigurationInformation = 537919824
    ConfigurationInformationDescription = 537919826
    MaximumCollatedFilms = 537919828
    Illumination = 537919838
    ReflectedAmbientLight = 537919840
    PrinterPixelSpacing = 537920374
    ReferencedFilmSessionSequence = 537920768
    ReferencedImageBoxSequence = 537920784
    ReferencedBasicAnnotationBoxSequence = 537920800
    ImageBoxPosition = 538968080
    Polarity = 538968096
    RequestedImageSize = 538968112
    RequestedDecimateCropBehavior = 538968128
    RequestedResolutionID = 538968144
    RequestedImageSizeFlag = 538968224
    DecimateCropResult = 538968226
    BasicGrayscaleImageSequence = 538968336
    BasicColorImageSequence = 538968337
    ReferencedImageOverlayBoxSequence = 538968368
    ReferencedVOILUTBoxSequence = 538968384
    AnnotationPosition = 540016656
    TextString = 540016672
    ReferencedOverlayPlaneSequence = 541065232
    ReferencedOverlayPlaneGroups = 541065233
    OverlayPixelDataSequence = 541065248
    OverlayMagnificationType = 541065312
    OverlaySmoothingType = 541065328
    OverlayOrImageMagnification = 541065330
    MagnifyToNumberOfColumns = 541065332
    OverlayForegroundDensity = 541065344
    OverlayBackgroundDensity = 541065346
    OverlayMode = 541065360
    ThresholdDensity = 541065472
    ReferencedImageBoxSequenceRetired = 541066496
    PresentationLUTSequence = 542113808
    PresentationLUTShape = 542113824
    ReferencedPresentationLUTSequence = 542115072
    PrintJobID = 553648144
    ExecutionStatus = 553648160
    ExecutionStatusInfo = 553648176
    CreationDate = 553648192
    CreationTime = 553648208
    Originator = 553648240
    DestinationAE = 553648448
    OwnerID = 553648480
    NumberOfFilms = 553648496
    ReferencedPrintJobSequencePullStoredPrint = 553649408
    PrinterStatus = 554696720
    PrinterStatusInfo = 554696736
    PrinterName = 554696752
    PrintQueueID = 554696857
    QueueStatus = 555745296
    PrintJobDescriptionSequence = 555745360
    ReferencedPrintJobSequence = 555745392
    PrintManagementCapabilitiesSequence = 556793872
    PrinterCharacteristicsSequence = 556793877
    FilmBoxContentSequence = 556793904
    ImageBoxContentSequence = 556793920
    AnnotationContentSequence = 556793936
    ImageOverlayBoxContentSequence = 556793952
    PresentationLUTContentSequence = 556793984
    ProposedStudySequence = 556794016
    OriginalImageSequence = 556794048
    LabelUsingInformationExtractedFromInstances = 570425345
    LabelText = 570425346
    LabelStyleSelection = 570425347
    MediaDisposition = 570425348
    BarcodeValue = 570425349
    BarcodeSymbology = 570425350
    AllowMediaSplitting = 570425351
    IncludeNonDICOMObjects = 570425352
    IncludeDisplayApplication = 570425353
    PreserveCompositeInstancesAfterMediaCreation = 570425354
    TotalNumberOfPiecesOfMediaCreated = 570425355
    RequestedMediaApplicationProfile = 570425356
    ReferencedStorageMediaSequence = 570425357
    FailureAttributes = 570425358
    AllowLossyCompression = 570425359
    RequestPriority = 570425376
    RTImageLabel = 805437442
    RTImageName = 805437443
    RTImageDescription = 805437444
    ReportedValuesOrigin = 805437450
    RTImagePlane = 805437452
    XRayImageReceptorTranslation = 805437453
    XRayImageReceptorAngle = 805437454
    RTImageOrientation = 805437456
    ImagePlanePixelSpacing = 805437457
    RTImagePosition = 805437458
    RadiationMachineName = 805437472
    RadiationMachineSAD = 805437474
    RadiationMachineSSD = 805437476
    RTImageSID = 805437478
    SourceToReferenceObjectDistance = 805437480
    FractionNumber = 805437481
    ExposureSequence = 805437488
    MetersetExposure = 805437490
    DiaphragmPosition = 805437492
    FluenceMapSequence = 805437504
    FluenceDataSource = 805437505
    FluenceDataScale = 805437506
    PrimaryFluenceModeSequence = 805437520
    FluenceMode = 805437521
    FluenceModeID = 805437522
    DVHType = 805568513
    DoseUnits = 805568514
    DoseType = 805568516
    SpatialTransformOfDose = 805568517
    DoseComment = 805568518
    NormalizationPoint = 805568520
    DoseSummationType = 805568522
    GridFrameOffsetVector = 805568524
    DoseGridScaling = 805568526
    RTDoseROISequence = 805568528
    DoseValue = 805568530
    TissueHeterogeneityCorrection = 805568532
    DVHNormalizationPoint = 805568576
    DVHNormalizationDoseValue = 805568578
    DVHSequence = 805568592
    DVHDoseScaling = 805568594
    DVHVolumeUnits = 805568596
    DVHNumberOfBins = 805568598
    DVHData = 805568600
    DVHReferencedROISequence = 805568608
    DVHROIContributionType = 805568610
    DVHMinimumDose = 805568624
    DVHMaximumDose = 805568626
    DVHMeanDose = 805568628
    StructureSetLabel = 805699586
    StructureSetName = 805699588
    StructureSetDescription = 805699590
    StructureSetDate = 805699592
    StructureSetTime = 805699593
    ReferencedFrameOfReferenceSequence = 805699600
    RTReferencedStudySequence = 805699602
    RTReferencedSeriesSequence = 805699604
    ContourImageSequence = 805699606
    PredecessorStructureSetSequence = 805699608
    StructureSetROISequence = 805699616
    ROINumber = 805699618
    ReferencedFrameOfReferenceUID = 805699620
    ROIName = 805699622
    ROIDescription = 805699624
    ROIDisplayColor = 805699626
    ROIVolume = 805699628
    RTRelatedROISequence = 805699632
    RTROIRelationship = 805699635
    ROIGenerationAlgorithm = 805699638
    ROIDerivationAlgorithmIdentificationSequence = 805699639
    ROIGenerationDescription = 805699640
    ROIContourSequence = 805699641
    ContourSequence = 805699648
    ContourGeometricType = 805699650
    ContourSlabThickness = 805699652
    ContourOffsetVector = 805699653
    NumberOfContourPoints = 805699654
    ContourNumber = 805699656
    AttachedContours = 805699657
    SourcePixelPlanesCharacteristicsSequence = 805699658
    ContourData = 805699664
    RTROIObservationsSequence = 805699712
    ObservationNumber = 805699714
    ReferencedROINumber = 805699716
    ROIObservationLabel = 805699717
    RTROIIdentificationCodeSequence = 805699718
    ROIObservationDescription = 805699720
    RelatedRTROIObservationsSequence = 805699744
    RTROIInterpretedType = 805699748
    ROIInterpreter = 805699750
    ROIPhysicalPropertiesSequence = 805699760
    ROIPhysicalProperty = 805699762
    ROIPhysicalPropertyValue = 805699764
    ROIElementalCompositionSequence = 805699766
    ROIElementalCompositionAtomicNumber = 805699767
    ROIElementalCompositionAtomicMassFraction = 805699768
    AdditionalRTROIIdentificationCodeSequence = 805699769
    FrameOfReferenceRelationshipSequence = 805699776
    RelatedFrameOfReferenceUID = 805699778
    FrameOfReferenceTransformationType = 805699780
    FrameOfReferenceTransformationMatrix = 805699782
    FrameOfReferenceTransformationComment = 805699784
    PatientLocationCoordinatesSequence = 805699785
    PatientLocationCoordinatesCodeSequence = 805699786
    PatientSupportPositionSequence = 805699787
    MeasuredDoseReferenceSequence = 805830672
    MeasuredDoseDescription = 805830674
    MeasuredDoseType = 805830676
    MeasuredDoseValue = 805830678
    TreatmentSessionBeamSequence = 805830688
    TreatmentSessionIonBeamSequence = 805830689
    CurrentFractionNumber = 805830690
    TreatmentControlPointDate = 805830692
    TreatmentControlPointTime = 805830693
    TreatmentTerminationStatus = 805830698
    TreatmentTerminationCode = 805830699
    TreatmentVerificationStatus = 805830700
    ReferencedTreatmentRecordSequence = 805830704
    SpecifiedPrimaryMeterset = 805830706
    SpecifiedSecondaryMeterset = 805830707
    DeliveredPrimaryMeterset = 805830710
    DeliveredSecondaryMeterset = 805830711
    SpecifiedTreatmentTime = 805830714
    DeliveredTreatmentTime = 805830715
    ControlPointDeliverySequence = 805830720
    IonControlPointDeliverySequence = 805830721
    SpecifiedMeterset = 805830722
    DeliveredMeterset = 805830724
    MetersetRateSet = 805830725
    MetersetRateDelivered = 805830726
    ScanSpotMetersetsDelivered = 805830727
    DoseRateDelivered = 805830728
    TreatmentSummaryCalculatedDoseReferenceSequence = 805830736
    CumulativeDoseToDoseReference = 805830738
    FirstTreatmentDate = 805830740
    MostRecentTreatmentDate = 805830742
    NumberOfFractionsDelivered = 805830746
    OverrideSequence = 805830752
    ParameterSequencePointer = 805830753
    OverrideParameterPointer = 805830754
    ParameterItemIndex = 805830755
    MeasuredDoseReferenceNumber = 805830756
    ParameterPointer = 805830757
    OverrideReason = 805830758
    ParameterValueNumber = 805830759
    CorrectedParameterSequence = 805830760
    CorrectionValue = 805830762
    CalculatedDoseReferenceSequence = 805830768
    CalculatedDoseReferenceNumber = 805830770
    CalculatedDoseReferenceDescription = 805830772
    CalculatedDoseReferenceDoseValue = 805830774
    StartMeterset = 805830776
    EndMeterset = 805830778
    ReferencedMeasuredDoseReferenceSequence = 805830784
    ReferencedMeasuredDoseReferenceNumber = 805830786
    ReferencedCalculatedDoseReferenceSequence = 805830800
    ReferencedCalculatedDoseReferenceNumber = 805830802
    BeamLimitingDeviceLeafPairsSequence = 805830816
    RecordedWedgeSequence = 805830832
    RecordedCompensatorSequence = 805830848
    RecordedBlockSequence = 805830864
    TreatmentSummaryMeasuredDoseReferenceSequence = 805830880
    RecordedSnoutSequence = 805830896
    RecordedRangeShifterSequence = 805830898
    RecordedLateralSpreadingDeviceSequence = 805830900
    RecordedRangeModulatorSequence = 805830902
    RecordedSourceSequence = 805830912
    SourceSerialNumber = 805830917
    TreatmentSessionApplicationSetupSequence = 805830928
    ApplicationSetupCheck = 805830934
    RecordedBrachyAccessoryDeviceSequence = 805830944
    ReferencedBrachyAccessoryDeviceNumber = 805830946
    RecordedChannelSequence = 805830960
    SpecifiedChannelTotalTime = 805830962
    DeliveredChannelTotalTime = 805830964
    SpecifiedNumberOfPulses = 805830966
    DeliveredNumberOfPulses = 805830968
    SpecifiedPulseRepetitionInterval = 805830970
    DeliveredPulseRepetitionInterval = 805830972
    RecordedSourceApplicatorSequence = 805830976
    ReferencedSourceApplicatorNumber = 805830978
    RecordedChannelShieldSequence = 805830992
    ReferencedChannelShieldNumber = 805830994
    BrachyControlPointDeliveredSequence = 805831008
    SafePositionExitDate = 805831010
    SafePositionExitTime = 805831012
    SafePositionReturnDate = 805831014
    SafePositionReturnTime = 805831016
    PulseSpecificBrachyControlPointDeliveredSequence = 805831025
    PulseNumber = 805831026
    BrachyPulseControlPointDeliveredSequence = 805831027
    CurrentTreatmentStatus = 805831168
    TreatmentStatusComment = 805831170
    FractionGroupSummarySequence = 805831200
    ReferencedFractionNumber = 805831203
    FractionGroupType = 805831204
    BeamStopperPosition = 805831216
    FractionStatusSummarySequence = 805831232
    TreatmentDate = 805831248
    TreatmentTime = 805831249
    RTPlanLabel = 805961730
    RTPlanName = 805961731
    RTPlanDescription = 805961732
    RTPlanDate = 805961734
    RTPlanTime = 805961735
    TreatmentProtocols = 805961737
    PlanIntent = 805961738
    TreatmentSites = 805961739
    RTPlanGeometry = 805961740
    PrescriptionDescription = 805961742
    DoseReferenceSequence = 805961744
    DoseReferenceNumber = 805961746
    DoseReferenceUID = 805961747
    DoseReferenceStructureType = 805961748
    NominalBeamEnergyUnit = 805961749
    DoseReferenceDescription = 805961750
    DoseReferencePointCoordinates = 805961752
    NominalPriorDose = 805961754
    DoseReferenceType = 805961760
    ConstraintWeight = 805961761
    DeliveryWarningDose = 805961762
    DeliveryMaximumDose = 805961763
    TargetMinimumDose = 805961765
    TargetPrescriptionDose = 805961766
    TargetMaximumDose = 805961767
    TargetUnderdoseVolumeFraction = 805961768
    OrganAtRiskFullVolumeDose = 805961770
    OrganAtRiskLimitDose = 805961771
    OrganAtRiskMaximumDose = 805961772
    OrganAtRiskOverdoseVolumeFraction = 805961773
    ToleranceTableSequence = 805961792
    ToleranceTableNumber = 805961794
    ToleranceTableLabel = 805961795
    GantryAngleTolerance = 805961796
    BeamLimitingDeviceAngleTolerance = 805961798
    BeamLimitingDeviceToleranceSequence = 805961800
    BeamLimitingDevicePositionTolerance = 805961802
    SnoutPositionTolerance = 805961803
    PatientSupportAngleTolerance = 805961804
    TableTopEccentricAngleTolerance = 805961806
    TableTopPitchAngleTolerance = 805961807
    TableTopRollAngleTolerance = 805961808
    TableTopVerticalPositionTolerance = 805961809
    TableTopLongitudinalPositionTolerance = 805961810
    TableTopLateralPositionTolerance = 805961811
    RTPlanRelationship = 805961813
    FractionGroupSequence = 805961840
    FractionGroupNumber = 805961841
    FractionGroupDescription = 805961842
    NumberOfFractionsPlanned = 805961848
    NumberOfFractionPatternDigitsPerDay = 805961849
    RepeatFractionCycleLength = 805961850
    FractionPattern = 805961851
    NumberOfBeams = 805961856
    BeamDoseSpecificationPoint = 805961858
    ReferencedDoseReferenceUID = 805961859
    BeamDose = 805961860
    BeamMeterset = 805961862
    BeamDosePointDepth = 805961864
    BeamDosePointEquivalentDepth = 805961865
    BeamDosePointSSD = 805961866
    BeamDoseMeaning = 805961867
    BeamDoseVerificationControlPointSequence = 805961868
    AverageBeamDosePointDepth = 805961869
    AverageBeamDosePointEquivalentDepth = 805961870
    AverageBeamDosePointSSD = 805961871
    BeamDoseType = 805961872
    AlternateBeamDose = 805961873
    AlternateBeamDoseType = 805961874
    DepthValueAveragingFlag = 805961875
    BeamDosePointSourceToExternalContourDistance = 805961876
    NumberOfBrachyApplicationSetups = 805961888
    BrachyApplicationSetupDoseSpecificationPoint = 805961890
    BrachyApplicationSetupDose = 805961892
    BeamSequence = 805961904
    TreatmentMachineName = 805961906
    PrimaryDosimeterUnit = 805961907
    SourceAxisDistance = 805961908
    BeamLimitingDeviceSequence = 805961910
    RTBeamLimitingDeviceType = 805961912
    SourceToBeamLimitingDeviceDistance = 805961914
    IsocenterToBeamLimitingDeviceDistance = 805961915
    NumberOfLeafJawPairs = 805961916
    LeafPositionBoundaries = 805961918
    BeamNumber = 805961920
    BeamName = 805961922
    BeamDescription = 805961923
    BeamType = 805961924
    BeamDeliveryDurationLimit = 805961925
    RadiationType = 805961926
    HighDoseTechniqueType = 805961927
    ReferenceImageNumber = 805961928
    PlannedVerificationImageSequence = 805961930
    ImagingDeviceSpecificAcquisitionParameters = 805961932
    TreatmentDeliveryType = 805961934
    NumberOfWedges = 805961936
    WedgeSequence = 805961937
    WedgeNumber = 805961938
    WedgeType = 805961939
    WedgeID = 805961940
    WedgeAngle = 805961941
    WedgeFactor = 805961942
    TotalWedgeTrayWaterEquivalentThickness = 805961943
    WedgeOrientation = 805961944
    IsocenterToWedgeTrayDistance = 805961945
    SourceToWedgeTrayDistance = 805961946
    WedgeThinEdgePosition = 805961947
    BolusID = 805961948
    BolusDescription = 805961949
    EffectiveWedgeAngle = 805961950
    NumberOfCompensators = 805961952
    MaterialID = 805961953
    TotalCompensatorTrayFactor = 805961954
    CompensatorSequence = 805961955
    CompensatorNumber = 805961956
    CompensatorID = 805961957
    SourceToCompensatorTrayDistance = 805961958
    CompensatorRows = 805961959
    CompensatorColumns = 805961960
    CompensatorPixelSpacing = 805961961
    CompensatorPosition = 805961962
    CompensatorTransmissionData = 805961963
    CompensatorThicknessData = 805961964
    NumberOfBoli = 805961965
    CompensatorType = 805961966
    CompensatorTrayID = 805961967
    NumberOfBlocks = 805961968
    TotalBlockTrayFactor = 805961970
    TotalBlockTrayWaterEquivalentThickness = 805961971
    BlockSequence = 805961972
    BlockTrayID = 805961973
    SourceToBlockTrayDistance = 805961974
    IsocenterToBlockTrayDistance = 805961975
    BlockType = 805961976
    AccessoryCode = 805961977
    BlockDivergence = 805961978
    BlockMountingPosition = 805961979
    BlockNumber = 805961980
    BlockName = 805961982
    BlockThickness = 805961984
    BlockTransmission = 805961986
    BlockNumberOfPoints = 805961988
    BlockData = 805961990
    ApplicatorSequence = 805961991
    ApplicatorID = 805961992
    ApplicatorType = 805961993
    ApplicatorDescription = 805961994
    CumulativeDoseReferenceCoefficient = 805961996
    FinalCumulativeMetersetWeight = 805961998
    NumberOfControlPoints = 805962000
    ControlPointSequence = 805962001
    ControlPointIndex = 805962002
    NominalBeamEnergy = 805962004
    DoseRateSet = 805962005
    WedgePositionSequence = 805962006
    WedgePosition = 805962008
    BeamLimitingDevicePositionSequence = 805962010
    LeafJawPositions = 805962012
    GantryAngle = 805962014
    GantryRotationDirection = 805962015
    BeamLimitingDeviceAngle = 805962016
    BeamLimitingDeviceRotationDirection = 805962017
    PatientSupportAngle = 805962018
    PatientSupportRotationDirection = 805962019
    TableTopEccentricAxisDistance = 805962020
    TableTopEccentricAngle = 805962021
    TableTopEccentricRotationDirection = 805962022
    TableTopVerticalPosition = 805962024
    TableTopLongitudinalPosition = 805962025
    TableTopLateralPosition = 805962026
    IsocenterPosition = 805962028
    SurfaceEntryPoint = 805962030
    SourceToSurfaceDistance = 805962032
    AverageBeamDosePointSourceToExternalContourDistance = 805962033
    SourceToExternalContourDistance = 805962034
    ExternalContourEntryPoint = 805962035
    CumulativeMetersetWeight = 805962036
    TableTopPitchAngle = 805962048
    TableTopPitchRotationDirection = 805962050
    TableTopRollAngle = 805962052
    TableTopRollRotationDirection = 805962054
    HeadFixationAngle = 805962056
    GantryPitchAngle = 805962058
    GantryPitchRotationDirection = 805962060
    GantryPitchAngleTolerance = 805962062
    FixationEye = 805962064
    ChairHeadFramePosition = 805962065
    HeadFixationAngleTolerance = 805962066
    ChairHeadFramePositionTolerance = 805962067
    FixationLightAzimuthalAngleTolerance = 805962068
    FixationLightPolarAngleTolerance = 805962069
    PatientSetupSequence = 805962112
    PatientSetupNumber = 805962114
    PatientSetupLabel = 805962115
    PatientAdditionalPosition = 805962116
    FixationDeviceSequence = 805962128
    FixationDeviceType = 805962130
    FixationDeviceLabel = 805962132
    FixationDeviceDescription = 805962134
    FixationDevicePosition = 805962136
    FixationDevicePitchAngle = 805962137
    FixationDeviceRollAngle = 805962138
    ShieldingDeviceSequence = 805962144
    ShieldingDeviceType = 805962146
    ShieldingDeviceLabel = 805962148
    ShieldingDeviceDescription = 805962150
    ShieldingDevicePosition = 805962152
    SetupTechnique = 805962160
    SetupTechniqueDescription = 805962162
    SetupDeviceSequence = 805962164
    SetupDeviceType = 805962166
    SetupDeviceLabel = 805962168
    SetupDeviceDescription = 805962170
    SetupDeviceParameter = 805962172
    SetupReferenceDescription = 805962192
    TableTopVerticalSetupDisplacement = 805962194
    TableTopLongitudinalSetupDisplacement = 805962196
    TableTopLateralSetupDisplacement = 805962198
    BrachyTreatmentTechnique = 805962240
    BrachyTreatmentType = 805962242
    TreatmentMachineSequence = 805962246
    SourceSequence = 805962256
    SourceNumber = 805962258
    SourceType = 805962260
    SourceManufacturer = 805962262
    ActiveSourceDiameter = 805962264
    ActiveSourceLength = 805962266
    SourceModelID = 805962267
    SourceDescription = 805962268
    SourceEncapsulationNominalThickness = 805962274
    SourceEncapsulationNominalTransmission = 805962276
    SourceIsotopeName = 805962278
    SourceIsotopeHalfLife = 805962280
    SourceStrengthUnits = 805962281
    ReferenceAirKermaRate = 805962282
    SourceStrength = 805962283
    SourceStrengthReferenceDate = 805962284
    SourceStrengthReferenceTime = 805962286
    ApplicationSetupSequence = 805962288
    ApplicationSetupType = 805962290
    ApplicationSetupNumber = 805962292
    ApplicationSetupName = 805962294
    ApplicationSetupManufacturer = 805962296
    TemplateNumber = 805962304
    TemplateType = 805962306
    TemplateName = 805962308
    TotalReferenceAirKerma = 805962320
    BrachyAccessoryDeviceSequence = 805962336
    BrachyAccessoryDeviceNumber = 805962338
    BrachyAccessoryDeviceID = 805962339
    BrachyAccessoryDeviceType = 805962340
    BrachyAccessoryDeviceName = 805962342
    BrachyAccessoryDeviceNominalThickness = 805962346
    BrachyAccessoryDeviceNominalTransmission = 805962348
    ChannelEffectiveLength = 805962353
    ChannelInnerLength = 805962354
    AfterloaderChannelID = 805962355
    SourceApplicatorTipLength = 805962356
    ChannelSequence = 805962368
    ChannelNumber = 805962370
    ChannelLength = 805962372
    ChannelTotalTime = 805962374
    SourceMovementType = 805962376
    NumberOfPulses = 805962378
    PulseRepetitionInterval = 805962380
    SourceApplicatorNumber = 805962384
    SourceApplicatorID = 805962385
    SourceApplicatorType = 805962386
    SourceApplicatorName = 805962388
    SourceApplicatorLength = 805962390
    SourceApplicatorManufacturer = 805962392
    SourceApplicatorWallNominalThickness = 805962396
    SourceApplicatorWallNominalTransmission = 805962398
    SourceApplicatorStepSize = 805962400
    ApplicatorShapeReferencedROINumber = 805962401
    TransferTubeNumber = 805962402
    TransferTubeLength = 805962404
    ChannelShieldSequence = 805962416
    ChannelShieldNumber = 805962418
    ChannelShieldID = 805962419
    ChannelShieldName = 805962420
    ChannelShieldNominalThickness = 805962424
    ChannelShieldNominalTransmission = 805962426
    FinalCumulativeTimeWeight = 805962440
    BrachyControlPointSequence = 805962448
    ControlPointRelativePosition = 805962450
    ControlPoint3DPosition = 805962452
    CumulativeTimeWeight = 805962454
    CompensatorDivergence = 805962464
    CompensatorMountingPosition = 805962465
    SourceToCompensatorDistance = 805962466
    TotalCompensatorTrayWaterEquivalentThickness = 805962467
    IsocenterToCompensatorTrayDistance = 805962468
    CompensatorColumnOffset = 805962469
    IsocenterToCompensatorDistances = 805962470
    CompensatorRelativeStoppingPowerRatio = 805962471
    CompensatorMillingToolDiameter = 805962472
    IonRangeCompensatorSequence = 805962474
    CompensatorDescription = 805962475
    RadiationMassNumber = 805962498
    RadiationAtomicNumber = 805962500
    RadiationChargeState = 805962502
    ScanMode = 805962504
    ModulatedScanModeType = 805962505
    VirtualSourceAxisDistances = 805962506
    SnoutSequence = 805962508
    SnoutPosition = 805962509
    SnoutID = 805962511
    NumberOfRangeShifters = 805962514
    RangeShifterSequence = 805962516
    RangeShifterNumber = 805962518
    RangeShifterID = 805962520
    RangeShifterType = 805962528
    RangeShifterDescription = 805962530
    NumberOfLateralSpreadingDevices = 805962544
    LateralSpreadingDeviceSequence = 805962546
    LateralSpreadingDeviceNumber = 805962548
    LateralSpreadingDeviceID = 805962550
    LateralSpreadingDeviceType = 805962552
    LateralSpreadingDeviceDescription = 805962554
    LateralSpreadingDeviceWaterEquivalentThickness = 805962556
    NumberOfRangeModulators = 805962560
    RangeModulatorSequence = 805962562
    RangeModulatorNumber = 805962564
    RangeModulatorID = 805962566
    RangeModulatorType = 805962568
    RangeModulatorDescription = 805962570
    BeamCurrentModulationID = 805962572
    PatientSupportType = 805962576
    PatientSupportID = 805962578
    PatientSupportAccessoryCode = 805962580
    TrayAccessoryCode = 805962581
    FixationLightAzimuthalAngle = 805962582
    FixationLightPolarAngle = 805962584
    MetersetRate = 805962586
    RangeShifterSettingsSequence = 805962592
    RangeShifterSetting = 805962594
    IsocenterToRangeShifterDistance = 805962596
    RangeShifterWaterEquivalentThickness = 805962598
    LateralSpreadingDeviceSettingsSequence = 805962608
    LateralSpreadingDeviceSetting = 805962610
    IsocenterToLateralSpreadingDeviceDistance = 805962612
    RangeModulatorSettingsSequence = 805962624
    RangeModulatorGatingStartValue = 805962626
    RangeModulatorGatingStopValue = 805962628
    RangeModulatorGatingStartWaterEquivalentThickness = 805962630
    RangeModulatorGatingStopWaterEquivalentThickness = 805962632
    IsocenterToRangeModulatorDistance = 805962634
    ScanSpotTimeOffset = 805962639
    ScanSpotTuneID = 805962640
    ScanSpotPrescribedIndices = 805962641
    NumberOfScanSpotPositions = 805962642
    ScanSpotReordered = 805962643
    ScanSpotPositionMap = 805962644
    ScanSpotReorderingAllowed = 805962645
    ScanSpotMetersetWeights = 805962646
    ScanningSpotSize = 805962648
    ScanSpotSizesDelivered = 805962649
    NumberOfPaintings = 805962650
    IonToleranceTableSequence = 805962656
    IonBeamSequence = 805962658
    IonBeamLimitingDeviceSequence = 805962660
    IonBlockSequence = 805962662
    IonControlPointSequence = 805962664
    IonWedgeSequence = 805962666
    IonWedgePositionSequence = 805962668
    ReferencedSetupImageSequence = 805962753
    SetupImageComment = 805962754
    MotionSynchronizationSequence = 805962768
    ControlPointOrientation = 805962770
    GeneralAccessorySequence = 805962784
    GeneralAccessoryID = 805962785
    GeneralAccessoryDescription = 805962786
    GeneralAccessoryType = 805962787
    GeneralAccessoryNumber = 805962788
    SourceToGeneralAccessoryDistance = 805962789
    IsocenterToGeneralAccessoryDistance = 805962790
    ApplicatorGeometrySequence = 805962801
    ApplicatorApertureShape = 805962802
    ApplicatorOpening = 805962803
    ApplicatorOpeningX = 805962804
    ApplicatorOpeningY = 805962805
    SourceToApplicatorMountingPositionDistance = 805962806
    NumberOfBlockSlabItems = 805962816
    BlockSlabSequence = 805962817
    BlockSlabThickness = 805962818
    BlockSlabNumber = 805962819
    DeviceMotionControlSequence = 805962832
    DeviceMotionExecutionMode = 805962833
    DeviceMotionObservationMode = 805962834
    DeviceMotionParameterCodeSequence = 805962835
    DistalDepthFraction = 805963009
    DistalDepth = 805963010
    NominalRangeModulationFractions = 805963011
    NominalRangeModulatedRegionDepths = 805963012
    DepthDoseParametersSequence = 805963013
    DeliveredDepthDoseParametersSequence = 805963014
    DeliveredDistalDepthFraction = 805963015
    DeliveredDistalDepth = 805963016
    DeliveredNominalRangeModulationFractions = 805963017
    DeliveredNominalRangeModulatedRegionDepths = 805963024
    DeliveredReferenceDoseDefinition = 805963025
    ReferenceDoseDefinition = 805963026
    RTControlPointIndex = 805963264
    RadiationGenerationModeIndex = 805963265
    ReferencedDefinedDeviceIndex = 805963266
    RadiationDoseIdentificationIndex = 805963267
    NumberOfRTControlPoints = 805963268
    ReferencedRadiationGenerationModeIndex = 805963269
    TreatmentPositionIndex = 805963270
    ReferencedDeviceIndex = 805963271
    TreatmentPositionGroupLabel = 805963272
    TreatmentPositionGroupUID = 805963273
    TreatmentPositionGroupSequence = 805963274
    ReferencedTreatmentPositionIndex = 805963275
    ReferencedRadiationDoseIdentificationIndex = 805963276
    RTAccessoryHolderWaterEquivalentThickness = 805963277
    ReferencedRTAccessoryHolderDeviceIndex = 805963278
    RTAccessoryHolderSlotExistenceFlag = 805963279
    RTAccessoryHolderSlotSequence = 805963280
    RTAccessoryHolderSlotID = 805963281
    RTAccessoryHolderSlotDistance = 805963282
    RTAccessorySlotDistance = 805963283
    RTAccessoryHolderDefinitionSequence = 805963284
    RTAccessoryDeviceSlotID = 805963285
    RTRadiationSequence = 805963286
    RadiationDoseSequence = 805963287
    RadiationDoseIdentificationSequence = 805963288
    RadiationDoseIdentificationLabel = 805963289
    ReferenceDoseType = 805963290
    PrimaryDoseValueIndicator = 805963291
    DoseValuesSequence = 805963292
    DoseValuePurpose = 805963293
    ReferenceDosePointCoordinates = 805963294
    RadiationDoseValuesParametersSequence = 805963295
    MetersetToDoseMappingSequence = 805963296
    ExpectedInVivoMeasurementValuesSequence = 805963297
    ExpectedInVivoMeasurementValueIndex = 805963298
    RadiationDoseInVivoMeasurementLabel = 805963299
    RadiationDoseCentralAxisDisplacement = 805963300
    RadiationDoseValue = 805963301
    RadiationDoseSourceToSkinDistance = 805963302
    RadiationDoseMeasurementPointCoordinates = 805963303
    RadiationDoseSourceToExternalContourDistance = 805963304
    RTToleranceSetSequence = 805963305
    RTToleranceSetLabel = 805963306
    AttributeToleranceValuesSequence = 805963307
    ToleranceValue = 805963308
    PatientSupportPositionToleranceSequence = 805963309
    TreatmentTimeLimit = 805963310
    CArmPhotonElectronControlPointSequence = 805963311
    ReferencedRTRadiationSequence = 805963312
    ReferencedRTInstanceSequence = 805963313
    ReferencedRTPatientSetupSequence = 805963314
    SourceToPatientSurfaceDistance = 805963316
    TreatmentMachineSpecialModeCodeSequence = 805963317
    IntendedNumberOfFractions = 805963318
    RTRadiationSetIntent = 805963319
    RTRadiationPhysicalAndGeometricContentDetailFlag = 805963320
    RTRecordFlag = 805963321
    TreatmentDeviceIdentificationSequence = 805963322
    ReferencedRTPhysicianIntentSequence = 805963323
    CumulativeMeterset = 805963324
    DeliveryRate = 805963325
    DeliveryRateUnitSequence = 805963326
    TreatmentPositionSequence = 805963327
    RadiationSourceAxisDistance = 805963328
    NumberOfRTBeamLimitingDevices = 805963329
    RTBeamLimitingDeviceProximalDistance = 805963330
    RTBeamLimitingDeviceDistalDistance = 805963331
    ParallelRTBeamDelimiterDeviceOrientationLabelCodeSequence = 805963332
    BeamModifierOrientationAngle = 805963333
    FixedRTBeamDelimiterDeviceSequence = 805963334
    ParallelRTBeamDelimiterDeviceSequence = 805963335
    NumberOfParallelRTBeamDelimiters = 805963336
    ParallelRTBeamDelimiterBoundaries = 805963337
    ParallelRTBeamDelimiterPositions = 805963338
    RTBeamLimitingDeviceOffset = 805963339
    RTBeamDelimiterGeometrySequence = 805963340
    RTBeamLimitingDeviceDefinitionSequence = 805963341
    ParallelRTBeamDelimiterOpeningMode = 805963342
    ParallelRTBeamDelimiterLeafMountingSide = 805963343
    PatientSetupUID = 805963344
    WedgeDefinitionSequence = 805963345
    RadiationBeamWedgeAngle = 805963346
    RadiationBeamWedgeThinEdgeDistance = 805963347
    RadiationBeamEffectiveWedgeAngle = 805963348
    NumberOfWedgePositions = 805963349
    RTBeamLimitingDeviceOpeningSequence = 805963350
    NumberOfRTBeamLimitingDeviceOpenings = 805963351
    RadiationDosimeterUnitSequence = 805963352
    RTDeviceDistanceReferenceLocationCodeSequence = 805963353
    RadiationDeviceConfigurationAndCommissioningKeySequence = 805963354
    PatientSupportPositionParameterSequence = 805963355
    PatientSupportPositionSpecificationMethod = 805963356
    PatientSupportPositionDeviceParameterSequence = 805963357
    DeviceOrderIndex = 805963358
    PatientSupportPositionParameterOrderIndex = 805963359
    PatientSupportPositionDeviceToleranceSequence = 805963360
    PatientSupportPositionToleranceOrderIndex = 805963361
    CompensatorDefinitionSequence = 805963362
    CompensatorMapOrientation = 805963363
    CompensatorProximalThicknessMap = 805963364
    CompensatorDistalThicknessMap = 805963365
    CompensatorBasePlaneOffset = 805963366
    CompensatorShapeFabricationCodeSequence = 805963367
    CompensatorShapeSequence = 805963368
    RadiationBeamCompensatorMillingToolDiameter = 805963369
    BlockDefinitionSequence = 805963370
    BlockEdgeData = 805963371
    BlockOrientation = 805963372
    RadiationBeamBlockThickness = 805963373
    RadiationBeamBlockSlabThickness = 805963374
    BlockEdgeDataSequence = 805963375
    NumberOfRTAccessoryHolders = 805963376
    GeneralAccessoryDefinitionSequence = 805963377
    NumberOfGeneralAccessories = 805963378
    BolusDefinitionSequence = 805963379
    NumberOfBoluses = 805963380
    EquipmentFrameOfReferenceUID = 805963381
    EquipmentFrameOfReferenceDescription = 805963382
    EquipmentReferencePointCoordinatesSequence = 805963383
    EquipmentReferencePointCodeSequence = 805963384
    RTBeamLimitingDeviceAngle = 805963385
    SourceRollAngle = 805963386
    RadiationGenerationModeSequence = 805963387
    RadiationGenerationModeLabel = 805963388
    RadiationGenerationModeDescription = 805963389
    RadiationGenerationModeMachineCodeSequence = 805963390
    RadiationTypeCodeSequence = 805963391
    NominalEnergy = 805963392
    MinimumNominalEnergy = 805963393
    MaximumNominalEnergy = 805963394
    RadiationFluenceModifierCodeSequence = 805963395
    EnergyUnitCodeSequence = 805963396
    NumberOfRadiationGenerationModes = 805963397
    PatientSupportDevicesSequence = 805963398
    NumberOfPatientSupportDevices = 805963399
    RTBeamModifierDefinitionDistance = 805963400
    BeamAreaLimitSequence = 805963401
    ReferencedRTPrescriptionSequence = 805963402
    TreatmentSessionUID = 805963520
    RTRadiationUsage = 805963521
    ReferencedRTRadiationSetSequence = 805963522
    ReferencedRTRadiationRecordSequence = 805963523
    RTRadiationSetDeliveryNumber = 805963524
    ClinicalFractionNumber = 805963525
    RTTreatmentFractionCompletionStatus = 805963526
    RTRadiationSetUsage = 805963527
    TreatmentDeliveryContinuationFlag = 805963528
    TreatmentRecordContentOrigin = 805963529
    RTTreatmentTerminationStatus = 805963540
    RTTreatmentTerminationReasonCodeSequence = 805963541
    MachineSpecificTreatmentTerminationCodeSequence = 805963542
    RTRadiationSalvageRecordControlPointSequence = 805963554
    StartingMetersetValueKnownFlag = 805963555
    TreatmentTerminationDescription = 805963568
    TreatmentToleranceViolationSequence = 805963569
    TreatmentToleranceViolationCategory = 805963570
    TreatmentToleranceViolationAttributeSequence = 805963571
    TreatmentToleranceViolationDescription = 805963572
    TreatmentToleranceViolationIdentification = 805963573
    TreatmentToleranceViolationDateTime = 805963574
    RecordedRTControlPointDateTime = 805963578
    ReferencedRadiationRTControlPointIndex = 805963579
    AlternateValueSequence = 805963582
    ConfirmationSequence = 805963583
    InterlockSequence = 805963584
    InterlockDateTime = 805963585
    InterlockDescription = 805963586
    InterlockOriginatingDeviceSequence = 805963587
    InterlockCodeSequence = 805963588
    InterlockResolutionCodeSequence = 805963589
    InterlockResolutionUserSequence = 805963590
    OverrideDateTime = 805963616
    TreatmentToleranceViolationTypeCodeSequence = 805963617
    TreatmentToleranceViolationCauseCodeSequence = 805963618
    MeasuredMetersetToDoseMappingSequence = 805963634
    ReferencedExpectedInVivoMeasurementValueIndex = 805963635
    DoseMeasurementDeviceCodeSequence = 805963636
    AdditionalParameterRecordingInstanceSequence = 805963648
    InterlockOriginDescription = 805963651
    RTPatientPositionScopeSequence = 805963652
    ReferencedTreatmentPositionGroupUID = 805963653
    RadiationOrderIndex = 805963654
    OmittedRadiationSequence = 805963655
    ReasonforOmissionCodeSequence = 805963656
    RTDeliveryStartPatientPositionSequence = 805963657
    RTTreatmentPreparationPatientPositionSequence = 805963658
    ReferencedRTTreatmentPreparationSequence = 805963659
    ReferencedPatientSetupPhotoSequence = 805963660
    PatientTreatmentPreparationMethodCodeSequence = 805963661
    PatientTreatmentPreparationProcedureParameterDescription = 805963662
    PatientTreatmentPreparationDeviceSequence = 805963663
    PatientTreatmentPreparationProcedureSequence = 805963664
    PatientTreatmentPreparationProcedureCodeSequence = 805963665
    PatientTreatmentPreparationMethodDescription = 805963666
    PatientTreatmentPreparationProcedureParameterSequence = 805963667
    PatientSetupPhotoDescription = 805963668
    PatientTreatmentPreparationProcedureIndex = 805963669
    ReferencedPatientSetupProcedureIndex = 805963670
    RTRadiationTaskSequence = 805963671
    RTPatientPositionDisplacementSequence = 805963672
    RTPatientPositionSequence = 805963673
    DisplacementReferenceLabel = 805963674
    DisplacementMatrix = 805963675
    PatientSupportDisplacementSequence = 805963676
    DisplacementReferenceLocationCodeSequence = 805963677
    RTRadiationSetDeliveryUsage = 805963678
    ReferencedRTPlanSequence = 806092802
    ReferencedBeamSequence = 806092804
    ReferencedBeamNumber = 806092806
    ReferencedReferenceImageNumber = 806092807
    StartCumulativeMetersetWeight = 806092808
    EndCumulativeMetersetWeight = 806092809
    ReferencedBrachyApplicationSetupSequence = 806092810
    ReferencedBrachyApplicationSetupNumber = 806092812
    ReferencedSourceNumber = 806092814
    ReferencedFractionGroupSequence = 806092832
    ReferencedFractionGroupNumber = 806092834
    ReferencedVerificationImageSequence = 806092864
    ReferencedReferenceImageSequence = 806092866
    ReferencedDoseReferenceSequence = 806092880
    ReferencedDoseReferenceNumber = 806092881
    BrachyReferencedDoseReferenceSequence = 806092885
    ReferencedStructureSetSequence = 806092896
    ReferencedPatientSetupNumber = 806092906
    ReferencedDoseSequence = 806092928
    ReferencedToleranceTableNumber = 806092960
    ReferencedBolusSequence = 806092976
    ReferencedWedgeNumber = 806092992
    ReferencedCompensatorNumber = 806093008
    ReferencedBlockNumber = 806093024
    ReferencedControlPointIndex = 806093040
    ReferencedControlPointSequence = 806093042
    ReferencedStartControlPointIndex = 806093044
    ReferencedStopControlPointIndex = 806093046
    ReferencedRangeShifterNumber = 806093056
    ReferencedLateralSpreadingDeviceNumber = 806093058
    ReferencedRangeModulatorNumber = 806093060
    OmittedBeamTaskSequence = 806093073
    ReasonForOmission = 806093074
    ReasonForOmissionDescription = 806093075
    ApprovalStatus = 806223874
    ReviewDate = 806223876
    ReviewTime = 806223877
    ReviewerName = 806223880
    RadiobiologicalDoseEffectSequence = 806354945
    RadiobiologicalDoseEffectFlag = 806354946
    EffectiveDoseCalculationMethodCategoryCodeSequence = 806354947
    EffectiveDoseCalculationMethodCodeSequence = 806354948
    EffectiveDoseCalculationMethodDescription = 806354949
    ConceptualVolumeUID = 806354950
    OriginatingSOPInstanceReferenceSequence = 806354951
    ConceptualVolumeConstituentSequence = 806354952
    EquivalentConceptualVolumeInstanceReferenceSequence = 806354953
    EquivalentConceptualVolumesSequence = 806354954
    ReferencedConceptualVolumeUID = 806354955
    ConceptualVolumeCombinationExpression = 806354956
    ConceptualVolumeConstituentIndex = 806354957
    ConceptualVolumeCombinationFlag = 806354958
    ConceptualVolumeCombinationDescription = 806354959
    ConceptualVolumeSegmentationDefinedFlag = 806354960
    ConceptualVolumeSegmentationReferenceSequence = 806354961
    ConceptualVolumeConstituentSegmentationReferenceSequence = 806354962
    ConstituentConceptualVolumeUID = 806354963
    DerivationConceptualVolumeSequence = 806354964
    SourceConceptualVolumeUID = 806354965
    ConceptualVolumeDerivationAlgorithmSequence = 806354966
    ConceptualVolumeDescription = 806354967
    SourceConceptualVolumeSequence = 806354968
    AuthorIdentificationSequence = 806354969
    ManufacturerModelVersion = 806354970
    DeviceAlternateIdentifier = 806354971
    DeviceAlternateIdentifierType = 806354972
    DeviceAlternateIdentifierFormat = 806354973
    SegmentationCreationTemplateLabel = 806354974
    SegmentationTemplateUID = 806354975
    ReferencedSegmentReferenceIndex = 806354976
    SegmentReferenceSequence = 806354977
    SegmentReferenceIndex = 806354978
    DirectSegmentReferenceSequence = 806354979
    CombinationSegmentReferenceSequence = 806354980
    ConceptualVolumeSequence = 806354981
    SegmentedRTAccessoryDeviceSequence = 806354982
    SegmentCharacteristicsSequence = 806354983
    RelatedSegmentCharacteristicsSequence = 806354984
    SegmentCharacteristicsPrecedence = 806354985
    RTSegmentAnnotationSequence = 806354986
    SegmentAnnotationCategoryCodeSequence = 806354987
    SegmentAnnotationTypeCodeSequence = 806354988
    DeviceLabel = 806354989
    DeviceTypeCodeSequence = 806354990
    SegmentAnnotationTypeModifierCodeSequence = 806354991
    PatientEquipmentRelationshipCodeSequence = 806354992
    ReferencedFiducialsUID = 806354993
    PatientTreatmentOrientationSequence = 806354994
    UserContentLabel = 806354995
    UserContentLongLabel = 806354996
    EntityLabel = 806354997
    EntityName = 806354998
    EntityDescription = 806354999
    EntityLongLabel = 806355000
    DeviceIndex = 806355001
    RTTreatmentPhaseIndex = 806355002
    RTTreatmentPhaseUID = 806355003
    RTPrescriptionIndex = 806355004
    RTSegmentAnnotationIndex = 806355005
    BasisRTTreatmentPhaseIndex = 806355006
    RelatedRTTreatmentPhaseIndex = 806355007
    ReferencedRTTreatmentPhaseIndex = 806355008
    ReferencedRTPrescriptionIndex = 806355009
    ReferencedParentRTPrescriptionIndex = 806355010
    ManufacturerDeviceIdentifier = 806355011
    InstanceLevelReferencedPerformedProcedureStepSequence = 806355012
    RTTreatmentPhaseIntentPresenceFlag = 806355013
    RadiotherapyTreatmentType = 806355014
    TeletherapyRadiationType = 806355015
    BrachytherapySourceType = 806355016
    ReferencedRTTreatmentPhaseSequence = 806355017
    ReferencedDirectSegmentInstanceSequence = 806355018
    IntendedRTTreatmentPhaseSequence = 806355019
    IntendedPhaseStartDate = 806355020
    IntendedPhaseEndDate = 806355021
    RTTreatmentPhaseIntervalSequence = 806355022
    TemporalRelationshipIntervalAnchor = 806355023
    MinimumNumberOfIntervalDays = 806355024
    MaximumNumberOfIntervalDays = 806355025
    PertinentSOPClassesInStudy = 806355026
    PertinentSOPClassesInSeries = 806355027
    RTPrescriptionLabel = 806355028
    RTPhysicianIntentPredecessorSequence = 806355029
    RTTreatmentApproachLabel = 806355030
    RTPhysicianIntentSequence = 806355031
    RTPhysicianIntentIndex = 806355032
    RTTreatmentIntentType = 806355033
    RTPhysicianIntentNarrative = 806355034
    RTProtocolCodeSequence = 806355035
    ReasonForSuperseding = 806355036
    RTDiagnosisCodeSequence = 806355037
    ReferencedRTPhysicianIntentIndex = 806355038
    RTPhysicianIntentInputInstanceSequence = 806355039
    RTAnatomicPrescriptionSequence = 806355040
    PriorTreatmentDoseDescription = 806355041
    PriorTreatmentReferenceSequence = 806355042
    DosimetricObjectiveEvaluationScope = 806355043
    TherapeuticRoleCategoryCodeSequence = 806355044
    TherapeuticRoleTypeCodeSequence = 806355045
    ConceptualVolumeOptimizationPrecedence = 806355046
    ConceptualVolumeCategoryCodeSequence = 806355047
    ConceptualVolumeBlockingConstraint = 806355048
    ConceptualVolumeTypeCodeSequence = 806355049
    ConceptualVolumeTypeModifierCodeSequence = 806355050
    RTPrescriptionSequence = 806355051
    DosimetricObjectiveSequence = 806355052
    DosimetricObjectiveTypeCodeSequence = 806355053
    DosimetricObjectiveUID = 806355054
    ReferencedDosimetricObjectiveUID = 806355055
    DosimetricObjectiveParameterSequence = 806355056
    ReferencedDosimetricObjectivesSequence = 806355057
    AbsoluteDosimetricObjectiveFlag = 806355059
    DosimetricObjectiveWeight = 806355060
    DosimetricObjectivePurpose = 806355061
    PlanningInputInformationSequence = 806355062
    TreatmentSite = 806355063
    TreatmentSiteCodeSequence = 806355064
    FractionPatternSequence = 806355065
    TreatmentTechniqueNotes = 806355066
    PrescriptionNotes = 806355067
    NumberOfIntervalFractions = 806355068
    NumberOfFractions = 806355069
    IntendedDeliveryDuration = 806355070
    FractionationNotes = 806355071
    RTTreatmentTechniqueCodeSequence = 806355072
    PrescriptionNotesSequence = 806355073
    FractionBasedRelationshipSequence = 806355074
    FractionBasedRelationshipIntervalAnchor = 806355075
    MinimumHoursBetweenFractions = 806355076
    IntendedFractionStartTime = 806355077
    IntendedStartDayOfWeek = 806355078
    WeekdayFractionPatternSequence = 806355079
    DeliveryTimeStructureCodeSequence = 806355080
    TreatmentSiteModifierCodeSequence = 806355081
    RoboticBaseLocationIndicator = 806355088
    RoboticPathNodeSetCodeSequence = 806355089
    RoboticNodeIdentifier = 806355090
    RTTreatmentSourceCoordinates = 806355091
    RadiationSourceCoordinateSystemYawAngle = 806355092
    RadiationSourceCoordinateSystemRollAngle = 806355093
    RadiationSourceCoordinateSystemPitchAngle = 806355094
    RoboticPathControlPointSequence = 806355095
    TomotherapeuticControlPointSequence = 806355096
    TomotherapeuticLeafOpenDurations = 806355097
    TomotherapeuticLeafInitialClosedDurations = 806355098
    Arbitrary = 1073741840
    TextComments = 1073758208
    ResultsID = 1074266176
    ResultsIDIssuer = 1074266178
    ReferencedInterpretationSequence = 1074266192
    ReportProductionStatusTrial = 1074266367
    InterpretationRecordedDate = 1074266368
    InterpretationRecordedTime = 1074266369
    InterpretationRecorder = 1074266370
    ReferenceToRecordedSound = 1074266371
    InterpretationTranscriptionDate = 1074266376
    InterpretationTranscriptionTime = 1074266377
    InterpretationTranscriber = 1074266378
    InterpretationText = 1074266379
    InterpretationAuthor = 1074266380
    InterpretationApproverSequence = 1074266385
    InterpretationApprovalDate = 1074266386
    InterpretationApprovalTime = 1074266387
    PhysicianApprovingInterpretation = 1074266388
    InterpretationDiagnosisDescription = 1074266389
    InterpretationDiagnosisCodeSequence = 1074266391
    ResultsDistributionListSequence = 1074266392
    DistributionName = 1074266393
    DistributionAddress = 1074266394
    InterpretationID = 1074266624
    InterpretationIDIssuer = 1074266626
    InterpretationTypeID = 1074266640
    InterpretationStatusID = 1074266642
    Impressions = 1074266880
    ResultsComments = 1074282496
    LowEnergyDetectors = 1074790401
    HighEnergyDetectors = 1074790402
    DetectorGeometrySequence = 1074790404
    ThreatROIVoxelSequence = 1074794497
    ThreatROIBase = 1074794500
    ThreatROIExtents = 1074794501
    ThreatROIBitmap = 1074794502
    RouteSegmentID = 1074794503
    GantryType = 1074794504
    OOIOwnerType = 1074794505
    RouteSegmentSequence = 1074794506
    PotentialThreatObjectID = 1074794512
    ThreatSequence = 1074794513
    ThreatCategory = 1074794514
    ThreatCategoryDescription = 1074794515
    ATDAbilityAssessment = 1074794516
    ATDAssessmentFlag = 1074794517
    ATDAssessmentProbability = 1074794518
    Mass = 1074794519
    Density = 1074794520
    ZEffective = 1074794521
    BoardingPassID = 1074794522
    CenterOfMass = 1074794523
    CenterOfPTO = 1074794524
    BoundingPolygon = 1074794525
    RouteSegmentStartLocationID = 1074794526
    RouteSegmentEndLocationID = 1074794527
    RouteSegmentLocationIDType = 1074794528
    AbortReason = 1074794529
    VolumeOfPTO = 1074794531
    AbortFlag = 1074794532
    RouteSegmentStartTime = 1074794533
    RouteSegmentEndTime = 1074794534
    TDRType = 1074794535
    InternationalRouteSegment = 1074794536
    ThreatDetectionAlgorithmAndVersion = 1074794537
    AssignedLocation = 1074794538
    AlarmDecisionTime = 1074794539
    AlarmDecision = 1074794545
    NumberOfTotalObjects = 1074794547
    NumberOfAlarmObjects = 1074794548
    PTORepresentationSequence = 1074794551
    ATDAssessmentSequence = 1074794552
    TIPType = 1074794553
    DICOSVersion = 1074794554
    OOIOwnerCreationTime = 1074794561
    OOIType = 1074794562
    OOISize = 1074794563
    AcquisitionStatus = 1074794564
    BasisMaterialsCodeSequence = 1074794565
    PhantomType = 1074794566
    OOIOwnerSequence = 1074794567
    ScanType = 1074794568
    ItineraryID = 1074794577
    ItineraryIDType = 1074794578
    ItineraryIDAssigningAuthority = 1074794579
    RouteID = 1074794580
    RouteIDAssigningAuthority = 1074794581
    InboundArrivalType = 1074794582
    CarrierID = 1074794584
    CarrierIDAssigningAuthority = 1074794585
    SourceOrientation = 1074794592
    SourcePosition = 1074794593
    BeltHeight = 1074794594
    AlgorithmRoutingCodeSequence = 1074794596
    TransportClassification = 1074794599
    OOITypeDescriptor = 1074794600
    TotalProcessingTime = 1074794601
    DetectorCalibrationData = 1074794604
    AdditionalScreeningPerformed = 1074794605
    AdditionalInspectionSelectionCriteria = 1074794606
    AdditionalInspectionMethodSequence = 1074794607
    AITDeviceType = 1074794608
    QRMeasurementsSequence = 1074794609
    TargetMaterialSequence = 1074794610
    SNRThreshold = 1074794611
    ImageScaleRepresentation = 1074794613
    ReferencedPTOSequence = 1074794614
    ReferencedTDRInstanceSequence = 1074794615
    PTOLocationDescription = 1074794616
    AnomalyLocatorIndicatorSequence = 1074794617
    AnomalyLocatorIndicator = 1074794618
    PTORegionSequence = 1074794619
    InspectionSelectionCriteria = 1074794620
    SecondaryInspectionMethodSequence = 1074794621
    PRCSToRCSOrientation = 1074794622
    MACParametersSequence = 1342046209
    SharedFunctionalGroupsSequence = 1375769129
    PerFrameFunctionalGroupsSequence = 1375769136
    WaveformSequence = 1409286400
    ChannelMinimumValue = 1409286416
    ChannelMaximumValue = 1409286418
    WaveformBitsAllocated = 1409290244
    WaveformSampleInterpretation = 1409290246
    WaveformPaddingValue = 1409290250
    WaveformData = 1409290256
    FirstOrderPhaseCorrectionAngle = 1442840592
    SpectroscopyData = 1442840608
    ExtendedOffsetTable = 2145386497
    ExtendedOffsetTableLengths = 2145386498
    FloatPixelData = 2145386504
    DoubleFloatPixelData = 2145386505
    PixelData = 2145386512
    CoefficientsSDVN = 2145386528
    CoefficientsSDHN = 2145386544
    CoefficientsSDDN = 2145386560
    DigitalSignaturesSequence = 4294639610
    DataSetTrailingPadding = 4294770684
    Item = 4294893568
    ItemDelimitationItem = 4294893581
    SequenceDelimitationItem = 4294893789
